@@ -32,7 +32,8 @@ _kubectl set env deployment -n $namespace virt-operator \
     VIRT_CONTROLLER_SHASUM=$VIRT_CONTROLLER_SHA \
     VIRT_API_SHASUM=$VIRT_API_SHA \
     VIRT_EXPORTPROXY_SHASUM=$VIRT_EXPORTPROXY_SHA \
-    VIRT_EXPORTSERVER_SHASUM=$VIRT_EXPORTSERVER_SHA
+    VIRT_EXPORTSERVER_SHASUM=$VIRT_EXPORTSERVER_SHA \
+    VIRT_SYNCHRONIZATION_CONTROLLER_SHASUM=$VIRT_SYNCHRONIZATION_CONTROLLER_SHASUM
 
 wait_for ds virt-handler "$VIRT_LAUNCHER_SHA $VIRT_HANDLER_SHA"
 wait_for deployment virt-controller "$VIRT_LAUNCHER_SHA $VIRT_CONTROLLER_SHA"
