@@ -21,4 +21,4 @@ rm -f staging/src/kubevirt.io/api/apitesting/testdata/HEAD/*.{yaml,json}
 # UPDATE_COMPATIBILITY_FIXTURE_DATA=true regenerates fixture data if needed.
 # -run //HEAD only runs the test cases comparing against testdata for HEAD.
 
-hack/dockerized "UPDATE_COMPATIBILITY_FIXTURE_DATA=true go test kubevirt.io/api/apitesting -run //HEAD >/dev/null 2>&1 || true && go test kubevirt.io/api/apitesting -run //HEAD -count=1"
+hack/dockerized "UPDATE_COMPATIBILITY_FIXTURE_DATA=true go test -mod=readonly kubevirt.io/api/apitesting -run //HEAD >/dev/null 2>&1 || true && go test -mod=readonly kubevirt.io/api/apitesting -run //HEAD -count=1"
