@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2017 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -150,23 +150,6 @@ var _ = Describe("ContainerDisk", func() {
 				Expect(err).To(HaveOccurred())
 			})
 
-			It("by verifying launcher directory locations", func() {
-				vmi := libvmi.New()
-				vmi.UID = "6789"
-
-				path, err := GetDiskTargetPartFromLauncherView(1)
-				Expect(err).To(HaveOccurred())
-				Expect(path).To(Equal(""))
-
-				expectedPath := fmt.Sprintf("%s/disk_1.img", tmpDir)
-				_, err = os.Create(expectedPath)
-				Expect(err).ToNot(HaveOccurred())
-
-				path, err = GetDiskTargetPartFromLauncherView(1)
-				Expect(err).ToNot(HaveOccurred())
-				Expect(path).To(Equal(expectedPath))
-			})
-
 			DescribeTable("by verifying that resources are set if the VMI wants the guaranteed QOS class", func(req, lim, expectedReq, expectedLimit k8sv1.ResourceList) {
 				clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
 					SupportContainerResources: []v1.SupportContainerResources{
@@ -368,7 +351,8 @@ var _ = Describe("ContainerDisk", func() {
 
 				pod := createMigrationSourcePod(vmi)
 
-				imageIDs := ExtractImageIDsFromSourcePod(vmi, pod)
+				imageIDs, err := ExtractImageIDsFromSourcePod(vmi, pod)
+				Expect(err).ToNot(HaveOccurred())
 				Expect(imageIDs).To(HaveKeyWithValue("disk1", "someimage@sha256:0"))
 				Expect(imageIDs).To(HaveKeyWithValue("disk2", "someimage@sha256:1"))
 				Expect(imageIDs).To(HaveLen(2))
@@ -392,7 +376,8 @@ var _ = Describe("ContainerDisk", func() {
 				pod := createMigrationSourcePod(vmi)
 
 				By("Extracting image IDs from the source pod")
-				imageIDs := ExtractImageIDsFromSourcePod(vmi, pod)
+				imageIDs, err := ExtractImageIDsFromSourcePod(vmi, pod)
+				Expect(err).ToNot(HaveOccurred())
 				Expect(imageIDs).To(HaveKeyWithValue("disk1", "someimage@sha256:0"))
 				Expect(imageIDs).To(HaveKeyWithValue("kernel-boot-volume", "someimage@sha256:bootcontainer"))
 				Expect(imageIDs).To(HaveLen(2))
@@ -404,7 +389,7 @@ var _ = Describe("ContainerDisk", func() {
 				Expect(newContainers[1].Image).To(Equal("someimage@sha256:bootcontainer"))
 			})
 
-			It("should return the source image tag if it can't detect a reproducible imageID", func() {
+			It("should fail if it can't detect a reproducible imageID", func() {
 				By("Creating a new VMI with a container disk")
 				vmi := libvmi.New(
 					libvmi.WithContainerDisk("disk1", someImage),
@@ -414,18 +399,21 @@ var _ = Describe("ContainerDisk", func() {
 				pod := createMigrationSourcePod(vmi)
 				pod.Status.ContainerStatuses[0].ImageID = "rubbish"
 
-				imageIDs := ExtractImageIDsFromSourcePod(vmi, pod)
-
-				Expect(imageIDs["disk1"]).To(Equal(vmi.Spec.Volumes[0].ContainerDisk.Image))
+				_, err := ExtractImageIDsFromSourcePod(vmi, pod)
+				Expect(err).To(HaveOccurred())
+				Expect(err.Error()).To(Equal(`failed to identify image digest for container "someimage:v1.2.3.4" with id "rubbish"`))
 			})
 
 			DescribeTable("It should detect the image ID from", func(imageID string) {
 				expected := "myregistry.io/myimage@sha256:4gjffGJlg4"
-				res := toPullableImageReference("myregistry.io/myimage", imageID)
+				res, err := toImageWithDigest("myregistry.io/myimage", imageID)
+				Expect(err).ToNot(HaveOccurred())
 				Expect(res).To(Equal(expected))
-				res = toPullableImageReference("myregistry.io/myimage:1234", imageID)
+				res, err = toImageWithDigest("myregistry.io/myimage", imageID)
+				Expect(err).ToNot(HaveOccurred())
 				Expect(res).To(Equal(expected))
-				res = toPullableImageReference("myregistry.io/myimage:latest", imageID)
+				res, err = toImageWithDigest("myregistry.io/myimage", imageID)
+				Expect(err).ToNot(HaveOccurred())
 				Expect(res).To(Equal(expected))
 			},
 				Entry("docker", "docker://sha256:4gjffGJlg4"),
@@ -434,7 +422,8 @@ var _ = Describe("ContainerDisk", func() {
 			)
 
 			DescribeTable("It should detect the base image from", func(given, expected string) {
-				res := toPullableImageReference(given, "docker://sha256:4gjffGJlg4")
+				res, err := toImageWithDigest(given, "docker://sha256:4gjffGJlg4")
+				Expect(err).ToNot(HaveOccurred())
 				Expect(strings.Split(res, "@sha256:")[0]).To(Equal(expected))
 			},
 				Entry("image with registry and no tags or shasum", "myregistry.io/myimage", "myregistry.io/myimage"),
@@ -458,7 +447,8 @@ var _ = Describe("ContainerDisk", func() {
 				)
 
 				pod := createMigrationSourcePod(vmi)
-				imageIDs := ExtractImageIDsFromSourcePod(vmi, pod)
+				imageIDs, err := ExtractImageIDsFromSourcePod(vmi, pod)
+				Expect(err).ToNot(HaveOccurred())
 
 				newContainers := GenerateContainers(vmi, clusterConfig, imageIDs, "a-name", "something")
 
