@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2024 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -26,13 +26,10 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
-	k8sv1 "k8s.io/api/core/v1"
 	k8smetav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	k8sruntime "k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/testing"
 
-	networkv1 "github.com/k8snetworkplumbingwg/network-attachment-definition-client/pkg/apis/k8s.cni.cncf.io/v1"
-
 	"kubevirt.io/client-go/kubevirt/fake"
 
 	v1 "kubevirt.io/api/core/v1"
@@ -40,33 +37,28 @@ import (
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	libvmistatus "kubevirt.io/kubevirt/pkg/libvmi/status"
 	"kubevirt.io/kubevirt/pkg/network/controllers"
+	"kubevirt.io/kubevirt/pkg/network/namescheme"
 	"kubevirt.io/kubevirt/pkg/network/vmispec"
 )
 
 var _ = Describe("VM Network Controller", func() {
 	const (
+		defaultNetName   = "default"
 		secondaryNetName = "foonet"
 		nadName          = "foonet-nad"
 	)
-	DescribeTable("sync does nothing when", func(vm *v1.VirtualMachine, vmi *v1.VirtualMachineInstance, podGetter stubPodGetter) {
-		c := controllers.NewVMController(fake.NewSimpleClientset(), podGetter)
+	DescribeTable("sync does nothing when", func(vm *v1.VirtualMachine, vmi *v1.VirtualMachineInstance) {
+		c := controllers.NewVMController(fake.NewSimpleClientset())
 		originalVM := vm.DeepCopy()
 		Expect(c.Sync(vm, vmi)).To(Equal(originalVM))
 	},
-		Entry("the VM is not running (there is no VMI)", newEmptyVM(), nil, stubPodGetter{}),
+		Entry("the VM is not running (there is no VMI)", newEmptyVM(), nil),
 		Entry(
 			"the VMI is marked for deletion",
 			newEmptyVM(),
 			&v1.VirtualMachineInstance{ObjectMeta: k8smetav1.ObjectMeta{DeletionTimestamp: &k8smetav1.Time{}}},
-			stubPodGetter{},
-		),
-		Entry("the VM & VMI have no interfaces and no pod is found", newEmptyVM(), libvmi.New(), stubPodGetter{}),
-		Entry(
-			"the VM & VMI have no interfaces",
-			newEmptyVM(),
-			libvmi.New(),
-			stubPodGetter{pod: &k8sv1.Pod{}},
 		),
+		Entry("the VM & VMI have no interfaces", newEmptyVM(), libvmi.New()),
 		Entry(
 			"the VM & VMI have identical interfaces",
 			libvmi.NewVirtualMachine(libvmi.New(
@@ -81,26 +73,25 @@ var _ = Describe("VM Network Controller", func() {
 				libvmi.WithNetwork(v1.DefaultPodNetwork()),
 				libvmi.WithNetwork(libvmi.MultusNetwork(secondaryNetName, nadName)),
 			),
-			stubPodGetter{pod: &k8sv1.Pod{}},
+		),
+		Entry("there is an interface status that does not match a spec interface",
+			libvmi.NewVirtualMachine(libvmi.New(
+				libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)),
+			libvmi.New(
+				libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+				libvmistatus.WithStatus(libvmistatus.New(
+					libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{Name: "DEFAULT"}),
+				)),
+			),
 		),
 	)
 
-	It("sync fails when pod fetching returns an error", func() {
-		c := controllers.NewVMController(
-			fake.NewSimpleClientset(),
-			stubPodGetter{err: errors.New("test")},
-		)
-		updatedVM, err := c.Sync(newEmptyVM(), libvmi.New())
-		Expect(err).To(MatchError(isSyncErrorType, "syncError"))
-		Expect(updatedVM).To(Equal(newEmptyVM()))
-	})
-
 	It("sync fails when VMI patch returns an error", func() {
 		clientset := fake.NewSimpleClientset()
-		c := controllers.NewVMController(
-			clientset,
-			stubPodGetter{pod: &k8sv1.Pod{}},
-		)
+		c := controllers.NewVMController(clientset)
 
 		// Setup `Patch` to fail.
 		injectedPatchError := errors.New("test patch error")
@@ -132,10 +123,7 @@ var _ = Describe("VM Network Controller", func() {
 
 	DescribeTable("sync succeeds to hotplug new interface", func(ifaceToPlug v1.Interface) {
 		clientset := fake.NewSimpleClientset()
-		c := controllers.NewVMController(
-			clientset,
-			stubPodGetter{pod: &k8sv1.Pod{}},
-		)
+		c := controllers.NewVMController(clientset)
 		vmi := libvmi.New(
 			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
 			libvmi.WithNetwork(v1.DefaultPodNetwork()),
@@ -181,12 +169,135 @@ var _ = Describe("VM Network Controller", func() {
 		}),
 	)
 
-	It("sync succeeds to clear hotunplug interfaces", func() {
+	It("sync does not hotplug a new absent interface", func() {
 		clientset := fake.NewSimpleClientset()
-		c := controllers.NewVMController(
-			clientset,
-			stubPodGetter{pod: &k8sv1.Pod{}},
+		c := controllers.NewVMController(clientset)
+		vmi := libvmi.New(
+			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+			libvmi.WithNetwork(v1.DefaultPodNetwork()),
 		)
+
+		originalVMI := vmi.DeepCopy()
+		vm := libvmi.NewVirtualMachine(originalVMI)
+
+		absentIfaceToPlug := v1.Interface{
+			Name:                   "absentIface",
+			State:                  v1.InterfaceStateAbsent,
+			InterfaceBindingMethod: v1.InterfaceBindingMethod{Bridge: &v1.InterfaceBridge{}},
+		}
+
+		vm = plugNetworkInterface(vm, absentIfaceToPlug)
+
+		// Simulate the existence of the VMI on the server (to allow the Sync to patch it).
+		_, err := clientset.KubevirtV1().VirtualMachineInstances(vmi.Namespace).Create(context.Background(), vmi, k8smetav1.CreateOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		updatedVM, err := c.Sync(vm, vmi)
+		Expect(err).NotTo(HaveOccurred())
+
+		// Assert that the hotplugged interface and its matching network were cleared
+		Expect(updatedVM.Spec.Template.Spec.Networks).To(Equal(originalVMI.Spec.Networks))
+		Expect(updatedVM.Spec.Template.Spec.Domain.Devices.Interfaces).To(Equal(originalVMI.Spec.Domain.Devices.Interfaces))
+
+		// Assert that the hotplug haven't reached the VMI
+		updatedVMI, err := clientset.KubevirtV1().
+			VirtualMachineInstances(vmi.Namespace).
+			Get(context.Background(), vmi.Name, k8smetav1.GetOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVMI.Spec.Networks).To(Equal(originalVMI.Spec.Networks))
+		Expect(updatedVMI.Spec.Domain.Devices.Interfaces).To(Equal(originalVMI.Spec.Domain.Devices.Interfaces))
+	})
+
+	DescribeTable("sync succeeds to mark an existing interface for hotunplug", func(currentIfaceState v1.InterfaceState) {
+		clientset := fake.NewSimpleClientset()
+		c := controllers.NewVMController(clientset)
+
+		multusAndDomainInfoSource := vmispec.NewInfoSource(vmispec.InfoSourceMultusStatus, vmispec.InfoSourceDomain)
+
+		secondaryIface := libvmi.InterfaceDeviceWithBridgeBinding(secondaryNetName)
+		secondaryIface.State = currentIfaceState
+
+		vmi := libvmi.New(
+			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+			libvmi.WithInterface(secondaryIface),
+			libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			libvmi.WithNetwork(libvmi.MultusNetwork(secondaryNetName, nadName)),
+			libvmistatus.WithStatus(
+				libvmistatus.New(
+					libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+						Name:             defaultNetName,
+						PodInterfaceName: namescheme.PrimaryPodInterfaceName,
+						InfoSource:       vmispec.InfoSourceDomain,
+					}),
+					libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+						Name:             secondaryNetName,
+						PodInterfaceName: namescheme.GenerateHashedInterfaceName(secondaryNetName),
+						InfoSource:       multusAndDomainInfoSource,
+					}),
+				),
+			),
+		)
+		vm := libvmi.NewVirtualMachine(vmi.DeepCopy())
+
+		// Mark the secondary interface for hotunplug
+		vm.Spec.Template.Spec.Domain.Devices.Interfaces[1].State = v1.InterfaceStateAbsent
+
+		// Simulate the existence of the VMI on the server (to allow the Sync to patch it).
+		_, err := clientset.KubevirtV1().VirtualMachineInstances(vmi.Namespace).Create(context.Background(), vmi, k8smetav1.CreateOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		originalVM := vm.DeepCopy()
+		updatedVM, err := c.Sync(vm, vmi)
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVM).To(Equal(originalVM))
+
+		// Assert that the hotunplug had reached the VMI
+		updatedVMI, err := clientset.KubevirtV1().
+			VirtualMachineInstances(vmi.Namespace).
+			Get(context.Background(), vmi.Name, k8smetav1.GetOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVMI.Spec.Networks).To(Equal(updatedVM.Spec.Template.Spec.Networks))
+		Expect(updatedVMI.Spec.Domain.Devices.Interfaces).To(Equal(updatedVM.Spec.Template.Spec.Domain.Devices.Interfaces))
+	},
+		Entry("when the current iface state is empty", v1.InterfaceState("")),
+		Entry("when the current iface state is absent", v1.InterfaceStateAbsent),
+	)
+
+	It("sync does not hotplug a new interface when it uses binding other than bridge or SR-IOV", func() {
+		clientset := fake.NewSimpleClientset()
+		c := controllers.NewVMController(clientset)
+
+		vmi := libvmi.New()
+		vm := libvmi.NewVirtualMachine(vmi.DeepCopy())
+
+		plugNetworkInterface(vm, libvmi.InterfaceWithBindingPlugin(secondaryNetName, v1.PluginBinding{Name: "someplugin"}))
+
+		// Simulate the existence of the VMI on the server (to allow the Sync to patch it).
+		_, err := clientset.KubevirtV1().VirtualMachineInstances(vmi.Namespace).Create(context.Background(), vmi, k8smetav1.CreateOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		originalVM := vm.DeepCopy()
+		updatedVM, err := c.Sync(vm, vmi)
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVM).To(Equal(originalVM))
+
+		// Assert that the hotunplug had not reached the VMI
+		updatedVMI, err := clientset.KubevirtV1().
+			VirtualMachineInstances(vmi.Namespace).
+			Get(context.Background(), vmi.Name, k8smetav1.GetOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVMI.Spec.Networks).To(BeEmpty())
+		Expect(updatedVMI.Spec.Domain.Devices.Interfaces).To(BeEmpty())
+	})
+
+	It("sync succeeds to clear hotunplug interfaces from running VM", func() {
+		clientset := fake.NewSimpleClientset()
+		c := controllers.NewVMController(clientset)
 		unpluggedIface := libvmi.InterfaceDeviceWithBridgeBinding("foonet")
 		unpluggedIface.State = v1.InterfaceStateAbsent
 		vmi := libvmi.New(
@@ -220,12 +331,31 @@ var _ = Describe("VM Network Controller", func() {
 		Expect(updatedVMI.Spec.Domain.Devices.Interfaces).To(Equal(updatedVM.Spec.Template.Spec.Domain.Devices.Interfaces))
 	})
 
-	It("sync does not hotunplug interfaces when pod is not found", func() {
+	It("sync succeeds to clear hotunplug interfaces from stopped VM", func() {
 		clientset := fake.NewSimpleClientset()
-		c := controllers.NewVMController(
-			clientset,
-			stubPodGetter{pod: nil},
+		c := controllers.NewVMController(clientset)
+		unpluggedIface := libvmi.InterfaceDeviceWithBridgeBinding("foonet")
+		unpluggedIface.State = v1.InterfaceStateAbsent
+		vmi := libvmi.New(
+			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+			libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			libvmi.WithInterface(unpluggedIface),
+			libvmi.WithNetwork(libvmi.MultusNetwork("foonet", "foonet-nad")),
 		)
+		vm := libvmi.NewVirtualMachine(vmi.DeepCopy())
+
+		originalVM := vm.DeepCopy()
+		updatedVM, err := c.Sync(vm, nil)
+		Expect(err).NotTo(HaveOccurred())
+
+		originalVM.Spec.Template.Spec.Networks = originalVM.Spec.Template.Spec.Networks[:1]
+		originalVM.Spec.Template.Spec.Domain.Devices.Interfaces = originalVM.Spec.Template.Spec.Domain.Devices.Interfaces[:1]
+		Expect(updatedVM).To(Equal(originalVM))
+	})
+
+	It("sync does not hotunplug interfaces when nameing scheme is unknown", func() {
+		clientset := fake.NewSimpleClientset()
+		c := controllers.NewVMController(clientset)
 		vmi := libvmi.New(
 			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
 			libvmi.WithNetwork(v1.DefaultPodNetwork()),
@@ -234,7 +364,9 @@ var _ = Describe("VM Network Controller", func() {
 		)
 		// Make sure the interfaces are visible on the status as well (otherwise hotunplug is not triggered)
 		for _, net := range vmi.Spec.Networks {
-			vmi.Status.Interfaces = append(vmi.Status.Interfaces, v1.VirtualMachineInstanceNetworkInterface{Name: net.Name})
+			vmi.Status.Interfaces = append(vmi.Status.Interfaces,
+				v1.VirtualMachineInstanceNetworkInterface{Name: net.Name, PodInterfaceName: ""},
+			)
 		}
 
 		vm := libvmi.NewVirtualMachine(vmi.DeepCopy())
@@ -267,10 +399,7 @@ var _ = Describe("VM Network Controller", func() {
 
 	DescribeTable("sync updates link state of an existing interface", func(fromState, toState v1.InterfaceState) {
 		clientset := fake.NewSimpleClientset()
-		c := controllers.NewVMController(
-			clientset,
-			stubPodGetter{pod: &k8sv1.Pod{}},
-		)
+		c := controllers.NewVMController(clientset)
 		const defaultNetName = "default"
 		vmi := libvmi.New(
 			libvmi.WithInterface(v1.Interface{
@@ -324,10 +453,7 @@ var _ = Describe("VM Network Controller", func() {
 
 	DescribeTable("sync doesn't update link state if hot-unplug is underway ", func(toState v1.InterfaceState) {
 		clientset := fake.NewSimpleClientset()
-		c := controllers.NewVMController(
-			clientset,
-			stubPodGetter{pod: &k8sv1.Pod{}},
-		)
+		c := controllers.NewVMController(clientset)
 		const defaultNetName = "default"
 		vmi := libvmi.New(
 			libvmi.WithInterface(v1.Interface{
@@ -373,28 +499,23 @@ var _ = Describe("VM Network Controller", func() {
 
 	It("sync does not hotunplug interfaces when legacy ordinal interface names are found", func() {
 		clientset := fake.NewSimpleClientset()
-		pod := &k8sv1.Pod{
-			ObjectMeta: k8smetav1.ObjectMeta{Annotations: map[string]string{
-				networkv1.NetworkStatusAnnot: `[
-						{"interface":"eth0", "name":"default", "namespace": "default"},
-						{"interface":"net1", "name":"foonet-nad", "namespace": "default"}
-					]`,
-			}},
-		}
-		c := controllers.NewVMController(
-			clientset,
-			stubPodGetter{pod: pod},
-		)
+		c := controllers.NewVMController(clientset)
 		vmi := libvmi.New(
 			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
 			libvmi.WithNetwork(v1.DefaultPodNetwork()),
 			libvmi.WithInterface(libvmi.InterfaceDeviceWithBridgeBinding("foonet")),
 			libvmi.WithNetwork(libvmi.MultusNetwork("foonet", "foonet-nad")),
+			libvmistatus.WithStatus(
+				libvmistatus.New(
+					libvmistatus.WithInterfaceStatus(
+						v1.VirtualMachineInstanceNetworkInterface{Name: defaultNetName, PodInterfaceName: namescheme.PrimaryPodInterfaceName},
+					),
+					libvmistatus.WithInterfaceStatus(
+						v1.VirtualMachineInstanceNetworkInterface{Name: "foonet", PodInterfaceName: "net1"},
+					),
+				),
+			),
 		)
-		// Make sure the interfaces are visible on the status as well (otherwise hotunplug is not triggered)
-		for _, net := range vmi.Spec.Networks {
-			vmi.Status.Interfaces = append(vmi.Status.Interfaces, v1.VirtualMachineInstanceNetworkInterface{Name: net.Name})
-		}
 
 		vm := libvmi.NewVirtualMachine(vmi.DeepCopy())
 
@@ -423,17 +544,122 @@ var _ = Describe("VM Network Controller", func() {
 		Expect(iface).NotTo(BeNil())
 		Expect(iface.State).NotTo(Equal(v1.InterfaceStateAbsent))
 	})
+
+	It("Sync successfully performs hotplug and hotunplug at the same time", func() {
+		const (
+			netToAttachName = "attach-me"
+
+			netToDetachName    = "detach-me"
+			netToDetachNADName = "detach-me-nad"
+		)
+
+		clientset := fake.NewSimpleClientset()
+		c := controllers.NewVMController(clientset)
+
+		multusAndDomainInfoSource := vmispec.NewInfoSource(vmispec.InfoSourceMultusStatus, vmispec.InfoSourceDomain)
+
+		ifaceToDetach := libvmi.InterfaceDeviceWithBridgeBinding(netToDetachName)
+		netToDetach := libvmi.MultusNetwork(netToDetachName, netToDetachNADName)
+
+		vmi := libvmi.New(
+			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+			libvmi.WithInterface(ifaceToDetach),
+			libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			libvmi.WithNetwork(netToDetach),
+			libvmistatus.WithStatus(
+				libvmistatus.New(
+					libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+						Name:             defaultNetName,
+						PodInterfaceName: namescheme.PrimaryPodInterfaceName,
+						InfoSource:       vmispec.InfoSourceDomain,
+					}),
+					libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+						Name:             netToDetachName,
+						PodInterfaceName: namescheme.GenerateHashedInterfaceName(netToDetachName),
+						InfoSource:       multusAndDomainInfoSource,
+					}),
+				),
+			),
+		)
+
+		vm := libvmi.NewVirtualMachine(vmi.DeepCopy())
+
+		// Mark the secondary interface for hotunplug
+		vm.Spec.Template.Spec.Domain.Devices.Interfaces[1].State = v1.InterfaceStateAbsent
+
+		vm = plugNetworkInterface(vm, libvmi.InterfaceDeviceWithBridgeBinding(netToAttachName))
+
+		// Simulate the existence of the VMI on the server (to allow the Sync to patch it).
+		_, err := clientset.KubevirtV1().VirtualMachineInstances(vmi.Namespace).Create(context.Background(), vmi, k8smetav1.CreateOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		originalVM := vm.DeepCopy()
+		updatedVM, err := c.Sync(vm, vmi)
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVM).To(Equal(originalVM))
+
+		// Assert that hotplug and hotunplug had reached the VMI
+		updatedVMI, err := clientset.KubevirtV1().
+			VirtualMachineInstances(vmi.Namespace).
+			Get(context.Background(), vmi.Name, k8smetav1.GetOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVMI.Spec.Networks).To(Equal(originalVM.Spec.Template.Spec.Networks))
+		Expect(updatedVMI.Spec.Domain.Devices.Interfaces).To(Equal(originalVM.Spec.Template.Spec.Domain.Devices.Interfaces))
+	})
+
+	It("sync does not hotunplug interfaces when a pending hotplug without a status entry exists", func() {
+		const (
+			netToDetachName    = "detach-me"
+			netToDetachNADName = "detach-me-nad"
+		)
+		clientset := fake.NewSimpleClientset()
+		c := controllers.NewVMController(clientset)
+
+		vmi := libvmi.New(
+			libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+			libvmi.WithInterface(libvmi.InterfaceDeviceWithBridgeBinding(netToDetachName)),
+			libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			libvmi.WithNetwork(libvmi.MultusNetwork(netToDetachName, netToDetachNADName)),
+			libvmistatus.WithStatus(
+				libvmistatus.New(
+					libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+						Name:             defaultNetName,
+						PodInterfaceName: namescheme.PrimaryPodInterfaceName,
+						InfoSource:       vmispec.InfoSourceDomain,
+					}),
+				),
+			),
+		)
+
+		originalVMI := vmi.DeepCopy()
+		vm := libvmi.NewVirtualMachine(vmi.DeepCopy())
+
+		// Simulate the existence of the VMI on the server (to allow the Sync to patch it).
+		_, err := clientset.KubevirtV1().VirtualMachineInstances(vmi.Namespace).Create(context.Background(), vmi, k8smetav1.CreateOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		// Mark the secondary interface for hotunplug
+		vm.Spec.Template.Spec.Domain.Devices.Interfaces[1].State = v1.InterfaceStateAbsent
+
+		originalVM := vm.DeepCopy()
+		updatedVM, err := c.Sync(vm, vmi)
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVM.Spec.Template.Spec.Networks).To(Equal(originalVM.Spec.Template.Spec.Networks))
+		Expect(updatedVM.Spec.Template.Spec.Domain.Devices.Interfaces).To(Equal(originalVM.Spec.Template.Spec.Domain.Devices.Interfaces))
+
+		updatedVMI, err := clientset.KubevirtV1().
+			VirtualMachineInstances(vmi.Namespace).
+			Get(context.Background(), vmi.Name, k8smetav1.GetOptions{})
+		Expect(err).NotTo(HaveOccurred())
+
+		Expect(updatedVMI.Spec.Networks).To(Equal(originalVMI.Spec.Networks))
+		Expect(updatedVMI.Spec.Domain.Devices.Interfaces).To(Equal(originalVMI.Spec.Domain.Devices.Interfaces))
+	})
 })
 
-type stubPodGetter struct {
-	pod *k8sv1.Pod
-	err error
-}
-
-func (s stubPodGetter) CurrentPod(_ *v1.VirtualMachineInstance) (*k8sv1.Pod, error) {
-	return s.pod, s.err
-}
-
 type syncError interface {
 	error
 	Reason() string
