@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2024 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -444,16 +444,6 @@ var _ = Describe("Annotations Generator", func() {
 			Expect(json.Unmarshal([]byte(actualAnnotations[downwardapi.NetworkInfoAnnot]), &actualNetInfo)).To(Succeed())
 
 			expectedNetInfo := []downwardapi.Interface{
-				{
-					Network: networkName2,
-					DeviceInfo: &networkv1.DeviceInfo{
-						Type:    "pci",
-						Version: "1.0.0",
-						Pci: &networkv1.PciDevice{
-							PciAddress: "0000:65:00.2",
-						},
-					},
-				},
 				{
 					Network: networkName3,
 					DeviceInfo: &networkv1.DeviceInfo{
@@ -464,9 +454,19 @@ var _ = Describe("Annotations Generator", func() {
 						},
 					},
 				},
+				{
+					Network: networkName2,
+					DeviceInfo: &networkv1.DeviceInfo{
+						Type:    "pci",
+						Version: "1.0.0",
+						Pci: &networkv1.PciDevice{
+							PciAddress: "0000:65:00.2",
+						},
+					},
+				},
 			}
 
-			Expect(actualNetInfo.Interfaces).To(ConsistOf(expectedNetInfo))
+			Expect(actualNetInfo.Interfaces).To(Equal(expectedNetInfo))
 		})
 	})
 
