@@ -3,13 +3,14 @@ package openapi
 import (
 	"encoding/json"
 	"fmt"
+	"log"
+	"os"
 	"strings"
 
 	"github.com/emicklei/go-restful/v3"
 	openapi_spec "github.com/go-openapi/spec"
 	"github.com/go-openapi/strfmt"
 	openapi_validate "github.com/go-openapi/validate"
-	"github.com/golang/glog"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/kube-openapi/pkg/builder"
 	"k8s.io/kube-openapi/pkg/common"
@@ -228,7 +229,8 @@ func CreateOpenAPIValidator(webServices []*restful.WebService) *Validator {
 	openapispec := LoadOpenAPISpec(webServices)
 	data, err := json.Marshal(openapispec)
 	if err != nil {
-		glog.Fatal(err)
+		log.Print(err)
+		os.Exit(2)
 	}
 
 	specSchema := &openapi_spec.Schema{}
@@ -247,7 +249,8 @@ func CreateOpenAPIValidator(webServices []*restful.WebService) *Validator {
 	// Expand the specSchemes
 	err = openapi_spec.ExpandSchema(specSchema, specSchema, nil)
 	if err != nil {
-		glog.Fatal(err)
+		log.Print(err)
+		os.Exit(2)
 	}
 
 	// Load spec once again for status. The status should accept unknown fields
@@ -260,7 +263,8 @@ func CreateOpenAPIValidator(webServices []*restful.WebService) *Validator {
 	// Expand the statusSchemes
 	err = openapi_spec.ExpandSchema(statusSchema, statusSchema, nil)
 	if err != nil {
-		glog.Fatal(err)
+		log.Print(err)
+		os.Exit(2)
 	}
 
 	return &Validator{
