@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -484,6 +484,28 @@ func (app *virtAPIApp) composeSubresources() {
 			Writes(v1.VirtualMachineInstanceFileSystemList{}).
 			Returns(http.StatusOK, "OK", v1.VirtualMachineInstanceFileSystemList{}))
 
+		subws.Route(subws.GET(definitions.NamespacedResourcePath(subresourcesvmiGVR)+definitions.SubResourcePath("objectgraph")).
+			To(subresourceApp.VMIObjectGraph).
+			Consumes(restful.MIME_JSON).
+			Reads(v1.ObjectGraphOptions{}).
+			Produces(restful.MIME_JSON).
+			Param(definitions.NamespaceParam(subws)).Param(definitions.NameParam(subws)).
+			Operation(version.Version+"vmi-objectgraph").
+			Doc("Get graph of objects related to a Virtual Machine Instance").
+			Writes(v1.ObjectGraphNode{}).
+			Returns(http.StatusOK, "OK", v1.ObjectGraphNode{}))
+
+		subws.Route(subws.GET(definitions.NamespacedResourcePath(subresourcesvmGVR)+definitions.SubResourcePath("objectgraph")).
+			To(subresourceApp.VMObjectGraph).
+			Consumes(restful.MIME_JSON).
+			Reads(v1.ObjectGraphOptions{}).
+			Produces(restful.MIME_JSON).
+			Param(definitions.NamespaceParam(subws)).Param(definitions.NameParam(subws)).
+			Operation(version.Version+"vm-objectgraph").
+			Doc("Get graph of objects related to a Virtual Machine").
+			Writes(v1.ObjectGraphNode{}).
+			Returns(http.StatusOK, "OK", v1.ObjectGraphNode{}))
+
 		subws.Route(subws.PUT(definitions.NamespacedResourcePath(subresourcesvmiGVR)+definitions.SubResourcePath("addvolume")).
 			To(subresourceApp.VMIAddVolumeRequestHandler).
 			Consumes(mime.MIME_ANY).
@@ -657,6 +679,10 @@ func (app *virtAPIApp) composeSubresources() {
 						Name:       "virtualmachines/expand-spec",
 						Namespaced: true,
 					},
+					{
+						Name:       "virtualmachines/objectgraph",
+						Namespaced: true,
+					},
 					{
 						Name:       "virtualmachineinstances/guestosinfo",
 						Namespaced: true,
@@ -677,6 +703,10 @@ func (app *virtAPIApp) composeSubresources() {
 						Name:       "virtualmachineinstances/removevolume",
 						Namespaced: true,
 					},
+					{
+						Name:       "virtualmachinesinstances/objectgraph",
+						Namespaced: true,
+					},
 					{
 						Name:       "virtualmachineinstances/sev/fetchcertchain",
 						Namespaced: true,
@@ -904,7 +934,7 @@ func (app *virtAPIApp) registerValidatingWebhooks(informers *webhooks.Informers)
 		validating_webhook.ServeVMIPreset(w, r)
 	})
 	http.HandleFunc(components.MigrationCreateValidatePath, func(w http.ResponseWriter, r *http.Request) {
-		validating_webhook.ServeMigrationCreate(w, r, app.virtCli)
+		validating_webhook.ServeMigrationCreate(w, r, app.clusterConfig, app.virtCli)
 	})
 	http.HandleFunc(components.MigrationUpdateValidatePath, func(w http.ResponseWriter, r *http.Request) {
 		validating_webhook.ServeMigrationUpdate(w, r)
