@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -27,13 +27,9 @@ import (
 	rt "runtime"
 	"strings"
 
-	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-
-	"kubevirt.io/client-go/kubecli"
-
-	"kubevirt.io/client-go/api"
+	"go.uber.org/mock/gomock"
 
 	admissionv1 "k8s.io/api/admission/v1"
 	k8sv1 "k8s.io/api/core/v1"
@@ -43,14 +39,15 @@ import (
 	k8sfield "k8s.io/apimachinery/pkg/util/validation/field"
 	k8sfake "k8s.io/client-go/kubernetes/fake"
 	"k8s.io/client-go/tools/cache"
-	"kubevirt.io/api/instancetype/v1beta1"
-	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
+
+	"kubevirt.io/client-go/api"
+	"kubevirt.io/client-go/kubecli"
 	fakeclientset "kubevirt.io/client-go/kubevirt/fake"
 
 	v1 "kubevirt.io/api/core/v1"
+	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
-	"kubevirt.io/kubevirt/pkg/instancetype/conflict"
 	instancetypeWebhooks "kubevirt.io/kubevirt/pkg/instancetype/webhooks/vm"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/liveupdate/memory"
@@ -489,6 +486,28 @@ var _ = Describe("Validating VM Admitter", func() {
 			},
 		},
 			true),
+		Entry("with valid request to add volume (virtio)", []v1.VirtualMachineVolumeRequest{
+			{
+				AddVolumeOptions: &v1.AddVolumeOptions{
+					Name: "testdisk2",
+					Disk: &v1.Disk{
+						Name: "testdisk2",
+						DiskDevice: v1.DiskDevice{
+							Disk: &v1.DiskTarget{
+								Bus: "virtio",
+							},
+						},
+					},
+					VolumeSource: &v1.HotplugVolumeSource{
+						PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{PersistentVolumeClaimVolumeSource: k8sv1.PersistentVolumeClaimVolumeSource{
+							ClaimName: "madeup",
+						},
+						},
+					},
+				},
+			},
+		},
+			true),
 		Entry("with valid request to add volume to a LUN disk", []v1.VirtualMachineVolumeRequest{
 			{
 				AddVolumeOptions: &v1.AddVolumeOptions{
@@ -511,6 +530,28 @@ var _ = Describe("Validating VM Admitter", func() {
 			},
 		},
 			true),
+		Entry("with invalid request to add volume to a LUN disk (virtio bus)", []v1.VirtualMachineVolumeRequest{
+			{
+				AddVolumeOptions: &v1.AddVolumeOptions{
+					Name: "testlun2",
+					Disk: &v1.Disk{
+						Name: "testlun2",
+						DiskDevice: v1.DiskDevice{
+							LUN: &v1.LunTarget{
+								Bus: "virtio",
+							},
+						},
+					},
+					VolumeSource: &v1.HotplugVolumeSource{
+						PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{PersistentVolumeClaimVolumeSource: k8sv1.PersistentVolumeClaimVolumeSource{
+							ClaimName: "madeupLUN",
+						},
+						},
+					},
+				},
+			},
+		},
+			false),
 		Entry("with invalid request to add volume with invalid disk/bus combination", []v1.VirtualMachineVolumeRequest{
 			{
 				AddVolumeOptions: &v1.AddVolumeOptions{
@@ -575,6 +616,29 @@ var _ = Describe("Validating VM Admitter", func() {
 			},
 		},
 			false),
+		Entry("with valid request to add volume with dedicated IOThreads snd virtio bus", []v1.VirtualMachineVolumeRequest{
+			{
+				AddVolumeOptions: &v1.AddVolumeOptions{
+					Name: "testdisk2",
+					Disk: &v1.Disk{
+						Name: "testdisk",
+						DiskDevice: v1.DiskDevice{
+							Disk: &v1.DiskTarget{
+								Bus: "virtio",
+							},
+						},
+						DedicatedIOThread: pointer.P(true),
+					},
+					VolumeSource: &v1.HotplugVolumeSource{
+						PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{PersistentVolumeClaimVolumeSource: k8sv1.PersistentVolumeClaimVolumeSource{
+							ClaimName: "madeup",
+						},
+						},
+					},
+				},
+			},
+		},
+			true),
 		Entry("with invalid request to add volume that conflicts with running vmi", []v1.VirtualMachineVolumeRequest{
 			{
 				AddVolumeOptions: &v1.AddVolumeOptions{
@@ -1257,31 +1321,17 @@ var _ = Describe("Validating VM Admitter", func() {
 	})
 
 	Context("Instancetype", func() {
-		var (
-			vm               *v1.VirtualMachine
-			testInstancetype *v1beta1.VirtualMachineInstancetype
-			testPreference   *v1beta1.VirtualMachinePreference
-		)
-
 		BeforeEach(func() {
-			vm = libvmi.NewVirtualMachine(
-				libvmi.New(
-					libvmi.WithNamespace("test"),
-				),
-				libvmi.WithInstancetype("test"),
-				libvmi.WithPreference("test"),
-			)
+			virtClient.EXPECT().VirtualMachineClusterInstancetype().Return(
+				fakeclientset.NewSimpleClientset().InstancetypeV1beta1().VirtualMachineClusterInstancetypes()).AnyTimes()
 
-			testInstancetypeClients := fakeclientset.NewSimpleClientset().InstancetypeV1beta1()
-
-			testInstancetypeClient := testInstancetypeClients.VirtualMachineInstancetypes(vm.Namespace)
-			virtClient.EXPECT().VirtualMachineInstancetype(gomock.Any()).Return(testInstancetypeClient).AnyTimes()
-
-			//TODO(lyarwood): Add WithNamespace to libinstancetype.builder and use here
-			testInstancetype = &instancetypev1beta1.VirtualMachineInstancetype{
+			vmsAdmitter.InstancetypeAdmitter = instancetypeWebhooks.NewAdmitter(virtClient)
+		})
+		It("should not apply instancetype to the VMISpec of the original VM", func() {
+			const clusterInstancetypeName = "clusterInstancetype"
+			clusterInstancetype := &instancetypev1beta1.VirtualMachineClusterInstancetype{
 				ObjectMeta: metav1.ObjectMeta{
-					Name:      vm.Spec.Instancetype.Name,
-					Namespace: vm.Namespace,
+					Name: clusterInstancetypeName,
 				},
 				Spec: instancetypev1beta1.VirtualMachineInstancetypeSpec{
 					CPU: instancetypev1beta1.CPUInstancetype{
@@ -1292,374 +1342,20 @@ var _ = Describe("Validating VM Admitter", func() {
 					},
 				},
 			}
-			_, err := virtClient.VirtualMachineInstancetype(vm.Namespace).Create(context.Background(), testInstancetype, metav1.CreateOptions{})
+			_, err := virtClient.VirtualMachineClusterInstancetype().Create(context.Background(), clusterInstancetype, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
 
-			fakePreferenceClient := testInstancetypeClients.VirtualMachinePreferences(vm.Namespace)
-			virtClient.EXPECT().VirtualMachinePreference(gomock.Any()).Return(fakePreferenceClient).AnyTimes()
-
-			//TODO(lyarwood): Add WithNamespace to libinstancetype.builder and use here
-			testPreference = &instancetypev1beta1.VirtualMachinePreference{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      vm.Spec.Preference.Name,
-					Namespace: vm.Namespace,
-				},
-				Spec: instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Cores),
-					},
-				},
-			}
-
-			_, err = virtClient.VirtualMachinePreference(vm.Namespace).Create(context.Background(), testPreference, metav1.CreateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-
-			vmsAdmitter.InstancetypeAdmitter = instancetypeWebhooks.NewAdmitter(virtClient)
-		})
-
-		It("should reject if instancetype is not found", func() {
-			vm.Spec.Instancetype.Name = "unknown"
-
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeFalse())
-			Expect(response.Result.Details.Causes).To(HaveLen(1))
-			Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueNotFound))
-			Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.instancetype"))
-		})
-
-		It("should reject if preference is not found", func() {
-			vm.Spec.Preference.Name = "unknown"
-
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeFalse())
-			Expect(response.Result.Details.Causes).To(HaveLen(1))
-			Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueNotFound))
-			Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.preference"))
-		})
-
-		It("should reject if instancetype fails to apply to VMI", func() {
-			vm.Spec.Template.Spec.Domain = v1.DomainSpec{
-				CPU: &v1.CPU{
-					Sockets: 1,
-				},
-				Memory: &v1.Memory{
-					Guest: pointer.P(resource.MustParse("1Gi")),
-				},
-			}
-
-			var (
-				conflict1 = conflict.New("spec", "template", "spec", "domain", "cpu", "sockets")
-				conflict2 = conflict.New("spec", "template", "spec", "domain", "memory")
-			)
-
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeFalse())
-			Expect(response.Result.Details.Causes).To(HaveLen(2))
-			Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
-			Expect(response.Result.Details.Causes[0].Field).To(Equal(conflict1.String()))
-			Expect(response.Result.Details.Causes[1].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
-			Expect(response.Result.Details.Causes[1].Field).To(Equal(conflict2.String()))
-		})
-
-		It("should not apply instancetype to the VMISpec of the original VM", func() {
 			// The VM should be admitted successfully
+			vm := libvmi.NewVirtualMachine(
+				libvmi.New(libvmi.WithNamespace(metav1.NamespaceDefault)),
+				libvmi.WithClusterInstancetype(clusterInstancetypeName),
+			)
 			response := admitVm(vmsAdmitter, vm)
 			Expect(response.Allowed).To(BeTrue())
 
 			// Ensure CPU has remained nil within the now admitted VMISpec
 			Expect(vm.Spec.Template.Spec.Domain.CPU).To(BeNil())
 		})
-
-		It("should reject if preference requirements are not met", func() {
-			testPreference.Spec.Requirements = &v1beta1.PreferenceRequirements{
-				CPU: &v1beta1.CPUPreferenceRequirement{
-					Guest: 10,
-				},
-			}
-
-			_, err := virtClient.VirtualMachinePreference(vm.Namespace).Update(context.Background(), testPreference, metav1.UpdateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeFalse())
-			Expect(response.Result.Details.Causes).To(HaveLen(1))
-			Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.instancetype"))
-			Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("failure checking preference requirements"))
-		})
-
-		const (
-			instancetypeCPUGuestPath       = "instancetype.spec.cpu.guest"
-			spreadAcrossSocketsCoresErrFmt = "%d vCPUs provided by the instance type are not divisible by the " +
-				"Spec.PreferSpreadSocketToCoreRatio or Spec.CPU.PreferSpreadOptions.Ratio of %d provided by the preference"
-			spreadAcrossCoresThreadsErrFmt        = "%d vCPUs provided by the instance type are not divisible by the number of threads per core %d"
-			spreadAcrossSocketsCoresThreadsErrFmt = "%d vCPUs provided by the instance type are not divisible by the number of threads per core " +
-				"%d and Spec.PreferSpreadSocketToCoreRatio or Spec.CPU.PreferSpreadOptions.Ratio of %d"
-		)
-
-		DescribeTable("should reject if PreferSpread requested with", func(vCPUs uint32, preferenceSpec instancetypev1beta1.VirtualMachinePreferenceSpec, expectedMessage string) {
-			testPreference.Spec = preferenceSpec
-
-			_, err := virtClient.VirtualMachinePreference(vm.Namespace).Update(context.Background(), testPreference, metav1.UpdateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-
-			testInstancetype.Spec.CPU.Guest = vCPUs
-
-			_, err = virtClient.VirtualMachineInstancetype(vm.Namespace).Update(context.Background(), testInstancetype, metav1.UpdateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeFalse())
-			Expect(response.Result.Details.Causes).To(HaveLen(1))
-			Expect(response.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueInvalid))
-			Expect(response.Result.Details.Causes[0].Message).To(Equal(expectedMessage))
-			Expect(response.Result.Details.Causes[0].Field).To(Equal(instancetypeCPUGuestPath))
-		},
-			Entry("3 vCPUs, default of SpreadAcrossSocketsCores and default SocketCoreRatio of 2 with spread",
-				uint32(3),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 3, 2),
-			),
-			Entry("3 vCPUs, default of SpreadAcrossSocketsCores and default SocketCoreRatio of 2 with preferSpread",
-				uint32(3),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 3, 2),
-			),
-			Entry("2 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via PreferSpreadSocketToCoreRatio of 3 with spread",
-				uint32(2),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferSpreadSocketToCoreRatio: uint32(3),
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 2, 3),
-			),
-			Entry("2 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via PreferSpreadSocketToCoreRatio of 3 with preferSpread",
-				uint32(2),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferSpreadSocketToCoreRatio: uint32(3),
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 2, 3),
-			),
-			Entry("2 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via SpreadOptions of 3 with spread",
-				uint32(2),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Ratio: pointer.P(uint32(3)),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 2, 3),
-			),
-			Entry("2 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via SpreadOptions of 3 with preferSpread",
-				uint32(2),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Ratio: pointer.P(uint32(3)),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 2, 3),
-			),
-			Entry("4 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via PreferSpreadSocketToCoreRatio of 3 with spread",
-				uint32(4),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferSpreadSocketToCoreRatio: uint32(3),
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 4, 3),
-			),
-			Entry("4 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via PreferSpreadSocketToCoreRatio of 3 with preferSpread",
-				uint32(4),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferSpreadSocketToCoreRatio: uint32(3),
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 4, 3),
-			),
-			Entry("4 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via SpreadOptions of 3 with spread",
-				uint32(4),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Ratio: pointer.P(uint32(3)),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 4, 3),
-			),
-			Entry("4 vCPUs, default of SpreadAcrossSocketsCores and SocketCoreRatio via SpreadOptions of 3 with preferSpread",
-				uint32(4),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Ratio: pointer.P(uint32(3)),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, 4, 3),
-			),
-			Entry("3 vCPUs and SpreadAcrossCoresThreads with spread",
-				uint32(3),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossCoresThreadsErrFmt, 3, 2),
-			),
-			Entry("3 vCPUs and SpreadAcrossCoresThreads with preferSpread",
-				uint32(3),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossCoresThreadsErrFmt, 3, 2),
-			),
-			Entry("5 vCPUs and SpreadAcrossCoresThreads with spread",
-				uint32(5),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossCoresThreadsErrFmt, 5, 2),
-			),
-			Entry("5 vCPUs and SpreadAcrossCoresThreads with preferSpread",
-				uint32(5),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossCoresThreadsErrFmt, 5, 2),
-			),
-			Entry("5 vCPUs, SpreadAcrossSocketsCoresThreads and default SocketCoreRatio of 2 with spread",
-				uint32(5),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossSocketsCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresThreadsErrFmt, 5, 2, 2),
-			),
-			Entry("5 vCPUs, SpreadAcrossSocketsCoresThreads and default SocketCoreRatio of 2 with preferSpread",
-				uint32(5),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossSocketsCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresThreadsErrFmt, 5, 2, 2),
-			),
-			Entry("6 vCPUs, SpreadAcrossSocketsCoresThreads and SocketCoreRatio via PreferSpreadSocketToCoreRatio of 4 with spread",
-				uint32(6),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferSpreadSocketToCoreRatio: uint32(4),
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossSocketsCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresThreadsErrFmt, 6, 2, 4),
-			),
-			Entry("6 vCPUs, SpreadAcrossSocketsCoresThreads and SocketCoreRatio via PreferSpreadSocketToCoreRatio of 4 with preferSpread",
-				uint32(6),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferSpreadSocketToCoreRatio: uint32(4),
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossSocketsCoresThreads),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresThreadsErrFmt, 6, 2, 4),
-			),
-			Entry("6 vCPUs, SpreadAcrossSocketsCoresThreads and SocketCoreRatio via SpreadOptions of 4 with spread",
-				uint32(6),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.Spread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossSocketsCoresThreads),
-							Ratio:  pointer.P(uint32(4)),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresThreadsErrFmt, 6, 2, 4),
-			),
-			Entry("6 vCPUs, SpreadAcrossSocketsCoresThreads and SocketCoreRatio via SpreadOptions of 4 with preferSpread",
-				uint32(6),
-				instancetypev1beta1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1beta1.CPUPreferences{
-						PreferredCPUTopology: pointer.P(instancetypev1beta1.DeprecatedPreferSpread),
-						SpreadOptions: &instancetypev1beta1.SpreadOptions{
-							Across: pointer.P(instancetypev1beta1.SpreadAcrossSocketsCoresThreads),
-							Ratio:  pointer.P(uint32(4)),
-						},
-					},
-				},
-				fmt.Sprintf(spreadAcrossSocketsCoresThreadsErrFmt, 6, 2, 4),
-			),
-		)
-
-		DescribeTable("should admit VM with preference using preferSpread and without instancetype", func(preferredCPUTopology instancetypev1beta1.PreferredCPUTopology) {
-			vm.Spec.Instancetype = nil
-
-			testPreference.Spec.CPU.PreferredCPUTopology = pointer.P(preferredCPUTopology)
-
-			_, err := virtClient.VirtualMachinePreference(vm.Namespace).Update(context.Background(), testPreference, metav1.UpdateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeTrue())
-		},
-			Entry("with spread", instancetypev1beta1.Spread),
-			Entry("with preferSpread", instancetypev1beta1.DeprecatedPreferSpread),
-		)
 	})
 
 	Context("Live update", func() {
@@ -1890,6 +1586,36 @@ var _ = Describe("Validating VM Admitter", func() {
 		Expect(resp.Result.Details.Causes[0].Type).To(Equal(metav1.CauseTypeFieldValueNotSupported))
 		Expect(resp.Result.Details.Causes[0].Message).To(Equal(fgMessage))
 	})
+
+	Context("run strategy", func() {
+		AfterEach(func() {
+			disableFeatureGates()
+		})
+
+		DescribeTable("validate should", func(runStrategy v1.VirtualMachineRunStrategy, featureGate string, accepted bool) {
+			vmi := api.NewMinimalVMI("testvmi")
+			vm := &v1.VirtualMachine{
+				Spec: v1.VirtualMachineSpec{
+					RunStrategy: &runStrategy,
+					Template: &v1.VirtualMachineInstanceTemplateSpec{
+						Spec: vmi.Spec,
+					},
+				},
+			}
+			enableFeatureGate(featureGate)
+			resp := admitVm(vmsAdmitter, vm)
+			Expect(resp.Allowed).To(Equal(accepted))
+		},
+			Entry("allow runstrategy halted", v1.RunStrategyHalted, "", true),
+			Entry("allow runstrategy manual", v1.RunStrategyManual, "", true),
+			Entry("allow runstrategy always", v1.RunStrategyAlways, "", true),
+			Entry("allow runstrategy rerun on failure", v1.RunStrategyRerunOnFailure, "", true),
+			Entry("allow runstrategy once", v1.RunStrategyOnce, "", true),
+			Entry("allow runstrategy wait as receiver", v1.RunStrategyWaitAsReceiver, featuregate.DecentralizedLiveMigration, true),
+			Entry("reject runstrategy wait as receiver, if feature gate not enabled", v1.RunStrategyWaitAsReceiver, "", false),
+			Entry("reject invalid runstrategy", v1.VirtualMachineRunStrategy("invalid"), "", false),
+		)
+	})
 })
 
 func admitVm(admitter *VMsAdmitter, vm *v1.VirtualMachine) *admissionv1.AdmissionResponse {
