@@ -24,6 +24,7 @@ var _ = Describe("Container spec renderer", func() {
 		containerName = "exampleContainer"
 		img           = "megaimage2000"
 		pullPolicy    = k8sv1.PullAlways
+		nonRootUser   = 207
 	)
 
 	Context("without any options", func() {
@@ -32,21 +33,12 @@ var _ = Describe("Container spec renderer", func() {
 		})
 
 		It("should have the unprivileged root user security context", func() {
-			Expect(specRenderer.Render(exampleCommand)).Should(
-				Equal(
-					k8sv1.Container{
-						Name:            containerName,
-						Image:           img,
-						Command:         exampleCommand,
-						ImagePullPolicy: pullPolicy,
-						SecurityContext: unprivilegedRootUserSecurityContext(),
-					}))
+			Expect(specRenderer.Render(exampleCommand).SecurityContext).Should(
+				Equal(unprivilegedRootUserSecurityContext()))
 		})
 	})
 
 	Context("with non root user option", func() {
-		const nonRootUser = 207
-
 		BeforeEach(func() {
 			specRenderer = NewContainerSpecRenderer(containerName, img, pullPolicy, WithNonRoot(nonRootUser))
 		})
@@ -82,6 +74,11 @@ var _ = Describe("Container spec renderer", func() {
 				Equal(privilegedRootUserSecurityContext()),
 			)
 		})
+
+		It("should set allowPrivilegeEscalation to true when non root", func() {
+			specRenderer = NewContainerSpecRenderer(containerName, img, pullPolicy, WithPrivileged(), WithNonRoot(nonRootUser))
+			Expect(*specRenderer.Render(exampleCommand).SecurityContext.AllowPrivilegeEscalation).Should(BeTrue())
+		})
 	})
 
 	Context("vmi capabilities", func() {
@@ -118,7 +115,7 @@ var _ = Describe("Container spec renderer", func() {
 
 		Context("a VMI belonging to a non root user", func() {
 			BeforeEach(func() {
-				const nonRootUser = 207
+
 				specRenderer = NewContainerSpecRenderer(
 					containerName,
 					img,
