@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2017 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -27,9 +27,9 @@ import (
 	"sync"
 	"time"
 
-	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	"go.uber.org/mock/gomock"
 
 	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/watch"
@@ -43,12 +43,6 @@ import (
 	cmdserver "kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/cmd-server"
 )
 
-func clearGhostRecordCache() {
-	ghostRecordGlobalMutex.Lock()
-	defer ghostRecordGlobalMutex.Unlock()
-	ghostRecordGlobalCache = make(map[string]ghostRecord)
-}
-
 var _ = Describe("Domain informer", func() {
 	var shareDir string
 	var podsDir string
@@ -60,6 +54,7 @@ var _ = Describe("Domain informer", func() {
 	var domainManager *virtwrap.MockDomainManager
 	var socketPath string
 	var resyncPeriod int
+	var ghostRecordStore *GhostRecordStore
 
 	podUID := "1234"
 
@@ -78,7 +73,7 @@ var _ = Describe("Domain informer", func() {
 		ghostCacheDir, err = os.MkdirTemp("", "")
 		Expect(err).ToNot(HaveOccurred())
 
-		InitializeGhostRecordCache(ghostCacheDir)
+		ghostRecordStore = InitializeGhostRecordCache(NewIterableCheckpointManager(ghostCacheDir))
 
 		cmdclient.SetPodsBaseDir(podsDir)
 
@@ -98,7 +93,6 @@ var _ = Describe("Domain informer", func() {
 		os.RemoveAll(shareDir)
 		os.RemoveAll(podsDir)
 		os.RemoveAll(ghostCacheDir)
-		DeleteGhostRecord("test", "test")
 	})
 
 	verifyObj := func(key string, domain *api.Domain, g Gomega) {
@@ -118,66 +112,59 @@ var _ = Describe("Domain informer", func() {
 
 	Context("with ghost record cache", func() {
 		It("Should be able to retrieve uid", func() {
-			err := AddGhostRecord("test1-namespace", "test1", "somefile1", "1234-1")
+			err := ghostRecordStore.Add("test1-namespace", "test1", "somefile1", "1234-1")
 			Expect(err).ToNot(HaveOccurred())
 
-			uid := LastKnownUIDFromGhostRecordCache("test1-namespace/test1")
+			uid := ghostRecordStore.LastKnownUID("test1-namespace/test1")
 			Expect(string(uid)).To(Equal("1234-1"))
-
 		})
 
 		It("Should find ghost record by socket ", func() {
-			err := AddGhostRecord("test1-namespace", "test1", "somefile1", "1234-1")
+			err := ghostRecordStore.Add("test1-namespace", "test1", "somefile1", "1234-1")
 			Expect(err).ToNot(HaveOccurred())
 
-			record, exists := findGhostRecordBySocket("somefile1")
+			record, exists := ghostRecordStore.findBySocket("somefile1")
 			Expect(exists).To(BeTrue())
 			Expect(record.Name).To(Equal("test1"))
 
-			record, exists = findGhostRecordBySocket("does-not-exist")
+			record, exists = ghostRecordStore.findBySocket("does-not-exist")
 			Expect(exists).To(BeFalse())
 		})
 
 		It("Should initialize cache from disk", func() {
-			err := AddGhostRecord("test1-namespace", "test1", "somefile1", "1234-1")
+			err := ghostRecordStore.Add("test1-namespace", "test1", "somefile1", "1234-1")
 			Expect(err).ToNot(HaveOccurred())
-			err = AddGhostRecord("test2-namespace", "test2", "somefile2", "1234-2")
+			err = ghostRecordStore.Add("test2-namespace", "test2", "somefile2", "1234-2")
 			Expect(err).ToNot(HaveOccurred())
 
-			clearGhostRecordCache()
+			ghostRecordStore = InitializeGhostRecordCache(NewIterableCheckpointManager(ghostCacheDir))
 
-			_, exists := ghostRecordGlobalCache["test1-namespace/test1"]
-			Expect(exists).To(BeFalse())
-
-			err = InitializeGhostRecordCache(ghostCacheDir)
-			Expect(err).ToNot(HaveOccurred())
-
-			record, exists := ghostRecordGlobalCache["test1-namespace/test1"]
+			record, exists := ghostRecordStore.cache["test1-namespace/test1"]
 			Expect(exists).To(BeTrue())
 			Expect(string(record.UID)).To(Equal("1234-1"))
 			Expect(record.SocketFile).To(Equal("somefile1"))
 
-			record, exists = ghostRecordGlobalCache["test2-namespace/test2"]
+			record, exists = ghostRecordStore.cache["test2-namespace/test2"]
 			Expect(exists).To(BeTrue())
 			Expect(string(record.UID)).To(Equal("1234-2"))
 			Expect(record.SocketFile).To(Equal("somefile2"))
 		})
 
 		It("Should delete ghost record from cache and disk", func() {
-			err := AddGhostRecord("test1-namespace", "test1", "somefile1", "1234-1")
+			err := ghostRecordStore.Add("test1-namespace", "test1", "somefile1", "1234-1")
 			Expect(err).ToNot(HaveOccurred())
 
-			_, exists := ghostRecordGlobalCache["test1-namespace/test1"]
+			_, exists := ghostRecordStore.cache["test1-namespace/test1"]
 			Expect(exists).To(BeTrue())
 
 			exists, err = diskutils.FileExists(filepath.Join(ghostCacheDir, "1234-1"))
 			Expect(err).ToNot(HaveOccurred())
 			Expect(exists).To(BeTrue())
 
-			err = DeleteGhostRecord("test1-namespace", "test1")
+			err = ghostRecordStore.Delete("test1-namespace", "test1")
 			Expect(err).ToNot(HaveOccurred())
 
-			_, exists = ghostRecordGlobalCache["test1-namespace/test1"]
+			_, exists = ghostRecordStore.cache["test1-namespace/test1"]
 			Expect(exists).To(BeFalse())
 
 			exists, err = diskutils.FileExists(filepath.Join(ghostCacheDir, "1234-1"))
@@ -187,16 +174,16 @@ var _ = Describe("Domain informer", func() {
 		})
 
 		It("Should reject adding a ghost record with missing data", func() {
-			err := AddGhostRecord("", "test1", "somefile1", "1234-1")
+			err := ghostRecordStore.Add("", "test1", "somefile1", "1234-1")
 			Expect(err).To(HaveOccurred())
 
-			err = AddGhostRecord("test1-namespace", "", "somefile1", "1234-1")
+			err = ghostRecordStore.Add("test1-namespace", "", "somefile1", "1234-1")
 			Expect(err).To(HaveOccurred())
 
-			err = AddGhostRecord("test1-namespace", "test1", "", "1234-1")
+			err = ghostRecordStore.Add("test1-namespace", "test1", "", "1234-1")
 			Expect(err).To(HaveOccurred())
 
-			err = AddGhostRecord("test1-namespace", "test1", "somefile1", "")
+			err = ghostRecordStore.Add("test1-namespace", "test1", "somefile1", "")
 			Expect(err).To(HaveOccurred())
 
 		})
@@ -239,7 +226,7 @@ var _ = Describe("Domain informer", func() {
 			domainManager.EXPECT().GetGuestOSInfo().Return(&api.GuestOSInfo{})
 			domainManager.EXPECT().InterfacesStatus().Return([]api.InterfaceStatus{})
 
-			err := AddGhostRecord("test1-namespace", "test1", "somefile1", "1234-1")
+			err := ghostRecordStore.Add("test1-namespace", "test1", "somefile1", "1234-1")
 			Expect(err).ToNot(HaveOccurred())
 			runCMDServer(wg, socketPath, domainManager, stopChan, nil)
 
@@ -328,7 +315,7 @@ var _ = Describe("Domain informer", func() {
 			Expect(err).ToNot(HaveOccurred())
 			f.Close()
 
-			AddGhostRecord("test", "test", socketPath, "1234")
+			ghostRecordStore.Add("test", "test", socketPath, "1234")
 
 			d := &domainWatcher{
 				backgroundWatcherStarted: false,
@@ -373,7 +360,7 @@ var _ = Describe("Domain informer", func() {
 				}
 			}()
 
-			err = AddGhostRecord("test", "test", socketPath, "1234")
+			err = ghostRecordStore.Add("test", "test", socketPath, "1234")
 			Expect(err).ToNot(HaveOccurred())
 
 			d := &domainWatcher{
@@ -450,7 +437,7 @@ var _ = Describe("Domain informer", func() {
 
 var _ = Describe("Iterable checkpoint manager", func() {
 	It("should list all keys", func() {
-		icp := newIterableCheckpointManager(GinkgoT().TempDir())
+		icp := NewIterableCheckpointManager(GinkgoT().TempDir())
 
 		Expect(icp.Store("one", "hi")).To(Succeed())
 		Expect(icp.Store("two", "hey")).To(Succeed())
