@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2019 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -138,13 +138,13 @@ func newManagerFromPid(pid int, deviceRules []*devices.Rule) (manager Manager, e
 	return manager, err
 }
 
-func NewManagerFromVM(vmi *v1.VirtualMachineInstance) (Manager, error) {
+func NewManagerFromVM(vmi *v1.VirtualMachineInstance, host string) (Manager, error) {
 	isolationRes, err := detectVMIsolation(vmi, "")
 	if err != nil {
 		return nil, err
 	}
 
-	vmiDeviceRules, err := generateDeviceRulesForVMI(vmi, isolationRes)
+	vmiDeviceRules, err := generateDeviceRulesForVMI(vmi, isolationRes, host)
 	if err != nil {
 		return nil, err
 	}
