@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2017 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -34,6 +34,7 @@ import (
 	"net/rpc"
 	"os"
 	"path/filepath"
+	"strings"
 	"syscall"
 	"time"
 
@@ -112,6 +113,7 @@ type LauncherClient interface {
 	GetLaunchMeasurement(*v1.VirtualMachineInstance) (*v1.SEVMeasurementInfo, error)
 	InjectLaunchSecret(*v1.VirtualMachineInstance, *v1.SEVSecretOptions) error
 	SyncVirtualMachineMemory(vmi *v1.VirtualMachineInstance, options *cmdv1.VirtualMachineOptions) error
+	GetDomainDirtyRateStats() (dirtyRateMbps int64, err error)
 }
 
 type VirtLauncherClient struct {
@@ -195,26 +197,30 @@ func SocketFilePathOnHost(podUID string) string {
 }
 
 // gets the cmd socket for a VMI
-func FindPodDirOnHost(vmi *v1.VirtualMachineInstance) (string, error) {
+func FindPodDirOnHost(vmi *v1.VirtualMachineInstance, socketDirFunc func(string) string) (string, error) {
 
+	var socketDirsForErrorReporting []string
 	// It is possible for multiple pods to be active on a single VMI
 	// during migrations. This loop will discover the active pod on
 	// this particular local node if it exists. A active pod not
 	// running on this node will not have a kubelet pods directory,
 	// so it will not be found.
 	for podUID := range vmi.Status.ActivePods {
-		socketPodDir := SocketDirectoryOnHost(string(podUID))
+		socketPodDir := socketDirFunc(string(podUID))
+		socketDirsForErrorReporting = append(socketDirsForErrorReporting, socketPodDir)
 		exists, _ := diskutils.FileExists(socketPodDir)
 		if exists {
 			return socketPodDir, nil
 		}
 	}
 
-	return "", fmt.Errorf("No command socketdir for vmi %s", vmi.UID)
+	return "", fmt.Errorf("No pod dir found for vmi %s in paths [%s]", vmi.UID, strings.Join(socketDirsForErrorReporting, ","))
 }
 
-// gets the cmd socket for a VMI
-func FindSocketOnHost(vmi *v1.VirtualMachineInstance) (string, error) {
+// Finds exactly one socket on a host based on the hostname.
+// A empty hostname is wildcard.
+// Returns error otherwise.
+func FindSocketOnHost(vmi *v1.VirtualMachineInstance, host string) (string, error) {
 	socketsFound := 0
 	foundSocket := ""
 	// It is possible for multiple pods to be active on a single VMI
@@ -222,7 +228,10 @@ func FindSocketOnHost(vmi *v1.VirtualMachineInstance) (string, error) {
 	// this particular local node if it exists. A active pod not
 	// running on this node will not have a kubelet pods directory,
 	// so it will not be found.
-	for podUID := range vmi.Status.ActivePods {
+	for podUID, phost := range vmi.Status.ActivePods {
+		if host != "" && host != phost {
+			continue
+		}
 		socket := SocketFilePathOnHost(string(podUID))
 		exists, _ := diskutils.FileExists(socket)
 		if exists {
@@ -240,6 +249,12 @@ func FindSocketOnHost(vmi *v1.VirtualMachineInstance) (string, error) {
 	return "", fmt.Errorf("No command socket found for vmi %s", vmi.UID)
 }
 
+// Finds exactly one socket on a host based on the NODE_NAME env. Returns error otherwise.
+func FindSocket(vmi *v1.VirtualMachineInstance) (string, error) {
+	host, _ := os.LookupEnv("NODE_NAME")
+	return FindSocketOnHost(vmi, host)
+}
+
 func SocketOnGuest() string {
 	sockFile := StandardLauncherSocketFileName
 	return filepath.Join(SocketsDirectory(), sockFile)
@@ -319,6 +334,7 @@ func (c *VirtLauncherClient) genericSendVMICmd(cmdName string,
 	err = handleError(err, cmdName, response)
 	return err
 }
+
 func IsUnimplemented(err error) bool {
 	if grpcStatus, ok := status.FromError(err); ok {
 		if grpcStatus.Code() == codes.Unimplemented {
@@ -517,7 +533,7 @@ func (c *VirtLauncherClient) GetDomain() (*api.Domain, bool, error) {
 		response = domainResponse.Response
 	}
 
-	if err = handleError(err, "GetDomain", response); err != nil {
+	if err = handleError(err, "GetDomain", response); err != nil || domainResponse == nil {
 		return domain, exists, err
 	}
 
@@ -531,6 +547,24 @@ func (c *VirtLauncherClient) GetDomain() (*api.Domain, bool, error) {
 	return domain, exists, nil
 }
 
+func (c *VirtLauncherClient) GetDomainDirtyRateStats() (dirtyRateMbps int64, err error) {
+	request := &cmdv1.EmptyRequest{}
+	ctx, cancel := context.WithTimeout(context.Background(), longTimeout)
+	defer cancel()
+
+	domainDirtyRateStatsResponse, err := c.v1client.GetDomainDirtyRateStats(ctx, request)
+	var response *cmdv1.Response
+	if domainDirtyRateStatsResponse != nil {
+		response = domainDirtyRateStatsResponse.Response
+	}
+
+	if err = handleError(err, "GetDomainDirtyRateStats", response); err != nil || domainDirtyRateStatsResponse == nil {
+		return -1, err
+	}
+
+	return domainDirtyRateStatsResponse.DirtyRateMbs, nil
+}
+
 func (c *VirtLauncherClient) GetQemuVersion() (string, error) {
 	request := &cmdv1.EmptyRequest{}
 	ctx, cancel := context.WithTimeout(context.Background(), shortTimeout)
@@ -567,7 +601,7 @@ func (c *VirtLauncherClient) GetDomainStats() (*stats.DomainStats, bool, error)
 		response = domainStatsResponse.Response
 	}
 
-	if err = handleError(err, "GetDomainStats", response); err != nil {
+	if err = handleError(err, "GetDomainStats", response); err != nil || domainStatsResponse == nil {
 		return stats, exists, err
 	}
 
@@ -605,7 +639,7 @@ func (c *VirtLauncherClient) GetGuestInfo() (*v1.VirtualMachineInstanceGuestAgen
 		response = gaRespose.Response
 	}
 
-	if err = handleError(err, "GetGuestInfo", response); err != nil {
+	if err = handleError(err, "GetGuestInfo", response); err != nil || gaRespose == nil {
 		return guestInfo, err
 	}
 
@@ -620,7 +654,7 @@ func (c *VirtLauncherClient) GetGuestInfo() (*v1.VirtualMachineInstanceGuestAgen
 
 // GetUsers returns the list of the active users on the guest machine
 func (c *VirtLauncherClient) GetUsers() (v1.VirtualMachineInstanceGuestOSUserList, error) {
-	userList := []v1.VirtualMachineInstanceGuestOSUser{}
+	var userList []v1.VirtualMachineInstanceGuestOSUser
 
 	request := &cmdv1.EmptyRequest{}
 	ctx, cancel := context.WithTimeout(context.Background(), shortTimeout)
@@ -632,7 +666,7 @@ func (c *VirtLauncherClient) GetUsers() (v1.VirtualMachineInstanceGuestOSUserLis
 		response = uResponse.Response
 	}
 
-	if err = handleError(err, "GetUsers", response); err != nil {
+	if err = handleError(err, "GetUsers", response); err != nil || uResponse == nil {
 		return v1.VirtualMachineInstanceGuestOSUserList{}, err
 	}
 
@@ -652,7 +686,7 @@ func (c *VirtLauncherClient) GetUsers() (v1.VirtualMachineInstanceGuestOSUserLis
 
 // GetFilesystems returns the list of active filesystems on the guest machine
 func (c *VirtLauncherClient) GetFilesystems() (v1.VirtualMachineInstanceFileSystemList, error) {
-	fsList := []v1.VirtualMachineInstanceFileSystem{}
+	var fsList []v1.VirtualMachineInstanceFileSystem
 
 	request := &cmdv1.EmptyRequest{}
 	ctx, cancel := context.WithTimeout(context.Background(), shortTimeout)
@@ -664,7 +698,7 @@ func (c *VirtLauncherClient) GetFilesystems() (v1.VirtualMachineInstanceFileSyst
 		response = fsResponse.Response
 	}
 
-	if err = handleError(err, "GetFilesystems", response); err != nil {
+	if err = handleError(err, "GetFilesystems", response); err != nil || fsResponse == nil {
 		return v1.VirtualMachineInstanceFileSystemList{}, err
 	}
 
