@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2020 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -25,9 +25,9 @@ import (
 	"os"
 	"path/filepath"
 
-	gomock "github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	gomock "go.uber.org/mock/gomock"
 
 	"google.golang.org/grpc"
 	"k8s.io/apimachinery/pkg/types"
@@ -57,6 +57,7 @@ var _ = Describe("Virt remote commands", func() {
 		vmi.Status = v1.VirtualMachineInstanceStatus{
 			ActivePods: map[types.UID]string{
 				types.UID(podUID): host,
+				types.UID("NA"):   host,
 			},
 		}
 
@@ -87,7 +88,7 @@ var _ = Describe("Virt remote commands", func() {
 
 	Context("client", func() {
 		It("socket from UID", func() {
-			sock, err := FindSocketOnHost(vmi)
+			sock, err := FindSocket(vmi)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(sock).To(Equal(podSocketFile))
 
@@ -107,7 +108,7 @@ var _ = Describe("Virt remote commands", func() {
 		})
 
 		It("Detect unresponsive socket", func() {
-			sock, err := FindSocketOnHost(vmi)
+			sock, err := FindSocket(vmi)
 			Expect(err).ToNot(HaveOccurred())
 
 			Expect(IsSocketUnresponsive(sock)).To(BeFalse())
@@ -129,6 +130,18 @@ var _ = Describe("Virt remote commands", func() {
 			Expect(IsSocketUnresponsive(sock)).To(BeTrue())
 		})
 
+		It("socket dir from UID and file path provider func", func() {
+			path, err := FindPodDirOnHost(vmi, SocketFilePathOnHost)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(path).To(Equal(podSocketFile))
+		})
+
+		It("negative test socket dir not found", func() {
+			_, err := FindPodDirOnHost(vmi, func(string) string { return "no-such-dir" })
+			Expect(err).To(HaveOccurred())
+			Expect(err.Error()).To(ContainSubstring("no-such-dir"))
+		})
+
 		Context("exec", func() {
 			var (
 				mockCmdClient *cmdv1.MockCmdClient
