@@ -11,18 +11,18 @@ import (
 	"sync"
 	"time"
 
-	"kubevirt.io/kubevirt/pkg/checkpoint"
-	"kubevirt.io/kubevirt/pkg/unsafepath"
-
-	"kubevirt.io/kubevirt/pkg/safepath"
-	"kubevirt.io/kubevirt/pkg/util"
-	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
-	virt_chroot "kubevirt.io/kubevirt/pkg/virt-handler/virt-chroot"
-
 	"kubevirt.io/client-go/log"
 
+	"kubevirt.io/kubevirt/pkg/checkpoint"
 	containerdisk "kubevirt.io/kubevirt/pkg/container-disk"
+	diskutils "kubevirt.io/kubevirt/pkg/ephemeral-disk-utils"
+	"kubevirt.io/kubevirt/pkg/safepath"
+	"kubevirt.io/kubevirt/pkg/unsafepath"
+	"kubevirt.io/kubevirt/pkg/util"
+	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+	cmdclient "kubevirt.io/kubevirt/pkg/virt-handler/cmd-client"
 	"kubevirt.io/kubevirt/pkg/virt-handler/isolation"
+	virt_chroot "kubevirt.io/kubevirt/pkg/virt-handler/virt-chroot"
 
 	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/types"
@@ -36,8 +36,7 @@ const (
 )
 
 var (
-	ErrChecksumMissing   = errors.New("missing checksum")
-	ErrChecksumMismatch  = errors.New("checksum mismatch")
+	ErrWaitingForDisks   = errors.New("waiting for containerdisks")
 	ErrDiskContainerGone = errors.New("disk container is gone")
 )
 
@@ -49,6 +48,7 @@ type mounter struct {
 	mountRecords               map[types.UID]*vmiMountTargetRecord
 	mountRecordsLock           sync.Mutex
 	suppressWarningTimeout     time.Duration
+	needsBindMountFunc         needsBindMountFunc
 	socketPathGetter           containerdisk.SocketPathGetter
 	kernelBootSocketPathGetter containerdisk.KernelBootSocketPathGetter
 	clusterConfig              *virtconfig.ClusterConfig
@@ -57,8 +57,12 @@ type mounter struct {
 
 type Mounter interface {
 	ContainerDisksReady(vmi *v1.VirtualMachineInstance, notInitializedSince time.Time) (bool, error)
-	MountAndVerify(vmi *v1.VirtualMachineInstance) (map[string]*containerdisk.DiskInfo, error)
+	MountAndVerify(vmi *v1.VirtualMachineInstance) error
 	Unmount(vmi *v1.VirtualMachineInstance) error
+	// ComputeChecksums method, along with the code added in this commit, can be removed after the 1.7 release.
+	// By then, we can be sure that during upgrades older versions of virt-handler no longer expect the checksum
+	// in the VMI status.
+	// Therefore, it will no longer be necessary to include this information in the VMI status.
 	ComputeChecksums(vmi *v1.VirtualMachineInstance) (*DiskChecksums, error)
 }
 
@@ -93,6 +97,7 @@ func NewMounter(isoDetector isolation.PodIsolationDetector, mountStateDir string
 		podIsolationDetector:       isoDetector,
 		checkpointManager:          checkpoint.NewSimpleCheckpointManager(mountStateDir),
 		suppressWarningTimeout:     1 * time.Minute,
+		needsBindMountFunc:         newNeedsBindMountFunc(""),
 		socketPathGetter:           containerdisk.NewSocketPathGetter(""),
 		kernelBootSocketPathGetter: containerdisk.NewKernelBootSocketPathGetter(""),
 		clusterConfig:              clusterConfig,
@@ -219,31 +224,39 @@ func (m *mounter) setAddMountTargetRecordHelper(vmi *v1.VirtualMachineInstance,
 
 // Mount takes a vmi and mounts all container disks of the VMI, so that they are visible for the qemu process.
 // Additionally qcow2 images are validated if "verify" is true. The validation happens with rlimits set, to avoid DOS.
-func (m *mounter) MountAndVerify(vmi *v1.VirtualMachineInstance) (map[string]*containerdisk.DiskInfo, error) {
-	record := vmiMountTargetRecord{}
-	disksInfo := map[string]*containerdisk.DiskInfo{}
+func (m *mounter) MountAndVerify(vmi *v1.VirtualMachineInstance) error {
+	if m.clusterConfig.ImageVolumeEnabled() {
+		bindMountNeeded, err := m.needsBindMountFunc(vmi)
+		if err != nil {
+			return fmt.Errorf("fail to detect if bind mount needed for vmi: %s in namespace: %v. err: %v", vmi.Name, vmi.Namespace, err)
+		}
+		if !bindMountNeeded {
+			return nil
+		}
+	}
 
+	record := vmiMountTargetRecord{}
 	for i, volume := range vmi.Spec.Volumes {
 		if volume.ContainerDisk != nil {
 			diskTargetDir, err := containerdisk.GetDiskTargetDirFromHostView(vmi)
 			if err != nil {
-				return nil, err
+				return err
 			}
 			diskName := containerdisk.GetDiskTargetName(i)
 			// If diskName is a symlink it will fail if the target exists.
 			if err := safepath.TouchAtNoFollow(diskTargetDir, diskName, os.ModePerm); err != nil {
 				if !os.IsExist(err) {
-					return nil, fmt.Errorf("failed to create mount point target: %v", err)
+					return fmt.Errorf("failed to create mount point target: %v", err)
 				}
 			}
 			targetFile, err := safepath.JoinNoFollow(diskTargetDir, diskName)
 			if err != nil {
-				return nil, err
+				return err
 			}
 
 			sock, err := m.socketPathGetter(vmi, i)
 			if err != nil {
-				return nil, err
+				return err
 			}
 
 			record.MountTargetEntries = append(record.MountTargetEntries, vmiMountTargetEntry{
@@ -256,59 +269,45 @@ func (m *mounter) MountAndVerify(vmi *v1.VirtualMachineInstance) (map[string]*co
 	if len(record.MountTargetEntries) > 0 {
 		err := m.setMountTargetRecord(vmi, &record)
 		if err != nil {
-			return nil, err
+			return err
 		}
 	}
 
-	vmiRes, err := m.podIsolationDetector.Detect(vmi)
-	if err != nil {
-		return nil, fmt.Errorf("failed to detect VMI pod: %v", err)
-	}
-
 	for i, volume := range vmi.Spec.Volumes {
 		if volume.ContainerDisk != nil {
 			diskTargetDir, err := containerdisk.GetDiskTargetDirFromHostView(vmi)
 			if err != nil {
-				return nil, err
+				return err
 			}
 			diskName := containerdisk.GetDiskTargetName(i)
 			targetFile, err := safepath.JoinNoFollow(diskTargetDir, diskName)
 			if err != nil {
-				return nil, err
+				return err
 			}
 
 			if isMounted, err := isolation.IsMounted(targetFile); err != nil {
-				return nil, fmt.Errorf("failed to determine if %s is already mounted: %v", targetFile, err)
+				return fmt.Errorf("failed to determine if %s is already mounted: %v", targetFile, err)
 			} else if !isMounted {
 
 				sourceFile, err := m.getContainerDiskPath(vmi, &volume, i)
 				if err != nil {
-					return nil, fmt.Errorf("failed to find a sourceFile in containerDisk %v: %v", volume.Name, err)
+					return fmt.Errorf("failed to find a sourceFile in containerDisk %v: %v", volume.Name, err)
 				}
 
 				log.DefaultLogger().Object(vmi).Infof("Bind mounting container disk at %s to %s", sourceFile, targetFile)
 				out, err := virt_chroot.MountChroot(sourceFile, targetFile, true).CombinedOutput()
 				if err != nil {
-					return nil, fmt.Errorf("failed to bindmount containerDisk %v: %v : %v", volume.Name, string(out), err)
+					return fmt.Errorf("failed to bindmount containerDisk %v: %v : %v", volume.Name, string(out), err)
 				}
 			}
-
-			imageInfo, err := isolation.GetImageInfo(containerdisk.GetDiskTargetPathFromLauncherView(i), vmiRes, m.clusterConfig.GetDiskVerification())
-			if err != nil {
-				return nil, fmt.Errorf("failed to get image info: %v", err)
-			}
-			if err := containerdisk.VerifyImage(imageInfo); err != nil {
-				return nil, fmt.Errorf("invalid image in containerDisk %v: %v", volume.Name, err)
-			}
-			disksInfo[volume.Name] = imageInfo
 		}
 	}
-	err = m.mountKernelArtifacts(vmi, true)
+	err := m.mountKernelArtifacts(vmi, true)
 	if err != nil {
-		return nil, fmt.Errorf("error mounting kernel artifacts: %v", err)
+		return fmt.Errorf("error mounting kernel artifacts: %v", err)
 	}
 
-	return disksInfo, nil
+	return nil
 }
 
 // Unmount unmounts all container disks of a given VMI.
@@ -347,7 +346,7 @@ func (m *mounter) Unmount(vmi *v1.VirtualMachineInstance) error {
 			return fmt.Errorf(failedCheckMountPointFmt, file, err)
 		} else if mounted {
 			log.DefaultLogger().Object(vmi).Infof("unmounting container disk at path %s", file)
-			// #nosec No risk for attacket injection. Parameters are predefined strings
+			// #nosec No risk for attacker injection. Parameters are predefined strings
 			out, err := virt_chroot.UmountChroot(file.Path()).CombinedOutput()
 			if err != nil {
 				return fmt.Errorf(failedUnmountFmt, file, string(out), err)
@@ -363,6 +362,15 @@ func (m *mounter) Unmount(vmi *v1.VirtualMachineInstance) error {
 }
 
 func (m *mounter) ContainerDisksReady(vmi *v1.VirtualMachineInstance, notInitializedSince time.Time) (bool, error) {
+	if m.clusterConfig.ImageVolumeEnabled() {
+		bindMountNeeded, err := m.needsBindMountFunc(vmi)
+		if err != nil {
+			return false, fmt.Errorf("fail to detect if bind mount needed for vmi: %s in namespace: %v. err: %v", vmi.Name, vmi.Namespace, err)
+		}
+		if !bindMountNeeded {
+			return true, nil
+		}
+	}
 	for i, volume := range vmi.Spec.Volumes {
 		if volume.ContainerDisk != nil {
 			sock, err := m.socketPathGetter(vmi, i)
@@ -730,66 +738,27 @@ func (m *mounter) ComputeChecksums(vmi *v1.VirtualMachineInstance) (*DiskChecksu
 	return diskChecksums, nil
 }
 
-func compareChecksums(expectedChecksum, computedChecksum uint32) error {
-	if expectedChecksum == 0 {
-		return ErrChecksumMissing
+type needsBindMountFunc func(vmi *v1.VirtualMachineInstance) (bool, error)
+
+func newNeedsBindMountFunc(baseDir string) needsBindMountFunc {
+	return func(vmi *v1.VirtualMachineInstance) (bool, error) {
+		for podUID := range vmi.Status.ActivePods {
+			virtLauncherSocketPath := cmdclient.SocketDirectoryOnHost(string(podUID))
+			launcherSocketExists, err := diskutils.FileExists(virtLauncherSocketPath)
+			if err != nil {
+				return false, err
+			}
+			basePath := fmt.Sprintf("%s/pods/%s/containers", baseDir, string(podUID))
+			containerDiskPath := filepath.Join(basePath, "container-disk-binary")
+			containerDiskInitContainerExists, err := diskutils.FileExists(containerDiskPath)
+			if err != nil {
+				return false, err
+			}
+			// we must check for launcherSocket to make sure this isn't an old launcher that is already completed
+			if launcherSocketExists && containerDiskInitContainerExists {
+				return true, nil
+			}
+		}
+		return false, nil
 	}
-	if expectedChecksum != computedChecksum {
-		return ErrChecksumMismatch
-	}
-	// checksum ok
-	return nil
-}
-
-func VerifyChecksums(mounter Mounter, vmi *v1.VirtualMachineInstance) error {
-	diskChecksums, err := mounter.ComputeChecksums(vmi)
-	if err != nil {
-		return fmt.Errorf("failed to compute checksums: %s", err)
-	}
-
-	// verify containerdisks
-	for _, volumeStatus := range vmi.Status.VolumeStatus {
-		if volumeStatus.ContainerDiskVolume == nil {
-			continue
-		}
-
-		expectedChecksum := volumeStatus.ContainerDiskVolume.Checksum
-		computedChecksum := diskChecksums.ContainerDiskChecksums[volumeStatus.Name]
-		if err := compareChecksums(expectedChecksum, computedChecksum); err != nil {
-			return fmt.Errorf("checksum error for volume %s: %w", volumeStatus.Name, err)
-		}
-	}
-
-	// verify kernel and initrd
-	if util.HasKernelBootContainerImage(vmi) {
-		if vmi.Status.KernelBootStatus == nil {
-			return ErrChecksumMissing
-		}
-
-		if diskChecksums.KernelBootChecksum.Kernel != nil {
-			if vmi.Status.KernelBootStatus.KernelInfo == nil {
-				return fmt.Errorf("checksum missing for kernel image: %w", ErrChecksumMissing)
-			}
-
-			expectedChecksum := vmi.Status.KernelBootStatus.KernelInfo.Checksum
-			computedChecksum := *diskChecksums.KernelBootChecksum.Kernel
-			if err := compareChecksums(expectedChecksum, computedChecksum); err != nil {
-				return fmt.Errorf("checksum error for kernel image: %w", err)
-			}
-		}
-
-		if diskChecksums.KernelBootChecksum.Initrd != nil {
-			if vmi.Status.KernelBootStatus.InitrdInfo == nil {
-				return fmt.Errorf("checksum missing for initrd image: %w", ErrChecksumMissing)
-			}
-
-			expectedChecksum := vmi.Status.KernelBootStatus.InitrdInfo.Checksum
-			computedChecksum := *diskChecksums.KernelBootChecksum.Initrd
-			if err := compareChecksums(expectedChecksum, computedChecksum); err != nil {
-				return fmt.Errorf("checksum error for initrd image: %w", err)
-			}
-		}
-	}
-
-	return nil
 }
