@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -256,7 +256,6 @@ func removeSelectorSpaces(selectorName string) string {
 	typeNameStr := strings.Replace(string(selectorName), " ", "_", -1)
 	typeNameStr = strings.TrimSpace(typeNameStr)
 	return typeNameStr
-
 }
 
 func (c *DeviceController) splitPermittedDevices(devices []Device) (map[string]Device, map[string]struct{}) {
@@ -327,8 +326,8 @@ func (c *DeviceController) refreshMediatedDeviceTypes() bool {
 
 func (c *DeviceController) refreshPermittedDevices() {
 	logger := log.DefaultLogger()
-	debugDevAdded := []string{}
-	debugDevRemoved := []string{}
+	var debugDevAdded []string
+	var debugDevRemoved []string
 
 	// This function can be called multiple times in parallel, either because of multiple
 	//   informer callbacks for the same event, or because the configmap was quickly updated
