@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2017 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -64,6 +64,7 @@ type Connection interface {
 	// 1. avoid to expose to the client code the libvirt-specific return type, see docs in stats/ subpackage
 	// 2. transparently handling the addition of the memory stats, currently (libvirt 4.9) not handled by the bulk stats API
 	GetDomainStats(statsTypes libvirt.DomainStatsTypes, l *stats.DomainJobInfo, flags libvirt.ConnectGetAllDomainStatsFlags) ([]*stats.DomainStats, error)
+	GetDomainDirtyRate(calculationDuration time.Duration, flags libvirt.DomainDirtyRateCalcFlags) ([]*stats.DomainStatsDirtyRate, error)
 	GetQemuVersion() (string, error)
 	GetSEVInfo() (*api.SEVNodeParameters, error)
 }
@@ -323,8 +324,10 @@ func (l *LibvirtConnection) GetDomainStats(statsTypes libvirt.DomainStatsTypes,
 			return list, err
 		}
 
+		dirtyRateInfo := domStat.DirtyRate
+
 		stat := &stats.DomainStats{}
-		err = statsconv.Convert_libvirt_DomainStats_to_stats_DomainStats(statsconv.DomainIdentifier(domStat.Domain), &domStats[i], memStats, domInfo, devAliasMap, migrateJobInfo, stat)
+		err = statsconv.Convert_libvirt_DomainStats_to_stats_DomainStats(statsconv.DomainIdentifier(domStat.Domain), &domStats[i], memStats, domInfo, devAliasMap, migrateJobInfo, dirtyRateInfo, stat)
 		if err != nil {
 			return list, err
 		}
@@ -343,6 +346,82 @@ func (l *LibvirtConnection) GetDomainStats(statsTypes libvirt.DomainStatsTypes,
 	return list, nil
 }
 
+func (l *LibvirtConnection) GetDomainDirtyRate(calculationDuration time.Duration, flags libvirt.DomainDirtyRateCalcFlags) ([]*stats.DomainStatsDirtyRate, error) {
+	domStats, err := l.GetAllDomainStats(libvirt.DOMAIN_STATS_DIRTYRATE, libvirt.CONNECT_GET_ALL_DOMAINS_STATS_RUNNING|libvirt.CONNECT_GET_ALL_DOMAINS_STATS_PAUSED)
+	if err != nil {
+		return nil, err
+	}
+
+	// Free memory allocated for domains
+	defer func() {
+		for i := range domStats {
+			err := domStats[i].Domain.Free()
+			if err != nil {
+				log.Log.Reason(err).Warning("Error freeing a domain.")
+			}
+		}
+	}()
+
+	for i := range domStats {
+		err := domStats[i].Domain.StartDirtyRateCalc(int(calculationDuration.Seconds()), flags)
+		if err != nil {
+			log.Log.Reason(err).Warning("Can't start dirty rate calc")
+		}
+	}
+
+	// Wait for the dirty rate calculation to finish
+	time.Sleep(calculationDuration)
+
+	var dirtyRateStats []*stats.DomainStatsDirtyRate
+	getDomainStats := func() ([]*stats.DomainStatsDirtyRate, error) {
+		var dirtyRateStats []*stats.DomainStatsDirtyRate
+		for _, domStat := range domStats {
+			dirtyRateInfo := domStat.DirtyRate
+
+			// warn if dirty rate calc is not set or not finished
+			if !dirtyRateInfo.CalcStatusSet {
+				return nil, fmt.Errorf("dirty rate stats calculation status is not set")
+			} else if dirtyRateInfo.CalcStatus != int(libvirt.DOMAIN_DIRTYRATE_MEASURED) {
+				var status string
+				switch dirtyRateInfo.CalcStatus {
+				case int(libvirt.DOMAIN_DIRTYRATE_UNSTARTED):
+					status = "DOMAIN_DIRTYRATE_UNSTARTED"
+				case int(libvirt.DOMAIN_DIRTYRATE_MEASURING):
+					status = "DOMAIN_DIRTYRATE_MEASURING"
+				}
+
+				log.Log.Infof("trying to get dirty rate stats, but dirty rate calc status is not finished: %s", status)
+				return nil, fmt.Errorf("dirty calc status is %s", status)
+			} else {
+				dirtyRateStat := statsconv.Convert_libvirt_DomainStatsDirtyRate_To_stats_DomainStatsDirtyRate(dirtyRateInfo)
+				dirtyRateStats = append(dirtyRateStats, dirtyRateStat)
+			}
+		}
+		return dirtyRateStats, nil
+	}
+	retryTicker := time.NewTicker(200 * time.Millisecond)
+	retryTimeout := time.After(1 * time.Second)
+
+retryLoop:
+	for {
+		select {
+		case <-retryTicker.C:
+			dirtyRateStats, err = getDomainStats()
+			if err == nil {
+				break retryLoop
+			}
+		case <-retryTimeout:
+			break retryLoop
+		}
+	}
+
+	if err != nil || dirtyRateStats == nil {
+		return nil, fmt.Errorf("failed to get dirty rate stats: %w", err)
+	}
+
+	return dirtyRateStats, nil
+}
+
 func (l *LibvirtConnection) GetSEVInfo() (*api.SEVNodeParameters, error) {
 	const flags = uint32(0)
 	params, err := l.Connect.GetSEVInfo(flags)
@@ -525,8 +604,10 @@ type VirDomain interface {
 	MemoryStats(nrStats uint32, flags uint32) ([]libvirt.DomainMemoryStat, error)
 	GetJobStats(flags libvirt.DomainGetJobStatsFlags) (*libvirt.DomainJobInfo, error)
 	GetJobInfo() (*libvirt.DomainJobInfo, error)
+	GetGuestInfo(types libvirt.DomainGuestInfoTypes, flags uint32) (*libvirt.DomainGuestInfo, error)
 	GetDiskErrors(flags uint32) ([]libvirt.DomainDiskError, error)
 	SetTime(secs int64, nsecs uint, flags libvirt.DomainSetTimeFlags) error
+	SetUserPassword(user string, password string, flags libvirt.DomainSetUserPasswordFlags) error
 	AuthorizedSSHKeysSet(user string, keys []string, flags libvirt.DomainAuthorizedSSHKeysFlags) error
 	AbortJob() error
 	Free() error
@@ -536,6 +617,8 @@ type VirDomain interface {
 	SetVcpusFlags(vcpu uint, flags libvirt.DomainVcpuFlags) error
 	GetLaunchSecurityInfo(flags uint32) (*libvirt.DomainLaunchSecurityParameters, error)
 	SetLaunchSecurityState(params *libvirt.DomainLaunchSecurityStateParameters, flags uint32) error
+	FSFreeze(mounts []string, flags uint32) error
+	FSThaw(mounts []string, flags uint32) error
 }
 
 func NewConnection(uri string, user string, pass string, checkInterval time.Duration) (Connection, error) {
