@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -70,6 +70,10 @@ const (
 	UsePopulatorAnnotation          = "cdi.kubevirt.io/storage.usePopulator"
 	PVCPrimeNameAnnotation          = "cdi.kubevirt.io/storage.populator.pvcPrime"
 
+	// labelApplyStorageProfile is a label used by the CDI mutating webhook
+	// to modify the PVC according to the storage profile.
+	labelApplyStorageProfile = "cdi.kubevirt.io/applyStorageProfile"
+
 	uploadReadyWaitInterval = 2 * time.Second
 
 	processingWaitInterval = 2 * time.Second
@@ -757,11 +761,21 @@ func (c *command) createUploadPVC() (*v1.PersistentVolumeClaim, error) {
 		contentTypeAnnotation:   contentType,
 	}
 
+	labels := map[string]string{
+		// Adding this label to allow the PVC to be processed by the CDI WebhookPvcRendering mutating webhook,
+		// which must be enabled in the CDI CR via feature gate.
+		// This mutating webhook processes the PVC based on its associated StorageProfile.
+		// For example, a profile can define a minimum supported volume size via the annotation:
+		// cdi.kubevirt.io/minimumSupportedPvcSize: 4Gi
+		labelApplyStorageProfile: "true",
+	}
+
 	if c.forceBind {
 		annotations[forceImmediateBindingAnnotation] = ""
 	}
 
 	pvc.ObjectMeta.Annotations = annotations
+	pvc.ObjectMeta.Labels = labels
 	c.setDefaultInstancetypeLabels(&pvc.ObjectMeta)
 
 	pvc, err = c.client.CoreV1().PersistentVolumeClaims(c.namespace).Create(context.Background(), pvc, metav1.CreateOptions{})
