@@ -4,6 +4,7 @@ package ssh
 
 import (
 	"fmt"
+	"io"
 
 	"github.com/spf13/pflag"
 	"kubevirt.io/client-go/kubecli"
@@ -18,6 +19,6 @@ func addAdditionalCommandlineArgs(flagset *pflag.FlagSet, opts *SSHOptions) {
 		fmt.Sprintf(`--%s="-o StrictHostKeyChecking=no" : Additional options to be passed to the local ssh`, additionalOpts))
 }
 
-func (o *SSH) nativeSSH(_, _, _ string, _ kubecli.KubevirtClient) error {
+func (o *SSH) nativeSSH(_, _, _ string, _ kubecli.KubevirtClient, _ io.Reader, _, _ io.Writer) error {
 	panic("Native SSH is unsupported in this build!")
 }
