@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2021 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -138,7 +138,7 @@ func (o *SSH) Run(cmd *cobra.Command, args []string) error {
 		return RunLocalClient(kind, namespace, name, &o.options, clientArgs)
 	}
 
-	return o.nativeSSH(kind, namespace, name, client)
+	return o.nativeSSH(kind, namespace, name, client, cmd.InOrStdin(), cmd.OutOrStdout(), cmd.ErrOrStderr())
 }
 
 func PrepareCommand(cmd *cobra.Command, fallbackNamespace string, opts *SSHOptions, args []string) (kind, namespace, name string, err error) {
@@ -164,7 +164,7 @@ func usage() string {
   {{ProgramName}} ssh jdoe@vmi/testvmi [--%s]
 
   # Connect to 'testvm' in 'mynamespace' namespace
-  {{ProgramName}} ssh jdoe@vm/testvm.mynamespace [--%s]
+  {{ProgramName}} ssh jdoe@vm/testvm/mynamespace [--%s]
 
   # Specify a username and namespace:
   {{ProgramName}} ssh --namespace=mynamespace --%s=jdoe vmi/testvmi`,
@@ -188,9 +188,9 @@ func defaultUsername() string {
 	return ""
 }
 
-// ParseTarget SSH Target argument supporting the form of username@vmi/name.namespace (or simpler)
+// ParseTarget SSH Target argument supporting the form of [username@]type/name[/namespace]
+// or the legacy form of [username@]type/name.namespace
 func ParseTarget(arg string) (string, string, string, string, error) {
-	kind := "vmi"
 	username := ""
 
 	usernameAndTarget := strings.Split(arg, "@")
@@ -207,5 +207,9 @@ func ParseTarget(arg string) (string, string, string, string, error) {
 	}
 
 	kind, namespace, name, err := portforward.ParseTarget(arg)
+	if err != nil {
+		return "", "", "", "", err
+	}
+
 	return kind, namespace, name, username, err
 }
