@@ -74,12 +74,6 @@ func SetDefaults_DiskDevice(obj *DiskDevice) {
 	}
 }
 
-func SetDefaults_Watchdog(obj *Watchdog) {
-	if obj.I6300ESB == nil {
-		obj.I6300ESB = &I6300ESBWatchdog{}
-	}
-}
-
 func SetDefaults_CDRomTarget(obj *CDRomTarget) {
 	if obj.ReadOnly == nil {
 		obj.ReadOnly = _true
@@ -98,12 +92,6 @@ func SetDefaults_FeatureSpinlocks(obj *FeatureSpinlocks) {
 	}
 }
 
-func SetDefaults_I6300ESBWatchdog(obj *I6300ESBWatchdog) {
-	if obj.Action == "" {
-		obj.Action = WatchdogActionReset
-	}
-}
-
 func SetDefaults_Firmware(obj *Firmware) {
 	if obj.UUID == "" {
 		obj.UUID = types.UID(uuid.NewString())
