@@ -7,9 +7,7 @@ import (
 	"time"
 
 	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/apimachinery/pkg/types"
 
-	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	"kubevirt.io/kubevirt/pkg/libdv"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
@@ -63,106 +61,6 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 		format.MaxLength = 0
 	})
 
-	createSnapshot := func(vm *virtv1.VirtualMachine) *snapshotv1.VirtualMachineSnapshot {
-		var err error
-
-		snapshot := &snapshotv1.VirtualMachineSnapshot{
-			ObjectMeta: v1.ObjectMeta{
-				Name:      "snapshot-" + vm.Name,
-				Namespace: vm.Namespace,
-			},
-			Spec: snapshotv1.VirtualMachineSnapshotSpec{
-				Source: k8sv1.TypedLocalObjectReference{
-					APIGroup: pointer.P(vmAPIGroup),
-					Kind:     "VirtualMachine",
-					Name:     vm.Name,
-				},
-			},
-		}
-
-		snapshot, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, v1.CreateOptions{})
-		ExpectWithOffset(1, err).ToNot(HaveOccurred())
-
-		return snapshot
-	}
-
-	waitSnapshotReady := func(snapshot *snapshotv1.VirtualMachineSnapshot) *snapshotv1.VirtualMachineSnapshot {
-		var err error
-
-		EventuallyWithOffset(1, func() bool {
-			snapshot, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Get(context.Background(), snapshot.Name, v1.GetOptions{})
-			ExpectWithOffset(1, err).ToNot(HaveOccurred())
-			return snapshot.Status != nil && snapshot.Status.ReadyToUse != nil && *snapshot.Status.ReadyToUse
-		}, 180*time.Second, time.Second).Should(BeTrue(), "snapshot should be ready")
-
-		return snapshot
-	}
-
-	waitSnapshotContentsExist := func(snapshot *snapshotv1.VirtualMachineSnapshot) *snapshotv1.VirtualMachineSnapshot {
-		var contentsName string
-		EventuallyWithOffset(1, func() error {
-			snapshot, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Get(context.Background(), snapshot.Name, v1.GetOptions{})
-			ExpectWithOffset(2, err).ToNot(HaveOccurred())
-			if snapshot.Status == nil {
-				return fmt.Errorf("snapshot's status is nil")
-			}
-
-			if snapshot.Status.VirtualMachineSnapshotContentName != nil {
-				contentsName = *snapshot.Status.VirtualMachineSnapshotContentName
-			} else {
-				return fmt.Errorf("vm snapshot contents name is nil")
-			}
-
-			return nil
-		}, 30*time.Second, 1*time.Second).ShouldNot(HaveOccurred())
-
-		EventuallyWithOffset(1, func() error {
-			_, err := virtClient.VirtualMachineSnapshotContent(snapshot.Namespace).Get(context.Background(), contentsName, v1.GetOptions{})
-			return err
-		}).ShouldNot(HaveOccurred())
-
-		return snapshot
-	}
-
-	generateCloneFromVMWithParams := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clone.VirtualMachineClone {
-		vmClone := kubecli.NewMinimalCloneWithNS("testclone", sourceVM.Namespace)
-
-		cloneSourceRef := &k8sv1.TypedLocalObjectReference{
-			APIGroup: pointer.P(vmAPIGroup),
-			Kind:     "VirtualMachine",
-			Name:     sourceVM.Name,
-		}
-
-		cloneTargetRef := cloneSourceRef.DeepCopy()
-		cloneTargetRef.Name = targetVMName
-
-		vmClone.Spec.Source = cloneSourceRef
-		vmClone.Spec.Target = cloneTargetRef
-
-		return vmClone
-	}
-
-	generateCloneFromSnapshot := func(snapshot *snapshotv1.VirtualMachineSnapshot, targetVMName string) *clone.VirtualMachineClone {
-		vmClone := kubecli.NewMinimalCloneWithNS("testclone", snapshot.Namespace)
-
-		cloneSourceRef := &k8sv1.TypedLocalObjectReference{
-			APIGroup: pointer.P(virtsnapshot.GroupName),
-			Kind:     "VirtualMachineSnapshot",
-			Name:     snapshot.Name,
-		}
-
-		cloneTargetRef := &k8sv1.TypedLocalObjectReference{
-			APIGroup: pointer.P(vmAPIGroup),
-			Kind:     "VirtualMachine",
-			Name:     targetVMName,
-		}
-
-		vmClone.Spec.Source = cloneSourceRef
-		vmClone.Spec.Target = cloneTargetRef
-
-		return vmClone
-	}
-
 	createClone := func(vmClone *clone.VirtualMachineClone) *clone.VirtualMachineClone {
 		By(fmt.Sprintf("Creating clone object %s", vmClone.Name))
 		vmClone, err = virtClient.VirtualMachineClone(vmClone.Namespace).Create(context.Background(), vmClone, v1.CreateOptions{})
@@ -186,8 +84,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 
 	expectVMRunnable := func(vm *virtv1.VirtualMachine, login console.LoginToFunction) *virtv1.VirtualMachine {
 		By(fmt.Sprintf("Starting VM %s", vm.Name))
-		vm, err = startCloneVM(virtClient, vm)
-		Expect(err).ShouldNot(HaveOccurred())
+		Expect(virtClient.VirtualMachine(vm.Namespace).Start(context.Background(), vm.Name, &virtv1.StartOptions{})).To(Succeed())
 		Eventually(ThisVM(vm)).WithTimeout(300 * time.Second).WithPolling(time.Second).Should(BeReady())
 		targetVMI, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, v1.GetOptions{})
 		Expect(err).ShouldNot(HaveOccurred())
@@ -195,26 +92,13 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 		err = login(targetVMI)
 		Expect(err).ShouldNot(HaveOccurred())
 
-		vm, err = stopCloneVM(virtClient, vm)
-		Expect(err).ShouldNot(HaveOccurred())
+		Expect(virtClient.VirtualMachine(vm.Namespace).Stop(context.Background(), vm.Name, &virtv1.StopOptions{})).To(Succeed())
 		Eventually(ThisVMIWith(vm.Namespace, vm.Name), 300*time.Second, 1*time.Second).ShouldNot(Exist())
 		Eventually(ThisVM(vm), 300*time.Second, 1*time.Second).Should(Not(BeReady()))
 
 		return vm
 	}
 
-	filterOutIrrelevantKeys := func(in map[string]string) map[string]string {
-		out := make(map[string]string)
-
-		for key, val := range in {
-			if !strings.Contains(key, "kubevirt.io") && !strings.Contains(key, "kubemacpool.io") {
-				out[key] = val
-			}
-		}
-
-		return out
-	}
-
 	Context("VM clone", func() {
 
 		const (
@@ -263,7 +147,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 			expectEqualStrMap(targetVM.Spec.Template.ObjectMeta.Annotations, sourceVM.Spec.Template.ObjectMeta.Annotations, fmt.Sprintf(cloneShouldEqualSourceMsgPattern, "template.annotations"), keysToExclude...)
 		}
 
-		expectSpecsToEqualExceptForMacAddress := func(vm1, vm2 *virtv1.VirtualMachine) {
+		expectSpecsToEqualExceptForMacAddressAndUUID := func(vm1, vm2 *virtv1.VirtualMachine) {
 			vm1Spec := vm1.Spec.DeepCopy()
 			vm2Spec := vm2.Spec.DeepCopy()
 
@@ -271,13 +155,29 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 				for i := range spec.Template.Spec.Domain.Devices.Interfaces {
 					spec.Template.Spec.Domain.Devices.Interfaces[i].MacAddress = ""
 				}
+				if spec.Template.Spec.Domain.Firmware != nil {
+					spec.Template.Spec.Domain.Firmware.UUID = ""
+				}
 			}
 
-			Expect(vm1Spec).To(Equal(vm2Spec), fmt.Sprintf(cloneShouldEqualSourceMsgPattern, "spec not including mac adresses"))
+			Expect(vm1Spec).To(Equal(vm2Spec), fmt.Sprintf(cloneShouldEqualSourceMsgPattern, "spec not including mac addresses and firmware UUID"))
+		}
+
+		expectSpecsToEqualExceptForFirmwareUUID := func(vm1, vm2 *virtv1.VirtualMachine) {
+			vm1Spec := vm1.Spec.DeepCopy()
+			vm2Spec := vm2.Spec.DeepCopy()
+
+			for _, spec := range []*virtv1.VirtualMachineSpec{vm1Spec, vm2Spec} {
+				if spec.Template.Spec.Domain.Firmware != nil {
+					spec.Template.Spec.Domain.Firmware.UUID = ""
+				}
+			}
+
+			Expect(vm1Spec).To(Equal(vm2Spec), fmt.Sprintf(cloneShouldEqualSourceMsgPattern, "spec not including firmware UUID"))
 		}
 
 		generateCloneFromVM := func() *clone.VirtualMachineClone {
-			return generateCloneFromVMWithParams(sourceVM, targetVMName)
+			return generateCloneFromVMWithParams(sourceVM.Name, sourceVM.Namespace, targetVMName)
 		}
 
 		Context("[sig-compute]simple VM and cloning operations", decorators.SigCompute, func() {
@@ -300,7 +200,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 				By("Making sure target is runnable")
 				targetVM = expectVMRunnable(targetVM)
 
-				Expect(targetVM.Spec).To(Equal(sourceVM.Spec), fmt.Sprintf(cloneShouldEqualSourceMsgPattern, "spec"))
+				expectSpecsToEqualExceptForFirmwareUUID(sourceVM, targetVM)
 				expectEqualLabels(targetVM, sourceVM)
 				expectEqualAnnotations(targetVM, sourceVM)
 				expectEqualTemplateLabels(targetVM, sourceVM)
@@ -319,7 +219,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 				}, 120*time.Second, 1*time.Second).Should(MatchError(errors.IsNotFound, "k8serrors.IsNotFound"), "VM clone should be successfully deleted")
 			})
 
-			It("simple clone with snapshot source", func() {
+			It("simple clone with snapshot source, create clone before snapshot", func() {
 				By("Creating a VM")
 				sourceVM, err = createSourceVM(defaultVMIOptions...)
 				Expect(err).ShouldNot(HaveOccurred())
@@ -330,22 +230,18 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 					return sourceVM.Status.PrintableStatus
 				}, 30*time.Second, 1*time.Second).Should(Equal(virtv1.VirtualMachineStatusStopped))
 
-				By("Creating a snapshot from VM")
-				snapshot := createSnapshot(sourceVM)
-				snapshot = waitSnapshotContentsExist(snapshot)
-				// "waitSnapshotReady" is not used here intentionally since it's okay for a snapshot source
-				// to not be ready when creating a clone. Therefore, it's not deterministic if snapshot would actually
-				// be ready for this test or not.
-				// TODO: use snapshot's createDenyVolumeSnapshotCreateWebhook() once it's refactored to work outside
-				// of snapshot tests scope.
+				snapshot := generateSnapshot(sourceVM.Name, sourceVM.Namespace)
+				By("Creating a clone before snapshot source created")
+				vmClone = generateCloneFromSnapshot(snapshot.Name, snapshot.Namespace, targetVMName)
+				vmClone = createClone(vmClone)
 
-				By("Deleting VM")
-				err = virtClient.VirtualMachine(sourceVM.Namespace).Delete(context.Background(), sourceVM.Name, v1.DeleteOptions{})
+				events.ExpectEvent(vmClone, k8sv1.EventTypeNormal, "SourceDoesNotExist")
+
+				By("Creating a snapshot from VM")
+				snapshot, err := virtClient.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, v1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				By("Creating a clone with a snapshot source")
-				vmClone = generateCloneFromSnapshot(snapshot, targetVMName)
-				createCloneAndWaitForCompletion(vmClone)
+				waitCloneSucceeded(vmClone)
 
 				By(fmt.Sprintf("Getting the target VM %s", targetVMName))
 				targetVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), targetVMName, v1.GetOptions{})
@@ -354,7 +250,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 				By("Making sure target is runnable")
 				targetVM = expectVMRunnable(targetVM)
 
-				By("Making sure snapshot source is not being deleted")
+				By("Making sure snapshot source was not deleted when clone completed")
 				_, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Get(context.Background(), snapshot.Name, v1.GetOptions{})
 				Expect(err).ShouldNot(HaveOccurred())
 			})
@@ -380,7 +276,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 				By("Making sure target is runnable")
 				targetVM = expectVMRunnable(targetVM)
 
-				Expect(targetVM.Spec).To(Equal(sourceVM.Spec), fmt.Sprintf(cloneShouldEqualSourceMsgPattern, "spec"))
+				expectSpecsToEqualExceptForFirmwareUUID(sourceVM, targetVM)
 				expectEqualLabels(targetVM, sourceVM, key2)
 				expectEqualAnnotations(targetVM, sourceVM, key2)
 			})
@@ -452,7 +348,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 				By("Making sure new mac address is applied to target VM")
 				Expect(targetInterface.MacAddress).ToNot(Equal(srcInterface.MacAddress))
 
-				expectSpecsToEqualExceptForMacAddress(targetVM, sourceVM)
+				expectSpecsToEqualExceptForMacAddressAndUUID(targetVM, sourceVM)
 				expectEqualLabels(targetVM, sourceVM)
 				expectEqualAnnotations(targetVM, sourceVM)
 				expectEqualTemplateLabels(targetVM, sourceVM)
@@ -563,44 +459,6 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 				return createVM(vm, storageClass, runStrategy)
 			}
 
-			Context("and no snapshot storage class", decorators.RequiresNoSnapshotStorageClass, func() {
-				var (
-					noSnapshotStorageClass string
-				)
-
-				Context("should reject source with non snapshotable volume", func() {
-					BeforeEach(func() {
-						noSnapshotStorageClass = libstorage.GetNoVolumeSnapshotStorageClass("local")
-						Expect(noSnapshotStorageClass).ToNot(BeEmpty(), "no storage class without snapshot support")
-
-						// create running in case storage is WFFC (local storage)
-						By("Creating source VM")
-						sourceVM = createVMWithStorageClass(noSnapshotStorageClass, virtv1.RunStrategyAlways)
-						sourceVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Get(context.Background(), sourceVM.Name, v1.GetOptions{})
-						Expect(err).ToNot(HaveOccurred())
-						sourceVM, err = stopCloneVM(virtClient, sourceVM)
-						Eventually(ThisVMIWith(sourceVM.Namespace, sourceVM.Name), 300*time.Second, 1*time.Second).ShouldNot(Exist())
-						Eventually(ThisVM(sourceVM), 300*time.Second, 1*time.Second).Should(Not(BeReady()))
-					})
-
-					It("with snapshot source", func() {
-						By("Snapshotting VM")
-						snapshot := createSnapshot(sourceVM)
-						snapshot = waitSnapshotReady(snapshot)
-
-						By("Deleting VM")
-						err = virtClient.VirtualMachine(sourceVM.Namespace).Delete(context.Background(), sourceVM.Name, v1.DeleteOptions{})
-						Expect(err).ToNot(HaveOccurred())
-
-						By("Creating a clone and expecting error")
-						vmClone = generateCloneFromSnapshot(snapshot, targetVMName)
-						vmClone, err = virtClient.VirtualMachineClone(vmClone.Namespace).Create(context.Background(), vmClone, v1.CreateOptions{})
-						Expect(err).Should(HaveOccurred())
-						Expect(err.Error()).To(ContainSubstring("not backed up in snapshot"))
-					})
-				})
-			})
-
 			Context("and snapshot storage class", decorators.RequiresSnapshotStorageClass, func() {
 				var (
 					snapshotStorageClass string
@@ -681,15 +539,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 						preference, err := virtClient.VirtualMachinePreference(ns).Create(context.Background(), preference, v1.CreateOptions{})
 						Expect(err).ToNot(HaveOccurred())
 
-						dv := libdv.NewDataVolume(
-							libdv.WithRegistryURLSource(cd.DataVolumeImportUrlForContainerDisk(cd.ContainerDiskAlpine)),
-							libdv.WithNamespace(testsuite.GetTestNamespace(nil)),
-							libdv.WithStorage(
-								libdv.StorageWithStorageClass(snapshotStorageClass),
-								libdv.StorageWithVolumeSize(cd.ContainerDiskSizeBySourceURL(cd.DataVolumeImportUrlForContainerDisk(cd.ContainerDiskAlpine))),
-							),
-						)
-						sourceVM = libstorage.RenderVMWithDataVolumeTemplate(dv)
+						sourceVM = libvmi.NewVirtualMachine(libvmifact.NewGuestless())
 						sourceVM.Spec.Template.Spec.Domain.Resources = virtv1.ResourceRequirements{}
 						sourceVM.Spec.Instancetype = &virtv1.InstancetypeMatcher{
 							Name: instancetype.Name,
@@ -703,12 +553,9 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 
 					DescribeTable("should create new ControllerRevisions for cloned VM", Label("instancetype", "clone"), func(runStrategy virtv1.VirtualMachineRunStrategy) {
 						sourceVM.Spec.RunStrategy = &runStrategy
-						sourceVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Create(context.Background(), sourceVM, v1.CreateOptions{})
+						sourceVM, err = virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Create(context.Background(), sourceVM, v1.CreateOptions{})
 						Expect(err).ToNot(HaveOccurred())
 
-						for _, dvt := range sourceVM.Spec.DataVolumeTemplates {
-							libstorage.EventuallyDVWith(sourceVM.Namespace, dvt.Name, 180, HaveSucceeded())
-						}
 						By("Waiting until the source VM has instancetype and preference RevisionNames")
 						Eventually(matcher.ThisVM(sourceVM)).WithTimeout(300 * time.Second).WithPolling(time.Second).Should(matcher.HaveControllerRevisionRefs())
 
@@ -745,7 +592,7 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 						vmClone.Spec.Template.AnnotationFilters = filters
 					}
 					generateCloneWithFilters := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clone.VirtualMachineClone {
-						vmclone := generateCloneFromVMWithParams(sourceVM, targetVMName)
+						vmclone := generateCloneFromVMWithParams(sourceVM.Name, sourceVM.Namespace, targetVMName)
 						addCloneAnnotationAndLabelFilters(vmclone)
 						return vmclone
 					}
@@ -787,11 +634,13 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 					expectEqualTemplateAnnotations(targetVMCloneFromClone, sourceVM)
 				})
 
-				Context("with WaitForFirstConsumer binding mode", func() {
+				Context("with WaitForFirstConsumer binding mode", decorators.RequiresWFFCStorageClass, func() {
 					BeforeEach(func() {
 						snapshotStorageClass, err = libstorage.GetWFFCStorageSnapshotClass(virtClient)
 						Expect(err).ToNot(HaveOccurred())
-						Expect(snapshotStorageClass).ToNot(BeEmpty(), "no storage class with snapshot support and wffc binding mode")
+						if snapshotStorageClass == "" {
+							Fail("Failing test, no storage class with snapshot support and wffc binding mode")
+						}
 					})
 
 					It("should not delete the vmsnapshot and vmrestore until all the pvc(s) are bound", func() {
@@ -803,15 +652,14 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 							vmClone.Spec.Template.AnnotationFilters = filters
 						}
 						generateCloneWithFilters := func(sourceVM *virtv1.VirtualMachine, targetVMName string) *clone.VirtualMachineClone {
-							vmclone := generateCloneFromVMWithParams(sourceVM, targetVMName)
+							vmclone := generateCloneFromVMWithParams(sourceVM.Name, sourceVM.Namespace, targetVMName)
 							addCloneAnnotationAndLabelFilters(vmclone)
 							return vmclone
 						}
 
 						sourceVM = createVMWithStorageClass(snapshotStorageClass, virtv1.RunStrategyAlways)
 						vmClone = generateCloneWithFilters(sourceVM, targetVMName)
-						sourceVM, err = stopCloneVM(virtClient, sourceVM)
-						Expect(err).ShouldNot(HaveOccurred())
+						Expect(virtClient.VirtualMachine(sourceVM.Namespace).Stop(context.Background(), sourceVM.Name, &virtv1.StopOptions{})).To(Succeed())
 						Eventually(ThisVMIWith(sourceVM.Namespace, sourceVM.Name), 300*time.Second, 1*time.Second).ShouldNot(Exist())
 						Eventually(ThisVM(sourceVM), 300*time.Second, 1*time.Second).Should(Not(BeReady()))
 
@@ -854,24 +702,6 @@ var _ = Describe("VirtualMachineClone Tests", Serial, func() {
 	})
 })
 
-func startCloneVM(virtClient kubecli.KubevirtClient, vm *virtv1.VirtualMachine) (*virtv1.VirtualMachine, error) {
-	patch, err := patch.New(patch.WithAdd("/spec/runStrategy", virtv1.RunStrategyAlways)).GeneratePayload()
-	if err != nil {
-		return nil, err
-	}
-
-	return virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, patch, v1.PatchOptions{})
-}
-
-func stopCloneVM(virtClient kubecli.KubevirtClient, vm *virtv1.VirtualMachine) (*virtv1.VirtualMachine, error) {
-	patch, err := patch.New(patch.WithAdd("/spec/runStrategy", virtv1.RunStrategyHalted)).GeneratePayload()
-	if err != nil {
-		return nil, err
-	}
-
-	return virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, patch, v1.PatchOptions{})
-}
-
 func withFirmware(firmware *virtv1.Firmware) libvmi.Option {
 	return func(vmi *virtv1.VirtualMachineInstance) {
 		vmi.Spec.Domain.Firmware = firmware
@@ -889,3 +719,71 @@ func createSourceVM(options ...libvmi.Option) (*virtv1.VirtualMachine, error) {
 	virtClient := kubevirt.Client()
 	return virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, v1.CreateOptions{})
 }
+
+func generateSnapshot(vmName, vmNamespace string) *snapshotv1.VirtualMachineSnapshot {
+	snapshot := &snapshotv1.VirtualMachineSnapshot{
+		ObjectMeta: v1.ObjectMeta{
+			Name:      "snapshot-" + vmName,
+			Namespace: vmNamespace,
+		},
+		Spec: snapshotv1.VirtualMachineSnapshotSpec{
+			Source: k8sv1.TypedLocalObjectReference{
+				APIGroup: pointer.P(vmAPIGroup),
+				Kind:     "VirtualMachine",
+				Name:     vmName,
+			},
+		},
+	}
+	return snapshot
+}
+
+func generateCloneFromSnapshot(snapshotName, namespace, targetVMName string) *clone.VirtualMachineClone {
+	vmClone := kubecli.NewMinimalCloneWithNS("testclone", namespace)
+
+	cloneSourceRef := &k8sv1.TypedLocalObjectReference{
+		APIGroup: pointer.P(virtsnapshot.GroupName),
+		Kind:     "VirtualMachineSnapshot",
+		Name:     snapshotName,
+	}
+
+	cloneTargetRef := &k8sv1.TypedLocalObjectReference{
+		APIGroup: pointer.P(vmAPIGroup),
+		Kind:     "VirtualMachine",
+		Name:     targetVMName,
+	}
+
+	vmClone.Spec.Source = cloneSourceRef
+	vmClone.Spec.Target = cloneTargetRef
+
+	return vmClone
+}
+
+func generateCloneFromVMWithParams(sourceVMName, sourceVMNamespace, targetVMName string) *clone.VirtualMachineClone {
+	vmClone := kubecli.NewMinimalCloneWithNS("testclone", sourceVMNamespace)
+
+	cloneSourceRef := &k8sv1.TypedLocalObjectReference{
+		APIGroup: pointer.P(vmAPIGroup),
+		Kind:     "VirtualMachine",
+		Name:     sourceVMName,
+	}
+
+	cloneTargetRef := cloneSourceRef.DeepCopy()
+	cloneTargetRef.Name = targetVMName
+
+	vmClone.Spec.Source = cloneSourceRef
+	vmClone.Spec.Target = cloneTargetRef
+
+	return vmClone
+}
+
+func filterOutIrrelevantKeys(in map[string]string) map[string]string {
+	out := make(map[string]string)
+
+	for key, val := range in {
+		if !strings.Contains(key, "kubevirt.io") && !strings.Contains(key, "kubemacpool.io") {
+			out[key] = val
+		}
+	}
+
+	return out
+}
