@@ -13,21 +13,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2023 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
+
 package compute
 
 import (
-	ginkgo "github.com/onsi/ginkgo/v2"
-
 	"kubevirt.io/kubevirt/tests/decorators"
 )
 
-func SIGDescribe(text string, args ...interface{}) bool {
-	return ginkgo.Describe("[sig-compute] "+text, decorators.SigCompute, args)
-}
-
-func FSIGDescribe(text string, args ...interface{}) bool {
-	return ginkgo.FDescribe("[sig-compute] "+text, decorators.SigCompute, args)
+func SIG(text string, args ...interface{}) (extendedText string, newArgs []interface{}) {
+	return decorators.SIG("[sig-compute]", text, decorators.SigCompute, args)
 }
