@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -34,9 +34,9 @@ import (
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
-	"kubevirt.io/kubevirt/tests"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
+	"kubevirt.io/kubevirt/tests/libdomain"
 	"kubevirt.io/kubevirt/tests/libkubevirt"
 	"kubevirt.io/kubevirt/tests/libkubevirt/config"
 	"kubevirt.io/kubevirt/tests/libvmifact"
@@ -44,7 +44,7 @@ import (
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
-var _ = SIGDescribe("VMIDefaults", func() {
+var _ = Describe(SIG("VMIDefaults", func() {
 	var virtClient kubecli.KubevirtClient
 
 	var vmi *v1.VirtualMachineInstance
@@ -121,7 +121,7 @@ var _ = SIGDescribe("VMIDefaults", func() {
 			libwait.WaitForSuccessfulVMIStart(vmi)
 
 			By("Getting domain of vmi")
-			domain, err := tests.GetRunningVMIDomainSpec(vmi)
+			domain, err := libdomain.GetRunningVMIDomainSpec(vmi)
 			Expect(err).ToNot(HaveOccurred())
 
 			expected := api.MemBalloon{
@@ -165,7 +165,7 @@ var _ = SIGDescribe("VMIDefaults", func() {
 			libwait.WaitForSuccessfulVMIStart(vmi)
 
 			By("Getting domain of vmi")
-			domain, err := tests.GetRunningVMIDomainSpec(vmi)
+			domain, err := libdomain.GetRunningVMIDomainSpec(vmi)
 
 			Expect(err).ToNot(HaveOccurred())
 			Expect(domain.Devices.Ballooning).ToNot(BeNil(), "There should be memballoon device")
@@ -206,7 +206,7 @@ var _ = SIGDescribe("VMIDefaults", func() {
 			libwait.WaitForSuccessfulVMIStart(vmi)
 
 			By("Getting domain of vmi")
-			domain, err := tests.GetRunningVMIDomainSpec(vmi)
+			domain, err := libdomain.GetRunningVMIDomainSpec(vmi)
 			Expect(err).ToNot(HaveOccurred())
 
 			expected := api.MemBalloon{
@@ -257,4 +257,4 @@ var _ = SIGDescribe("VMIDefaults", func() {
 		})
 
 	})
-})
+}))
