@@ -59,6 +59,7 @@ var (
 	MigrationBasedHotplugNICs            = Label("migration-based-hotplug-NICs")
 	NetCustomBindingPlugins              = Label("netCustomBindingPlugins")
 	RequiresTwoSchedulableNodes          = Label("requires-two-schedulable-nodes")
+	RequiresThreeSchedulableNodes        = Label("requires-three-schedulable-nodes")
 	VMLiveUpdateRolloutStrategy          = Label("VMLiveUpdateRolloutStrategy")
 	USB                                  = Label("USB")
 	RequiresTwoWorkerNodesWithCPUManager = Label("requires-two-worker-nodes-with-cpu-manager")
@@ -71,6 +72,8 @@ var (
 
 	// RequiresSnapshotStorageClass requires a storage class with support for snapshots
 	RequiresSnapshotStorageClass = Label("RequiresSnapshotStorageClass")
+	// RequiresWFFCStorageClass requires a storage class with support for WFFC bindingMode
+	RequiresWFFCStorageClass = Label("RequiresWFFCStorageClass")
 	// RequiresNoSnapshotStorageClass requires a storage class without support for snapshots
 	RequiresNoSnapshotStorageClass = Label("RequiresNoSnapshotStorageClass")
 	// RequiresRWXBlock requires a storage class with ReadWriteMany Block support
@@ -86,17 +89,14 @@ var (
 	StorageCritical = Label("StorageCritical")
 	// RequiresVolumeExpansion requires a storage class with volume expansion support
 	RequiresVolumeExpansion = Label("RequiresVolumeExpansion")
+	// RequiresDecentralizedLiveMigration request the feature gate is enabled
+	RequiresDecentralizedLiveMigration = Label("RequiresDecentralizedLiveMigration")
 
 	/* Provisioner */
 
 	// RequiresSizeRoundUp requires a provisioner that rounds up the size of the volume
 	RequiresSizeRoundUp = Label("RequiresSizeRoundUp")
 
-	/* Kubernetes versions */
-
-	// Kubernetes versions
-	Kubernetes130 = Label("kubernetes130")
-
 	/* architecture working groups */
 
 	WgS390x = Label("wg-s390x")
@@ -117,4 +117,12 @@ var (
 	// LargeStoragePoolRequired indicates that the test may fail in a cluster with a low storage pool capacity.
 	// This decorator can be used to skip the test as the failure might not indicate a functional problem.
 	LargeStoragePoolRequired = Label("large-storage-pool-required")
+
+	// OncePerOrderedCleanup decorates Ordered tests to only cleanup after the last
+	// test in an Ordered container.
+	// Currently, in pilot mode, restricted to SIG-Network and virtctl only.
+	OncePerOrderedCleanup = Label("OncePerOrderedCleanup")
+
+	// Swap decorator is used in case a swap is required on a node.
+	Swap = Label("SwapTest")
 )
