@@ -4,6 +4,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"strconv"
 	"time"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -20,8 +21,7 @@ import (
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
-	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
-	"kubevirt.io/kubevirt/tests"
+	"kubevirt.io/kubevirt/tests/console"
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/flags"
 	"kubevirt.io/kubevirt/tests/framework/checks"
@@ -102,23 +102,6 @@ var _ = Describe("[sig-compute]CPU Hotplug", decorators.SigCompute, decorators.S
 	})
 
 	Context("A VM with cpu.maxSockets set higher than cpu.sockets", func() {
-		type cpuCount struct {
-			enabled  int
-			disabled int
-		}
-		countDomCPUs := func(spec *api.DomainSpec) (count cpuCount) {
-			ExpectWithOffset(1, spec.VCPUs).NotTo(BeNil())
-			for _, cpu := range spec.VCPUs.VCPU {
-				if cpu.Enabled == "yes" {
-					count.enabled++
-				} else {
-					ExpectWithOffset(1, cpu.Enabled).To(Equal("no"))
-					ExpectWithOffset(1, cpu.Hotpluggable).To(Equal("yes"))
-					count.disabled++
-				}
-			}
-			return
-		}
 		It("[test_id:10811]should successfully plug vCPUs", func() {
 			By("Creating a running VM with 1 socket and 2 max sockets")
 			const (
@@ -152,17 +135,11 @@ var _ = Describe("[sig-compute]CPU Hotplug", decorators.SigCompute, decorators.S
 			expCpu := resource.MustParse("200m")
 			Expect(reqCpu).To(Equal(expCpu.Value()))
 
-			By("Ensuring the libvirt domain has 2 enabled cores and 2 hotpluggable cores")
-			var domSpec *api.DomainSpec
-			Eventually(func() error {
-				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
-				return err
-			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
-
-			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
-				enabled:  2,
-				disabled: 2,
-			}))
+			By("Ensuring the guest has the expected number of vCPUs")
+			vmi = libwait.WaitUntilVMIReady(vmi, console.LoginToAlpine)
+			guestCPUs, err := getGuestVirtualCpus(vmi)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(guestCPUs).To(Equal(2), "expected 2 vCPUs in the guest")
 
 			By("Enabling the second socket")
 			patchData, err := patch.GenerateTestReplacePatch("/spec/template/spec/domain/cpu/sockets", 1, 2)
@@ -189,18 +166,6 @@ var _ = Describe("[sig-compute]CPU Hotplug", decorators.SigCompute, decorators.S
 			}, 30*time.Second, time.Second).Should(BeTrue())
 			libmigration.ExpectMigrationToSucceedWithDefaultTimeout(virtClient, migration)
 
-			By("Ensuring the libvirt domain has 4 enabled cores")
-
-			Eventually(func() error {
-				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
-				return err
-			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
-
-			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
-				enabled:  4,
-				disabled: 0,
-			}))
-
 			By("Ensuring the virt-launcher pod now has 400m CPU")
 			compute, err = libpod.LookupComputeContainerFromVmi(vmi)
 			Expect(err).ToNot(HaveOccurred())
@@ -215,6 +180,18 @@ var _ = Describe("[sig-compute]CPU Hotplug", decorators.SigCompute, decorators.S
 			Expect(err).NotTo(HaveOccurred())
 			Eventually(ThisVM(vm), 4*time.Minute, 2*time.Second).Should(HaveConditionMissingOrFalse(v1.VirtualMachineRestartRequired))
 
+			By("Ensuring the guest has the expected number of vCPUs")
+			Eventually(func() error {
+				guestCPUs, err = getGuestVirtualCpus(vmi)
+				Expect(err).ToNot(HaveOccurred())
+
+				if guestCPUs != 4 {
+					return fmt.Errorf("expected 4 vCPUs in the guest, got %d", guestCPUs)
+				}
+
+				return nil
+			}).WithPolling(2 * time.Second).WithTimeout(30 * time.Second).Should(Succeed())
+
 			By("Changing the number of CPU cores")
 			patchData, err = patch.GenerateTestReplacePatch("/spec/template/spec/domain/cpu/cores", 2, 4)
 			Expect(err).NotTo(HaveOccurred())
@@ -260,17 +237,11 @@ var _ = Describe("[sig-compute]CPU Hotplug", decorators.SigCompute, decorators.S
 			expCpu := resource.MustParse("2")
 			Expect(reqCpu).To(Equal(expCpu.Value()))
 
-			By("Ensuring the libvirt domain has 2 enabled cores and 4 disabled cores")
-			var domSpec *api.DomainSpec
-			Eventually(func() error {
-				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
-				return err
-			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
-
-			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
-				enabled:  2,
-				disabled: 4,
-			}))
+			By("Ensuring the guest has the expected number of vCPUs")
+			vmi = libwait.WaitUntilVMIReady(vmi, console.LoginToAlpine)
+			guestCPUs, err := getGuestVirtualCpus(vmi)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(guestCPUs).To(Equal(2), "expected 2 vCPUs in the guest")
 
 			By("starting the migration")
 			migration := libmigration.New(vm.Name, vm.Namespace)
@@ -295,17 +266,6 @@ var _ = Describe("[sig-compute]CPU Hotplug", decorators.SigCompute, decorators.S
 				HaveConditionFalse(v1.VirtualMachineInstanceVCPUChange),
 			))
 
-			By("Ensuring the libvirt domain has 4 enabled cores")
-			Eventually(func() error {
-				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
-				return err
-			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
-
-			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
-				enabled:  4,
-				disabled: 2,
-			}))
-
 			By("Ensuring the virt-launcher pod now has 4 CPU")
 			compute, err = libpod.LookupComputeContainerFromVmi(vmi)
 			Expect(err).ToNot(HaveOccurred())
@@ -314,6 +274,18 @@ var _ = Describe("[sig-compute]CPU Hotplug", decorators.SigCompute, decorators.S
 			reqCpu = compute.Resources.Requests.Cpu().Value()
 			expCpu = resource.MustParse("4")
 			Expect(reqCpu).To(Equal(expCpu.Value()))
+
+			By("Ensuring the guest has the expected number of vCPUs")
+			Eventually(func() error {
+				guestCPUs, err = getGuestVirtualCpus(vmi)
+				Expect(err).ToNot(HaveOccurred())
+
+				if guestCPUs != 4 {
+					return fmt.Errorf("expected 4 vCPUs in the guest, got %d", guestCPUs)
+				}
+
+				return nil
+			}).WithPolling(2 * time.Second).WithTimeout(30 * time.Second).Should(Succeed())
 		})
 	})
 
@@ -409,3 +381,18 @@ func patchWorkloadUpdateMethodAndRolloutStrategy(kvName string, virtClient kubec
 		return err
 	}, 10*time.Second, 1*time.Second).ShouldNot(HaveOccurred())
 }
+
+// The VMI is assumed to be already logged-in.
+func getGuestVirtualCpus(vmi *v1.VirtualMachineInstance) (int, error) {
+	res, err := console.RunCommandAndStoreOutput(vmi, "nproc --all", time.Second*30)
+	if err != nil {
+		return -1, err
+	}
+
+	guestCPUs, err := strconv.Atoi(res)
+	if err != nil {
+		return -1, err
+	}
+
+	return guestCPUs, nil
+}
