@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2022 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -39,12 +39,15 @@ import (
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/libnode"
 	"kubevirt.io/kubevirt/tests/libregistry"
-	"kubevirt.io/kubevirt/tests/util"
 )
 
 const (
 	DefaultPvcMountPath                = "/pvc"
 	StorageClassHostPathSeparateDevice = "host-path-sd"
+
+	// LabelApplyStorageProfile is a label used by the CDI mutating webhook
+	// to modify the PVC according to the storage profile.
+	LabelApplyStorageProfile = "cdi.kubevirt.io/applyStorageProfile"
 )
 
 func RenderPodWithPVC(name string, cmd []string, args []string, pvc *k8sv1.PersistentVolumeClaim) *k8sv1.Pod {
@@ -132,16 +135,18 @@ func addVolumeMounts(volumeName string) []k8sv1.VolumeMount {
 }
 
 func NewPVC(name, size, storageClass string) *k8sv1.PersistentVolumeClaim {
-	quantity, err := resource.ParseQuantity(size)
-	util.PanicOnError(err)
-
 	return &k8sv1.PersistentVolumeClaim{
-		ObjectMeta: metav1.ObjectMeta{Name: name},
+		ObjectMeta: metav1.ObjectMeta{
+			Name: name,
+			Labels: map[string]string{
+				LabelApplyStorageProfile: "true",
+			},
+		},
 		Spec: k8sv1.PersistentVolumeClaimSpec{
 			AccessModes: []k8sv1.PersistentVolumeAccessMode{k8sv1.ReadWriteOnce},
 			Resources: k8sv1.VolumeResourceRequirements{
 				Requests: k8sv1.ResourceList{
-					"storage": quantity,
+					"storage": resource.MustParse(size),
 				},
 			},
 			StorageClassName: &storageClass,
@@ -153,9 +158,10 @@ func createPVC(pvc *k8sv1.PersistentVolumeClaim, namespace string) *k8sv1.Persis
 	virtCli := kubevirt.Client()
 
 	createdPvc, err := virtCli.CoreV1().PersistentVolumeClaims(namespace).Create(context.Background(), pvc, metav1.CreateOptions{})
-	if !errors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(errors.IsAlreadyExists, "errors.IsAlreadyExists"),
+	))
 
 	return createdPvc
 }
@@ -203,7 +209,7 @@ func CreatePVC(os, namespace, size, storageClass string, recycledPV bool) *k8sv1
 	pvcName := fmt.Sprintf("disk-%s", os)
 
 	selector := map[string]string{
-		util.KubevirtIoTest: os,
+		kubevirtIoTest: os,
 	}
 
 	// If the PV is not recycled, it will have a namespace related test label which  we should match
@@ -222,7 +228,7 @@ func DeleteAllSeparateDeviceHostPathPvs() {
 	virtClient := kubevirt.Client()
 
 	pvList, err := virtClient.CoreV1().PersistentVolumes().List(context.Background(), metav1.ListOptions{})
-	util.PanicOnError(err)
+	Expect(err).ToNot(HaveOccurred())
 	for _, pv := range pvList.Items {
 		if pv.Spec.StorageClassName == StorageClassHostPathSeparateDevice {
 			// ignore error we want to attempt to delete them all.
@@ -254,7 +260,7 @@ func createSeparateDeviceHostPathPv(osName, namespace, nodeName string) {
 		ObjectMeta: metav1.ObjectMeta{
 			Name: fmt.Sprintf("%s-%s", name, namespace),
 			Labels: map[string]string{
-				util.KubevirtIoTest:                      osName,
+				kubevirtIoTest:                           osName,
 				cleanup.TestLabelForNamespace(namespace): "",
 			},
 		},
@@ -289,9 +295,10 @@ func createSeparateDeviceHostPathPv(osName, namespace, nodeName string) {
 	}
 
 	_, err := virtCli.CoreV1().PersistentVolumes().Create(context.Background(), pv, metav1.CreateOptions{})
-	if !errors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(errors.IsAlreadyExists, "errors.IsAlreadyExists"),
+	))
 }
 
 func CreateHostPathPv(osName, namespace, hostPath string) string {
@@ -307,7 +314,7 @@ func CreateHostPathPvWithSizeAndStorageClass(osName, namespace, hostPath, size,
 	virtCli := kubevirt.Client()
 
 	quantity, err := resource.ParseQuantity(size)
-	util.PanicOnError(err)
+	Expect(err).ToNot(HaveOccurred())
 
 	hostPathType := k8sv1.HostPathDirectoryOrCreate
 
@@ -316,7 +323,7 @@ func CreateHostPathPvWithSizeAndStorageClass(osName, namespace, hostPath, size,
 		ObjectMeta: metav1.ObjectMeta{
 			Name: fmt.Sprintf("%s-%s", name, namespace),
 			Labels: map[string]string{
-				util.KubevirtIoTest:                      osName,
+				kubevirtIoTest:                           osName,
 				cleanup.TestLabelForNamespace(namespace): "",
 			},
 		},
@@ -352,9 +359,10 @@ func CreateHostPathPvWithSizeAndStorageClass(osName, namespace, hostPath, size,
 	}
 
 	_, err = virtCli.CoreV1().PersistentVolumes().Create(context.Background(), pv, metav1.CreateOptions{})
-	if !errors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(errors.IsAlreadyExists, "errors.IsAlreadyExists"),
+	))
 	return libnode.SchedulableNode
 }
 
@@ -363,9 +371,10 @@ func DeletePVC(os, namespace string) {
 
 	name := fmt.Sprintf("disk-%s", os)
 	err := virtCli.CoreV1().PersistentVolumeClaims(namespace).Delete(context.Background(), name, metav1.DeleteOptions{})
-	if !errors.IsNotFound(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(errors.IsNotFound, "errors.IsNotFound"),
+	))
 }
 
 func DeletePV(os string) {
@@ -373,7 +382,8 @@ func DeletePV(os string) {
 
 	name := fmt.Sprintf("%s-disk-for-tests", os)
 	err := virtCli.CoreV1().PersistentVolumes().Delete(context.Background(), name, metav1.DeleteOptions{})
-	if !errors.IsNotFound(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(errors.IsNotFound, "errors.IsNotFound"),
+	))
 }
