@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2024 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -37,6 +37,8 @@ import (
 
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	libvmici "kubevirt.io/kubevirt/pkg/libvmi/cloudinit"
+	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
+
 	"kubevirt.io/kubevirt/tests/console"
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/flags"
@@ -52,12 +54,12 @@ import (
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
-var _ = SIGDescribe(" VirtualMachineInstance with passt network binding plugin", decorators.NetCustomBindingPlugins, Serial, func() {
+var _ = Describe(SIG(" VirtualMachineInstance with passt network binding plugin", decorators.NetCustomBindingPlugins, Serial, func() {
 	const passtNetAttDefName = "netbindingpasst"
 
 	var err error
 
-	BeforeEach(func() {
+	BeforeEach(OncePerOrdered, func() {
 		const passtBindingName = "passt"
 
 		passtComputeMemoryOverheadWhenAllPortsAreForwarded := resource.MustParse("500Mi")
@@ -75,9 +77,11 @@ var _ = SIGDescribe(" VirtualMachineInstance with passt network binding plugin",
 			},
 		})
 		Expect(err).NotTo(HaveOccurred())
+
+		config.EnableFeatureGate(featuregate.PasstIPStackMigration)
 	})
 
-	BeforeEach(func() {
+	BeforeEach(OncePerOrdered, func() {
 		netAttachDef := libnet.NewPasstNetAttachDef(passtNetAttDefName)
 		_, err := libnet.CreateNetAttachDef(context.Background(), testsuite.GetTestNamespace(nil), netAttachDef)
 		Expect(err).NotTo(HaveOccurred())
@@ -97,12 +101,7 @@ var _ = SIGDescribe(" VirtualMachineInstance with passt network binding plugin",
 
 		vmi, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), vmi, metav1.CreateOptions{})
 		Expect(err).ToNot(HaveOccurred())
-		vmi = libwait.WaitUntilVMIReady(
-			vmi,
-			console.LoginToAlpine,
-			libwait.WithFailOnWarnings(false),
-			libwait.WithTimeout(180),
-		)
+		waitUntilVMIsReady(console.LoginToAlpine, vmi)
 
 		Expect(vmi.Status.Interfaces).To(HaveLen(1))
 		Expect(vmi.Status.Interfaces[0].IPs).NotTo(BeEmpty())
@@ -114,164 +113,200 @@ var _ = SIGDescribe(" VirtualMachineInstance with passt network binding plugin",
 		Expect(console.RunCommand(vmi, cmd, time.Second*5)).To(Succeed())
 	})
 
-	Context("should allow regular network connection", func() {
-		Context("should have client server connectivity", func() {
-			var clientVMI *v1.VirtualMachineInstance
-			var serverVMI *v1.VirtualMachineInstance
+	Context("TCP without port specification", Ordered, decorators.OncePerOrderedCleanup, func() {
+		var clientVMI *v1.VirtualMachineInstance
+		var serverVMI *v1.VirtualMachineInstance
 
-			startServerVMI := func(ports []v1.Port) {
-				passtIface := libvmi.InterfaceWithPasstBindingPlugin(ports...)
-				serverVMI = libvmifact.NewAlpineWithTestTooling(
-					libvmi.WithInterface(passtIface),
-					libvmi.WithNetwork(v1.DefaultPodNetwork()),
-				)
+		const highTCPPort = 8080
 
-				serverVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), serverVMI, metav1.CreateOptions{})
-				Expect(err).ToNot(HaveOccurred())
-				serverVMI = libwait.WaitUntilVMIReady(
-					serverVMI,
-					console.LoginToAlpine,
-					libwait.WithFailOnWarnings(false),
-					libwait.WithTimeout(180),
-				)
+		BeforeAll(func() {
+			clientVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithPasstInterfaceWithPort(),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			clientVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), clientVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			serverVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithInterface(libvmi.InterfaceWithPasstBindingPlugin()),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			serverVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), serverVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			waitUntilVMIsReady(console.LoginToAlpine, clientVMI, serverVMI)
+
+			vmnetserver.StartTCPServer(serverVMI, highTCPPort, console.LoginToAlpine)
+		})
+		DescribeTable("connectivity", func(ipFamily k8sv1.IPFamily) {
+			libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
+
+			serverIP := libnet.GetVmiPrimaryIPByFamily(serverVMI, ipFamily)
+			Expect(libnet.PingFromVMConsole(clientVMI, serverIP)).To(Succeed())
+			Expect(console.RunCommand(clientVMI, connectToServerCmd(serverIP, highTCPPort), 30*time.Second)).To(Succeed())
+		},
+			Entry("[IPv4]", k8sv1.IPv4Protocol),
+			Entry("[IPv6]", k8sv1.IPv6Protocol),
+		)
+	})
+
+	Context("TCP with port specification", Ordered, decorators.OncePerOrderedCleanup, func() {
+		var clientVMI *v1.VirtualMachineInstance
+		var serverVMI *v1.VirtualMachineInstance
+
+		const highTCPPort = 8080
+
+		BeforeAll(func() {
+			clientVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithPasstInterfaceWithPort(),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			clientVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), clientVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			ports := []v1.Port{{Name: "http", Port: highTCPPort, Protocol: "TCP"}}
+			serverVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithInterface(libvmi.InterfaceWithPasstBindingPlugin(ports...)),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			serverVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), serverVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			waitUntilVMIsReady(console.LoginToAlpine, clientVMI, serverVMI)
+
+			vmnetserver.StartTCPServer(serverVMI, highTCPPort, console.LoginToAlpine)
+			By("starting a TCP server on a port not specified on the VM spec")
+			vmnetserver.StartTCPServer(serverVMI, highTCPPort+1, console.LoginToAlpine)
+
+		})
+		DescribeTable("connectivity", func(ipFamily k8sv1.IPFamily) {
+			libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
+
+			serverIP := libnet.GetVmiPrimaryIPByFamily(serverVMI, ipFamily)
+			Expect(libnet.PingFromVMConsole(clientVMI, serverIP)).To(Succeed())
+
+			By("Connecting from the client VM")
+			Expect(console.RunCommand(clientVMI, connectToServerCmd(serverIP, highTCPPort), 30*time.Second)).To(Succeed())
+
+			By("Connecting from the client VM to a port not specified on the VM spec")
+			Expect(console.RunCommand(clientVMI, connectToServerCmd(serverIP, highTCPPort+1), 30)).NotTo(Succeed())
+		},
+			Entry("[IPv4]", k8sv1.IPv4Protocol),
+			Entry("[IPv6]", k8sv1.IPv6Protocol),
+		)
+	})
+
+	Context("TCP with low port specification", Ordered, decorators.OncePerOrderedCleanup, func() {
+		var clientVMI *v1.VirtualMachineInstance
+		var serverVMI *v1.VirtualMachineInstance
+
+		const lowTCPPort = 80
+
+		BeforeAll(func() {
+			clientVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithPasstInterfaceWithPort(),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			clientVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), clientVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			ports := []v1.Port{{Name: "http", Port: lowTCPPort, Protocol: "TCP"}}
+			serverVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithInterface(libvmi.InterfaceWithPasstBindingPlugin(ports...)),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			serverVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), serverVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			waitUntilVMIsReady(console.LoginToAlpine, clientVMI, serverVMI)
+
+			vmnetserver.StartTCPServer(serverVMI, lowTCPPort, console.LoginToAlpine)
+			By("starting a TCP server on a port not specified on the VM spec")
+			vmnetserver.StartTCPServer(serverVMI, lowTCPPort+1, console.LoginToAlpine)
+		})
+
+		DescribeTable("connectivity", func(ipFamily k8sv1.IPFamily) {
+			libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
+
+			serverIP := libnet.GetVmiPrimaryIPByFamily(serverVMI, ipFamily)
+			Expect(libnet.PingFromVMConsole(clientVMI, serverIP)).To(Succeed())
+
+			By("Connecting from the client VM")
+			Expect(console.RunCommand(clientVMI, connectToServerCmd(serverIP, lowTCPPort), 30*time.Second)).To(Succeed())
+
+			By("Connecting from the client VM to a port not specified on the VM spec")
+			Expect(console.RunCommand(clientVMI, connectToServerCmd(serverIP, lowTCPPort+1), 30)).NotTo(Succeed())
+		},
+			Entry("[IPv4]", k8sv1.IPv4Protocol),
+			Entry("[IPv6]", k8sv1.IPv6Protocol),
+		)
+	})
+
+	Context("UDP", Ordered, decorators.OncePerOrderedCleanup, func() {
+		var clientVMI *v1.VirtualMachineInstance
+		var serverVMI *v1.VirtualMachineInstance
+
+		const udpPortForIPv4 = 1700
+		const udpPortForIPv6 = 1701
+
+		BeforeAll(func() {
+			var ports = []v1.Port{
+				{Port: udpPortForIPv4, Protocol: "UDP"},
+				{Port: udpPortForIPv6, Protocol: "UDP"},
 			}
 
-			Context("TCP", func() {
-				verifyClientServerConnectivity := func(clientVMI, serverVMI *v1.VirtualMachineInstance, tcpPort int, ipFamily k8sv1.IPFamily) error {
-					serverIP := libnet.GetVmiPrimaryIPByFamily(serverVMI, ipFamily)
-					err := libnet.PingFromVMConsole(clientVMI, serverIP)
-					if err != nil {
-						return err
-					}
+			By("Starting server VMI")
+			serverVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithInterface(libvmi.InterfaceWithPasstBindingPlugin(ports...)),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			serverVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), serverVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
 
-					By("Connecting from the client VM")
-					err = console.RunCommand(clientVMI, connectToServerCmd(serverIP, tcpPort), 30*time.Second)
-					if err != nil {
-						return err
-					}
+			By("Starting client VMI")
+			clientVMI = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithInterface(libvmi.InterfaceWithPasstBindingPlugin()),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			clientVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), clientVMI, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
 
-					return nil
-				}
+			waitUntilVMIsReady(console.LoginToAlpine, serverVMI, clientVMI)
+		})
 
-				startClientVMI := func() {
-					clientVMI = libvmifact.NewAlpineWithTestTooling(
-						libvmi.WithPasstInterfaceWithPort(),
-						libvmi.WithNetwork(v1.DefaultPodNetwork()),
-					)
+		DescribeTable("connectivity", func(udpPort int, ipFamily k8sv1.IPFamily) {
+			libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
 
-					clientVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), clientVMI, metav1.CreateOptions{})
-					Expect(err).ToNot(HaveOccurred())
-					clientVMI = libwait.WaitUntilVMIReady(clientVMI,
-						console.LoginToAlpine,
-						libwait.WithFailOnWarnings(false),
-						libwait.WithTimeout(180),
-					)
-				}
-				DescribeTable("Client server connectivity", func(ports []v1.Port, tcpPort int, ipFamily k8sv1.IPFamily) {
-					libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
+			By("Starting a UDP server")
+			vmnetserver.StartPythonUDPServer(serverVMI, udpPort, ipFamily)
 
-					By("starting a client VMI")
-					startClientVMI()
+			By("Starting and verifying UDP client")
+			// Due to a passt bug, at least one UDPv6 message has to be sent from a machine before it can receive UDPv6 messages
+			// Tracking bug - https://bugs.passt.top/show_bug.cgi?id=16
+			if ipFamily == k8sv1.IPv6Protocol {
+				clientIP := libnet.GetVmiPrimaryIPByFamily(clientVMI, ipFamily)
+				Expect(libnet.PingFromVMConsole(serverVMI, clientIP)).To(Succeed())
+			}
+			serverIP := libnet.GetVmiPrimaryIPByFamily(serverVMI, ipFamily)
+			Expect(startAndVerifyUDPClient(clientVMI, serverIP, udpPort, ipFamily)).To(Succeed())
+		},
+			Entry("[IPv4]", udpPortForIPv4, k8sv1.IPv4Protocol),
+			Entry("[IPv6]", udpPortForIPv6, k8sv1.IPv6Protocol),
+		)
+	})
 
-					By("starting a server VMI")
-					startServerVMI(ports)
+	Context("egress connectivity", Ordered, decorators.OncePerOrderedCleanup, func() {
+		var vmi *v1.VirtualMachineInstance
 
-					By("starting a TCP server")
-					vmnetserver.StartTCPServer(serverVMI, tcpPort, console.LoginToAlpine)
+		BeforeAll(func() {
+			vmi = libvmifact.NewAlpineWithTestTooling(
+				libvmi.WithPasstInterfaceWithPort(),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			vmi, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), vmi, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
 
-					Expect(verifyClientServerConnectivity(clientVMI, serverVMI, tcpPort, ipFamily)).To(Succeed())
-
-					if len(ports) != 0 {
-						By("starting a TCP server on a port not specified on the VM spec")
-						vmPort := int(ports[0].Port)
-						serverIP := libnet.GetVmiPrimaryIPByFamily(serverVMI, ipFamily)
-
-						vmnetserver.StartTCPServer(serverVMI, vmPort+1, console.LoginToAlpine)
-
-						By("Connecting from the client VM to a port not specified on the VM spec")
-						Expect(console.RunCommand(clientVMI, connectToServerCmd(serverIP, tcpPort+1), 30)).NotTo(Succeed())
-					}
-				},
-					Entry("with a specific port number [IPv4]", []v1.Port{{Name: "http", Port: 8080, Protocol: "TCP"}}, 8080, k8sv1.IPv4Protocol),
-					Entry("with a specific lower port number [IPv4]", []v1.Port{{Name: "http", Port: 80, Protocol: "TCP"}}, 80, k8sv1.IPv4Protocol),
-					Entry("without a specific port number [IPv4]", []v1.Port{}, 8080, k8sv1.IPv4Protocol),
-					Entry("with a specific port number [IPv6]", []v1.Port{{Name: "http", Port: 8080, Protocol: "TCP"}}, 8080, k8sv1.IPv6Protocol),
-					Entry("without a specific port number [IPv6]", []v1.Port{}, 8080, k8sv1.IPv6Protocol),
-				)
-			})
-
-			Context("UDP", func() {
-				startAndVerifyUDPClient := func(vmi *v1.VirtualMachineInstance, serverIP string, serverPort int, ipFamily k8sv1.IPFamily) error {
-					var inetSuffix string
-					if ipFamily == k8sv1.IPv6Protocol {
-						inetSuffix = "6"
-					}
-
-					createClientScript := fmt.Sprintf(`cat >udp_client.py <<EOL
-import socket
-try:
-  client = socket.socket(socket.AF_INET%s, socket.SOCK_DGRAM);
-  client.sendto("Hello Server".encode(), ("%s",%d));
-  client.settimeout(5);
-  response = client.recv(1024);
-  print(response.decode("utf-8"));
-
-except socket.timeout:
-    client.close();
-EOL`, inetSuffix, serverIP, serverPort)
-					runClient := "python3 udp_client.py"
-					return console.ExpectBatch(vmi, []expect.Batcher{
-						&expect.BSnd{S: fmt.Sprintf("%s\n", createClientScript)},
-						&expect.BExp{R: console.PromptExpression},
-						&expect.BSnd{S: fmt.Sprintf("%s\n", runClient)},
-						&expect.BExp{R: console.RetValue("Hello Client")},
-						&expect.BSnd{S: console.EchoLastReturnValue},
-						&expect.BExp{R: console.ShellSuccess},
-					}, 60*time.Second)
-				}
-				DescribeTable("Client server connectivity", func(ipFamily k8sv1.IPFamily) {
-					libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
-
-					const SERVER_PORT = 1700
-
-					By("Starting server VMI")
-					startServerVMI([]v1.Port{{Port: SERVER_PORT, Protocol: "UDP"}})
-					serverVMI = libwait.WaitUntilVMIReady(serverVMI,
-						console.LoginToAlpine,
-						libwait.WithFailOnWarnings(false),
-						libwait.WithTimeout(180),
-					)
-
-					By("Starting a UDP server")
-					vmnetserver.StartPythonUDPServer(serverVMI, SERVER_PORT, ipFamily)
-
-					By("Starting client VMI")
-					clientVMI = libvmifact.NewAlpineWithTestTooling(
-						libvmi.WithInterface(libvmi.InterfaceWithPasstBindingPlugin()),
-						libvmi.WithNetwork(v1.DefaultPodNetwork()),
-					)
-					clientVMI, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), clientVMI, metav1.CreateOptions{})
-					Expect(err).ToNot(HaveOccurred())
-					clientVMI = libwait.WaitUntilVMIReady(clientVMI,
-						console.LoginToAlpine,
-						libwait.WithFailOnWarnings(false),
-						libwait.WithTimeout(180),
-					)
-
-					By("Starting and verifying UDP client")
-					// Due to a passt bug, at least one UDPv6 message has to be sent from a machine before it can receive UDPv6 messages
-					// Tracking bug - https://bugs.passt.top/show_bug.cgi?id=16
-					if ipFamily == k8sv1.IPv6Protocol {
-						clientIP := libnet.GetVmiPrimaryIPByFamily(clientVMI, ipFamily)
-						Expect(libnet.PingFromVMConsole(serverVMI, clientIP)).To(Succeed())
-					}
-					serverIP := libnet.GetVmiPrimaryIPByFamily(serverVMI, ipFamily)
-					Expect(startAndVerifyUDPClient(clientVMI, serverIP, SERVER_PORT, ipFamily)).To(Succeed())
-				},
-					Entry("[IPv4]", k8sv1.IPv4Protocol),
-					Entry("[IPv6]", k8sv1.IPv6Protocol),
-				)
-			})
+			waitUntilVMIsReady(console.LoginToAlpine, vmi)
 		})
 
 		It("should be able to reach the outside world [IPv4]", Label("RequiresOutsideConnectivity"), func() {
@@ -285,18 +320,6 @@ EOL`, inetSuffix, serverIP, serverPort)
 				dns = flags.ConnectivityCheckDNS
 			}
 
-			vmi := libvmifact.NewAlpineWithTestTooling(
-				libvmi.WithPasstInterfaceWithPort(),
-				libvmi.WithNetwork(v1.DefaultPodNetwork()),
-			)
-			vmi, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), vmi, metav1.CreateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			vmi = libwait.WaitUntilVMIReady(vmi,
-				console.LoginToAlpine,
-				libwait.WithFailOnWarnings(false),
-				libwait.WithTimeout(180),
-			)
-
 			By("Checking ping (IPv4)")
 			Expect(libnet.PingFromVMConsole(vmi, ipv4Address, "-c 5", "-w 15")).To(Succeed())
 			Expect(libnet.PingFromVMConsole(vmi, dns, "-c 5", "-w 15")).To(Succeed())
@@ -312,33 +335,27 @@ EOL`, inetSuffix, serverIP, serverPort)
 				ipv6Address = flags.IPV6ConnectivityCheckAddress
 			}
 
-			vmi := libvmifact.NewAlpineWithTestTooling(
-				libvmi.WithPasstInterfaceWithPort(),
-				libvmi.WithNetwork(v1.DefaultPodNetwork()),
-				libvmi.WithAnnotation("kubevirt.io/libvirt-log-filters", "3:remote 4:event 3:util.json 3:util.object 3:util.dbus 3:util.netlink 3:node_device 3:rpc 3:access 1:*"),
-			)
-			Expect(err).ToNot(HaveOccurred())
-			vmi, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), vmi, metav1.CreateOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			vmi = libwait.WaitUntilVMIReady(vmi,
-				console.LoginToAlpine,
-				libwait.WithFailOnWarnings(false),
-				libwait.WithTimeout(180),
-			)
-
 			By("Checking ping (IPv6) from VM to cluster nodes gateway")
 			Expect(libnet.PingFromVMConsole(vmi, ipv6Address)).To(Succeed())
 		})
+	})
 
-		DescribeTable("Connectivity should be preserved after migration", func(ipFamily k8sv1.IPFamily) {
-			libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
+	Context("migration", Ordered, decorators.OncePerOrderedCleanup, func() {
+		var migrateVMI *v1.VirtualMachineInstance
+		var anotherVMI *v1.VirtualMachineInstance
 
+		BeforeAll(func() {
 			By("Starting a VMI")
-			migrateVMI := startPasstVMI()
-			beforeMigNodeName := migrateVMI.Status.NodeName
+			migrateVMI = startPasstVMI()
 
 			By("Starting another VMI")
-			anotherVMI := startPasstVMI()
+			anotherVMI = startPasstVMI()
+
+			waitUntilVMIsReady(console.LoginToFedora, migrateVMI, anotherVMI)
+		})
+
+		DescribeTable("connectivity should be preserved", func(ipFamily k8sv1.IPFamily) {
+			libnet.SkipWhenClusterNotSupportIPFamily(ipFamily)
 
 			By("Verify the VMIs can ping each other")
 			migrateVmiBeforeMigIP := libnet.GetVmiPrimaryIPByFamily(migrateVMI, ipFamily)
@@ -346,6 +363,8 @@ EOL`, inetSuffix, serverIP, serverPort)
 			Expect(libnet.PingFromVMConsole(migrateVMI, anotherVmiIP)).To(Succeed())
 			Expect(libnet.PingFromVMConsole(anotherVMI, migrateVmiBeforeMigIP)).To(Succeed())
 
+			beforeMigNodeName := migrateVMI.Status.NodeName
+
 			By("Perform migration")
 			migration := libmigration.New(migrateVMI.Name, migrateVMI.Namespace)
 			migrationUID := libmigration.RunMigrationAndExpectToCompleteWithDefaultTimeout(kubevirt.Client(), migration)
@@ -357,11 +376,11 @@ EOL`, inetSuffix, serverIP, serverPort)
 
 			assertSourcePodContainersTerminate(labelSelector, fieldSelector, migrateVMI)
 
-			By("Verify the VMI new IP is propogated to the status")
+			By("Verify the VMI new IP is propagated to the status")
 			var migrateVmiAfterMigIP string
 			Eventually(func() string {
 				migrateVMI, err = kubevirt.Client().VirtualMachineInstance(migrateVMI.Namespace).Get(context.Background(), migrateVMI.Name, metav1.GetOptions{})
-				Expect(err).ToNot(HaveOccurred(), "should have been able to retrive the VMI instance")
+				Expect(err).ToNot(HaveOccurred(), "should have been able to retrieve the VMI instance")
 				migrateVmiAfterMigIP = libnet.GetVmiPrimaryIPByFamily(migrateVMI, ipFamily)
 				return migrateVmiAfterMigIP
 			}, 30*time.Second).ShouldNot(Equal(migrateVmiBeforeMigIP), "the VMI status should get a new IP after migration")
@@ -371,10 +390,10 @@ EOL`, inetSuffix, serverIP, serverPort)
 			Expect(libnet.PingFromVMConsole(anotherVMI, migrateVmiAfterMigIP)).To(Succeed())
 		},
 			Entry("[IPv4]", k8sv1.IPv4Protocol),
-			Entry("[IPv6]", k8sv1.IPv6Protocol),
+			Entry("[IPv6]", k8sv1.IPv6Protocol, decorators.Quarantine),
 		)
 	})
-})
+}))
 
 func assertSourcePodContainersTerminate(labelSelector, fieldSelector string, vmi *v1.VirtualMachineInstance) bool {
 	return Eventually(func() k8sv1.PodPhase {
@@ -403,14 +422,49 @@ func startPasstVMI() *v1.VirtualMachineInstance {
 	)
 	vmi, err = kubevirt.Client().VirtualMachineInstance(testsuite.GetTestNamespace(nil)).Create(context.Background(), vmi, metav1.CreateOptions{})
 	ExpectWithOffset(1, err).ToNot(HaveOccurred())
-	vmi = libwait.WaitUntilVMIReady(vmi,
-		console.LoginToFedora,
-		libwait.WithFailOnWarnings(false),
-		libwait.WithTimeout(180),
-	)
 	return vmi
 }
 
+func waitUntilVMIsReady(loginTo console.LoginToFunction, vmis ...*v1.VirtualMachineInstance) {
+	for idx, vmi := range vmis {
+		*vmis[idx] = *libwait.WaitUntilVMIReady(
+			vmi,
+			loginTo,
+			libwait.WithFailOnWarnings(false),
+			libwait.WithTimeout(180),
+		)
+	}
+}
+
 func connectToServerCmd(serverIP string, port int) string {
 	return fmt.Sprintf("echo test | nc %s %d -i 1 -w 1 1> /dev/null", serverIP, port)
 }
+
+func startAndVerifyUDPClient(vmi *v1.VirtualMachineInstance, serverIP string, serverPort int, ipFamily k8sv1.IPFamily) error {
+	var inetSuffix string
+	if ipFamily == k8sv1.IPv6Protocol {
+		inetSuffix = "6"
+	}
+
+	createClientScript := fmt.Sprintf(`cat >udp_client.py <<EOL
+import socket
+try:
+  client = socket.socket(socket.AF_INET%s, socket.SOCK_DGRAM);
+  client.sendto("Hello Server".encode(), ("%s",%d));
+  client.settimeout(5);
+  response = client.recv(1024);
+  print(response.decode("utf-8"));
+
+except socket.timeout:
+    client.close();
+EOL`, inetSuffix, serverIP, serverPort)
+	runClient := "python3 udp_client.py"
+	return console.ExpectBatch(vmi, []expect.Batcher{
+		&expect.BSnd{S: fmt.Sprintf("%s\n", createClientScript)},
+		&expect.BExp{R: console.PromptExpression},
+		&expect.BSnd{S: fmt.Sprintf("%s\n", runClient)},
+		&expect.BExp{R: console.RetValue("Hello Client")},
+		&expect.BSnd{S: console.EchoLastReturnValue},
+		&expect.BExp{R: console.ShellSuccess},
+	}, 60*time.Second)
+}
