@@ -42,8 +42,7 @@ import (
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
-var _ = SIGDescribe("interface state up/down", func() {
-
+var _ = Describe(SIG("interface state up/down", func() {
 	It("status and guest should show correct iface state", func() {
 		const (
 			primaryLogicalNetName    = "default"
@@ -88,7 +87,15 @@ var _ = SIGDescribe("interface state up/down", func() {
 		vm, err = kubevirt.Client().VirtualMachine(testNamespace).Create(context.Background(), vm, metav1.CreateOptions{})
 		Expect(err).NotTo(HaveOccurred())
 
-		Eventually(matcher.ThisVM(vm)).WithTimeout(6 * time.Minute).WithPolling(3 * time.Second).Should(matcher.HaveConditionTrue(v1.VirtualMachineInstanceAgentConnected))
+		const (
+			waitForGAConnectedTimout        = 6 * time.Minute
+			waitForGAConnectedRetryInterval = 3 * time.Second
+		)
+
+		Eventually(matcher.ThisVM(vm)).
+			WithTimeout(waitForGAConnectedTimout).
+			WithPolling(waitForGAConnectedRetryInterval).
+			Should(matcher.HaveConditionTrue(v1.VirtualMachineInstanceAgentConnected))
 		vmi, err = kubevirt.Client().VirtualMachineInstance(testNamespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 		Expect(err).ToNot(HaveOccurred())
 		Expect(console.LoginToFedora(vmi)).To(Succeed())
@@ -98,13 +105,14 @@ var _ = SIGDescribe("interface state up/down", func() {
 			{Name: secondary2LogicalNetName, LinkState: string(v1.InterfaceStateLinkDown)},
 		}
 
+		const waitForExpectedIfaceStatusesTimeout = 60 * time.Second
 		Eventually(func() ([]v1.VirtualMachineInstanceNetworkInterface, error) {
-			vmi, err := kubevirt.Client().VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
+			fetchedVMI, err := kubevirt.Client().VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 			if err != nil {
 				return nil, err
 			}
-			return normalizeIfaceStatuses(vmi.Status.Interfaces), nil
-		}).WithTimeout(60 * time.Second).Should(ConsistOf(expectedIfaceStatuses))
+			return normalizeIfaceStatuses(fetchedVMI.Status.Interfaces), nil
+		}).WithTimeout(waitForExpectedIfaceStatusesTimeout).Should(ConsistOf(expectedIfaceStatuses))
 
 		timeout := 5 * time.Second
 		Expect(console.RunCommand(vmi, assertLinkStateCmd(mac1.String(), v1.InterfaceStateLinkUp), timeout)).To(Succeed())
@@ -125,20 +133,18 @@ var _ = SIGDescribe("interface state up/down", func() {
 		}
 
 		Eventually(func() ([]v1.VirtualMachineInstanceNetworkInterface, error) {
-			vmi, err := kubevirt.Client().VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
+			fetchedVMI, err := kubevirt.Client().VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 			if err != nil {
 				return nil, err
 			}
-			return normalizeIfaceStatuses(vmi.Status.Interfaces), nil
-		}).WithTimeout(60 * time.Second).Should(ConsistOf(expectedIfaceStatuses))
+			return normalizeIfaceStatuses(fetchedVMI.Status.Interfaces), nil
+		}).WithTimeout(waitForExpectedIfaceStatusesTimeout).Should(ConsistOf(expectedIfaceStatuses))
 
 		timeout = 30 * time.Second
 		Expect(console.RunCommand(vmi, assertLinkStateCmd(mac1.String(), v1.InterfaceStateLinkDown), timeout)).To(Succeed())
 		Expect(console.RunCommand(vmi, assertLinkStateCmd(mac2.String(), v1.InterfaceStateLinkUp), timeout)).To(Succeed())
-
 	})
-
-})
+}))
 
 func normalizeIfaceStatuses(ifaceStatuses []v1.VirtualMachineInstanceNetworkInterface) []v1.VirtualMachineInstanceNetworkInterface {
 	var result []v1.VirtualMachineInstanceNetworkInterface
@@ -162,7 +168,10 @@ func assertLinkStateCmd(mac string, desiredLinkState v1.InterfaceState) string {
 		linkStateRegex = linkStateUPRegex
 	case v1.InterfaceStateLinkDown:
 		linkStateRegex = linkStateDOWNRegex
+	case v1.InterfaceStateAbsent:
+		// noop
 	}
+
 	return fmt.Sprintf(ipLinkTemplate, mac, linkStateRegex)
 }
 
