@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2021 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -55,7 +55,7 @@ const (
 	vmiCreationToRunningSecondsP95Threshold = 60
 )
 
-var _ = SIGDescribe("Control Plane Performance Density Testing", func() {
+var _ = Describe(SIG("Control Plane Performance Density Testing", func() {
 	var (
 		virtClient kubecli.KubevirtClient
 		startTime  time.Time
@@ -87,7 +87,7 @@ var _ = SIGDescribe("Control Plane Performance Density Testing", func() {
 		vmBatchStartupLimit := 5 * time.Minute
 
 		Context(fmt.Sprintf("[small] create a batch of %d VMIs", vmCount), func() {
-			It("should sucessfully create all VMIS", func() {
+			It("should successfully create all VMIS", func() {
 				By("Creating a batch of VMIs")
 				createBatchVMIWithRateControl(virtClient, vmCount)
 
@@ -98,7 +98,7 @@ var _ = SIGDescribe("Control Plane Performance Density Testing", func() {
 		})
 
 		Context(fmt.Sprintf("[small] create a batch of %d running VMs", vmCount), func() {
-			It("should sucessfully create all VMS", func() {
+			It("should successfully create all VMS", func() {
 				By("Creating a batch of VMs")
 				createBatchRunningVMWithResourcesWithRateControl(virtClient, vmCount)
 
@@ -109,7 +109,7 @@ var _ = SIGDescribe("Control Plane Performance Density Testing", func() {
 		})
 
 		Context(fmt.Sprintf("[small] create a batch of %d running VMs using a single instancetype and preference", vmCount), func() {
-			It("should sucessfully create all VMS with instancetype and preference", func() {
+			It("should successfully create all VMS with instancetype and preference", func() {
 				By("Creating an instancetype and preference for the test")
 				instancetype := createInstancetype(virtClient)
 				preference := createPreference(virtClient)
@@ -123,7 +123,7 @@ var _ = SIGDescribe("Control Plane Performance Density Testing", func() {
 			})
 		})
 	})
-})
+}))
 
 func collectMetrics(startTime time.Time, filepath string) {
 	// ensure the metrics get scraped by Prometheus till the end, since the default Prometheus scrape interval is 30s
