@@ -6,8 +6,8 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	"github.com/onsi/gomega/gmeasure"
 
-	"kubevirt.io/kubevirt/tests"
 	"kubevirt.io/kubevirt/tests/libvmifact"
+	"kubevirt.io/kubevirt/tests/libvmops"
 )
 
 // Replace PDescribe with FDescribe in order to measure if your changes made
@@ -19,7 +19,7 @@ var _ = PDescribe("Ensure stable functionality", func() {
 
 		experiment.Sample(func(idx int) {
 			experiment.MeasureDuration("Create VM", func() {
-				tests.RunVMIAndExpectLaunch(libvmifact.NewCirros(), 30)
+				libvmops.RunVMIAndExpectLaunch(libvmifact.NewCirros(), 30)
 			})
 		}, gmeasure.SamplingConfig{N: 15, Duration: 10 * time.Minute})
 	})
