@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2017 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -24,8 +24,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"math"
-	"os"
-	"path/filepath"
 	"strings"
 	"time"
 
@@ -61,7 +59,6 @@ import (
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 
-	"kubevirt.io/kubevirt/tests/clientcmd"
 	"kubevirt.io/kubevirt/tests/console"
 	cd "kubevirt.io/kubevirt/tests/containerdisk"
 	"kubevirt.io/kubevirt/tests/exec"
@@ -87,7 +84,7 @@ const (
 
 const InvalidDataVolumeUrl = "docker://127.0.0.1/invalid:latest"
 
-var _ = SIGDescribe("DataVolume Integration", func() {
+var _ = Describe(SIG("DataVolume Integration", func() {
 
 	var virtClient kubecli.KubevirtClient
 	var err error
@@ -188,8 +185,13 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 			Expect(console.LoginToCirros(vmi)).To(Succeed())
 
 			By("Expanding PVC")
+			pvc, err := virtClient.CoreV1().PersistentVolumeClaims(dataVolume.Namespace).Get(context.Background(), dataVolume.Name, metav1.GetOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			origSize, exists := pvc.Status.Capacity[k8sv1.ResourceStorage]
+			Expect(exists).To(BeTrue())
+			newSize := *resource.NewQuantity(2*origSize.Value(), origSize.Format)
 			patchSet := patch.New(
-				patch.WithAdd("/spec/resources/requests/storage", resource.MustParse("2Gi")),
+				patch.WithAdd("/spec/resources/requests/storage", newSize),
 			)
 			patchData, err := patchSet.GeneratePayload()
 			Expect(err).ToNot(HaveOccurred())
@@ -204,7 +206,7 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 					&expect.BExp{R: console.PromptExpression},
 					&expect.BSnd{S: "dmesg |grep 'new size'\n"},
 					&expect.BExp{R: console.PromptExpression},
-					&expect.BSnd{S: "dmesg |grep -c 'new size: [34]'\n"},
+					&expect.BSnd{S: "dmesg |grep -c 'new size: [1-9]'\n"},
 					&expect.BExp{R: "1"},
 				}, 10)
 				return err
@@ -606,66 +608,57 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 		})
 	})
 
-	Describe("[rfe_id:896][crit:high][vendor:cnv-qe@redhat.com][level:system] with oc/kubectl", func() {
-		var vm *v1.VirtualMachine
-		var err error
-		var vmJson string
-		var dataVolumeName string
-		var pvcName string
-
-		k8sClient := clientcmd.GetK8sCmdClient()
+	Describe("[rfe_id:3188][crit:high][vendor:cnv-qe@redhat.com][level:system] Starting a VirtualMachine with a DataVolume using http import", func() {
+		var sc string
 
 		BeforeEach(func() {
-			sc, exists := libstorage.GetRWOFileSystemStorageClass()
+			var exists bool
+			sc, exists = libstorage.GetRWOFileSystemStorageClass()
 			if !exists {
 				Fail("Fail test when Filesystem storage is not present")
 			}
-
-			vm = renderVMWithRegistryImportDataVolume(cd.ContainerDiskAlpine, sc)
-			vm.Spec.RunStrategy = pointer.P(v1.RunStrategyAlways)
-
-			dataVolumeName = vm.Spec.DataVolumeTemplates[0].Name
-			pvcName = dataVolumeName
-
-			data, err := json.Marshal(vm)
-			Expect(err).ToNot(HaveOccurred())
-			vmJson = filepath.Join(GinkgoT().TempDir(), fmt.Sprintf("%s.json", vm.Name))
-			Expect(os.WriteFile(vmJson, data, 0644)).To(Succeed())
-			Expect(err).ToNot(HaveOccurred())
 		})
 
-		It("[test_id:836] Creating a VM with DataVolumeTemplates should succeed.", func() {
-			By(creatingVMDataVolumeTemplateEntry)
-			_, _, err = clientcmd.RunCommand(testsuite.GetTestNamespace(nil), k8sClient, "create", "-f", vmJson)
+		It("[test_id:3191]should be successfully started and stopped multiple times", func() {
+			vm := renderVMWithRegistryImportDataVolume(cd.ContainerDiskAlpine, sc)
+			vm, err = virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Create(context.Background(), vm, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
-
-			By(verifyingDataVolumeSuccess)
-			libstorage.EventuallyDVWith(vm.Namespace, dataVolumeName, 100, And(HaveSucceeded(), BeOwned()))
-
-			By(verifyingPVCCreated)
-			Eventually(ThisPVCWith(vm.Namespace, pvcName), 160).Should(Exist())
-
-			By(verifyingVMICreated)
-			Eventually(ThisVMIWith(vm.Namespace, vm.Name), 160).Should(And(BeRunning(), BeOwned()))
+			num := 2
+			By("Starting and stopping the VirtualMachine number of times")
+			for i := 0; i < num; i++ {
+				By(fmt.Sprintf("Doing run: %d", i))
+				vm = libvmops.StartVirtualMachine(vm)
+				// Verify console on last iteration to verify the VirtualMachineInstance is still booting properly
+				// after being restarted multiple times
+				if i == num {
+					By(checkingVMInstanceConsoleExpectedOut)
+					vmi, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
+					Expect(err).ToNot(HaveOccurred())
+					Expect(console.LoginToAlpine(vmi)).To(Succeed())
+				}
+				vm = libvmops.StopVirtualMachine(vm)
+			}
 		})
 
-		It("[test_id:837]deleting VM with cascade=true should automatically delete DataVolumes and VMI owned by VM.", func() {
-			By(creatingVMDataVolumeTemplateEntry)
-			_, _, err = clientcmd.RunCommand(testsuite.GetTestNamespace(nil), k8sClient, "create", "-f", vmJson)
+		It("[test_id:837]deleting VM with background propagation policy should automatically delete DataVolumes and VMI owned by VM.", func() {
+			vm := renderVMWithRegistryImportDataVolume(cd.ContainerDiskAlpine, sc)
+			vm, err = virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Create(context.Background(), vm, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
+			vm = libvmops.StartVirtualMachine(vm)
 
 			By(verifyingDataVolumeSuccess)
-			libstorage.EventuallyDVWith(vm.Namespace, dataVolumeName, 100, And(HaveSucceeded(), BeOwned()))
+			libstorage.EventuallyDVWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name, 100, And(HaveSucceeded(), BeOwned()))
 
 			By(verifyingPVCCreated)
-			Eventually(ThisPVCWith(vm.Namespace, pvcName), 160).Should(Exist())
+			Eventually(ThisPVCWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name), 160).Should(Exist())
 
 			By(verifyingVMICreated)
 			Eventually(ThisVMIWith(vm.Namespace, vm.Name), 160).Should(And(BeRunning(), BeOwned()))
 
-			By("Deleting VM with cascade=true")
-			_, _, err = clientcmd.RunCommand(testsuite.GetTestNamespace(nil), "kubectl", "delete", "vm", vm.Name, "--cascade=true")
-			Expect(err).ToNot(HaveOccurred())
+			By("Deleting VM with background propagation policy")
+			Expect(virtClient.VirtualMachine(vm.Namespace).Delete(context.Background(), vm.Name, metav1.DeleteOptions{
+				PropagationPolicy: pointer.P(metav1.DeletePropagationBackground),
+			})).To(Succeed())
 
 			By("Waiting for the VM to be deleted")
 			Eventually(ThisVM(vm), 100).Should(BeGone())
@@ -674,97 +667,40 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 			Eventually(ThisVMIWith(vm.Namespace, vm.Name), 100).Should(BeGone())
 
 			By("Waiting for the DataVolume to be deleted")
-			Eventually(ThisDVWith(vm.Namespace, dataVolumeName), 100).Should(BeGone())
+			Eventually(ThisDVWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name), 100).Should(BeGone())
 
 			By("Waiting for the PVC to be deleted")
-			Eventually(ThisPVCWith(vm.Namespace, pvcName), 100).Should(BeGone())
+			Eventually(ThisPVCWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name), 100).Should(BeGone())
 		})
 
-		It("[test_id:838]deleting VM with cascade=false should orphan DataVolumes and VMI owned by VM.", func() {
-			_, _, err = clientcmd.RunCommand(testsuite.GetTestNamespace(nil), k8sClient, "create", "-f", vmJson)
-			By(creatingVMDataVolumeTemplateEntry)
+		It("[test_id:3192]should remove owner references on DataVolume if VM is orphan deleted.", func() {
+			vm := renderVMWithRegistryImportDataVolume(cd.ContainerDiskAlpine, sc)
+			vm, err = virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Create(context.Background(), vm, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
+			vm = libvmops.StartVirtualMachine(vm)
 
-			By(verifyingDataVolumeSuccess)
-			libstorage.EventuallyDVWith(vm.Namespace, dataVolumeName, 100, And(HaveSucceeded(), BeOwned()))
+			// Check for owner reference
+			Eventually(ThisDVWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name), 100).Should(BeOwned())
 
-			By(verifyingPVCCreated)
-			Eventually(ThisPVCWith(vm.Namespace, pvcName), 160).Should(Exist())
+			// Delete the VM with orphan Propagation
+			Expect(virtClient.VirtualMachine(vm.Namespace).Delete(context.Background(), vm.Name, metav1.DeleteOptions{
+				PropagationPolicy: pointer.P(metav1.DeletePropagationOrphan),
+			})).To(Succeed())
 
-			By(verifyingVMICreated)
-			Eventually(ThisVMIWith(vm.Namespace, vm.Name), 160).Should(And(BeRunning(), BeOwned()))
-
-			By("Deleting VM with cascade=false")
-			_, _, err = clientcmd.RunCommand(testsuite.GetTestNamespace(nil), "kubectl", "delete", "vm", vm.Name, "--cascade=false")
-			Expect(err).ToNot(HaveOccurred())
-
-			By("Waiting for the VM to be deleted")
+			// Wait for the VM to be deleted
 			Eventually(ThisVM(vm), 100).Should(BeGone())
 
-			By("Verifying DataVolume still exists with owner references removed")
-			libstorage.EventuallyDVWith(vm.Namespace, dataVolumeName, 100, And(HaveSucceeded(), Not(BeOwned())))
+			// Wait for the owner reference to disappear
+			libstorage.EventuallyDVWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name, 100, And(HaveSucceeded(), Not(BeOwned())))
 
-			By("Verifying VMI still exists with owner references removed")
+			// Verify VMI still exists with owner references removed
 			Consistently(ThisVMIWith(vm.Namespace, vm.Name), 60, 1).Should(And(BeRunning(), Not(BeOwned())))
 		})
-
-	})
-
-	Describe("[rfe_id:3188][crit:high][vendor:cnv-qe@redhat.com][level:system] Starting a VirtualMachine with a DataVolume", func() {
-		Context("using Alpine http import", func() {
-			It("[test_id:3191]should be successfully started and stopped multiple times", func() {
-				sc, exists := libstorage.GetRWOFileSystemStorageClass()
-				if !exists {
-					Fail("Fail test when Filesystem storage is not present")
-				}
-
-				vm := renderVMWithRegistryImportDataVolume(cd.ContainerDiskAlpine, sc)
-				vm, err = virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Create(context.Background(), vm, metav1.CreateOptions{})
-				Expect(err).ToNot(HaveOccurred())
-				num := 2
-				By("Starting and stopping the VirtualMachine number of times")
-				for i := 0; i < num; i++ {
-					By(fmt.Sprintf("Doing run: %d", i))
-					vm = libvmops.StartVirtualMachine(vm)
-					// Verify console on last iteration to verify the VirtualMachineInstance is still booting properly
-					// after being restarted multiple times
-					if i == num {
-						By(checkingVMInstanceConsoleExpectedOut)
-						vmi, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
-						Expect(err).ToNot(HaveOccurred())
-						Expect(console.LoginToAlpine(vmi)).To(Succeed())
-					}
-					vm = libvmops.StopVirtualMachine(vm)
-				}
-			})
-
-			It("[test_id:3192]should remove owner references on DataVolume if VM is orphan deleted.", func() {
-				sc, exists := libstorage.GetRWOFileSystemStorageClass()
-				if !exists {
-					Fail("Fail test when Filesystem storage is not present")
-				}
-
-				vm := renderVMWithRegistryImportDataVolume(cd.ContainerDiskAlpine, sc)
-				vm, err = virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Create(context.Background(), vm, metav1.CreateOptions{})
-				Expect(err).ToNot(HaveOccurred())
-
-				// Check for owner reference
-				Eventually(ThisDVWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name), 100).Should(BeOwned())
-
-				// Delete the VM with orphan Propagation
-				orphanPolicy := metav1.DeletePropagationOrphan
-				Expect(virtClient.VirtualMachine(vm.Namespace).
-					Delete(context.Background(), vm.Name, metav1.DeleteOptions{PropagationPolicy: &orphanPolicy})).To(Succeed())
-
-				// Wait for the owner reference to disappear
-				Eventually(ThisDVWith(vm.Namespace, vm.Spec.DataVolumeTemplates[0].Name), 100).Should(Not(BeOwned()))
-			})
-		})
 	})
 
 	Describe("[rfe_id:3188][crit:high][vendor:cnv-qe@redhat.com][level:system] DataVolume clone permission checking", func() {
 		Context("using Alpine import/clone", decorators.RequiresSnapshotStorageClass, func() {
-			var dataVolume *cdiv1.DataVolume
+			var sourceDV *cdiv1.DataVolume
 			var cloneRole *rbacv1.Role
 			var cloneRoleBinding *rbacv1.RoleBinding
 			var storageClass string
@@ -777,30 +713,33 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 					Fail("Failing test, no VolumeSnapshot support")
 				}
 
-				dataVolume = libdv.NewDataVolume(
+				sourceDV = libdv.NewDataVolume(
 					libdv.WithRegistryURLSourceAndPullMethod(cd.DataVolumeImportUrlForContainerDisk(cd.ContainerDiskAlpine), cdiv1.RegistryPullNode),
 					libdv.WithStorage(libdv.StorageWithStorageClass(storageClass)),
 					libdv.WithForceBindAnnotation(),
 				)
-
-				dataVolume, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(testsuite.NamespaceTestAlternative).Create(context.Background(), dataVolume, metav1.CreateOptions{})
+				sourceDV, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(testsuite.NamespaceTestAlternative).Create(context.Background(), sourceDV, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
-				libstorage.EventuallyDV(dataVolume, 90, HaveSucceeded())
+				libstorage.EventuallyDV(sourceDV, 90, HaveSucceeded())
 
-				vm = renderVMWithCloneDataVolume(testsuite.NamespaceTestAlternative, dataVolume.Name, testsuite.GetTestNamespace(nil), storageClass)
+				dv := libdv.NewDataVolume(
+					libdv.WithNamespace(testsuite.GetTestNamespace(nil)),
+					libdv.WithPVCSource(testsuite.NamespaceTestAlternative, sourceDV.Name),
+					libdv.WithStorage(
+						libdv.StorageWithStorageClass(storageClass),
+						libdv.StorageWithoutVolumeSize(),
+					),
+				)
 
-				const volumeName = "sa"
-				saVol := v1.Volume{
-					Name: volumeName,
-					VolumeSource: v1.VolumeSource{
-						ServiceAccount: &v1.ServiceAccountVolumeSource{
-							ServiceAccountName: testsuite.AdminServiceAccountName,
-						},
-					},
-				}
-				vm.Spec.DataVolumeTemplates[0].Spec.Storage.StorageClassName = pointer.P(storageClass)
-				vm.Spec.Template.Spec.Volumes = append(vm.Spec.Template.Spec.Volumes, saVol)
-				vm.Spec.Template.Spec.Domain.Devices.Disks = append(vm.Spec.Template.Spec.Domain.Devices.Disks, v1.Disk{Name: volumeName})
+				vm = libvmi.NewVirtualMachine(
+					libvmi.New(
+						libvmi.WithNamespace(testsuite.GetTestNamespace(nil)),
+						libvmi.WithResourceMemory("1Mi"),
+						libvmi.WithDataVolume("disk0", dv.Name),
+						libvmi.WithServiceAccountDisk(testsuite.AdminServiceAccountName),
+					),
+					libvmi.WithDataVolumeTemplate(dv),
+				)
 			})
 
 			AfterEach(func() {
@@ -881,6 +820,9 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 
 				// set the target DV size to the snapshot restore size if it is not zero
 				if !snap.Status.RestoreSize.IsZero() {
+					if dvt.Spec.Storage.Resources.Requests == nil {
+						dvt.Spec.Storage.Resources.Requests = k8sv1.ResourceList{}
+					}
 					dvt.Spec.Storage.Resources.Requests[k8sv1.ResourceStorage] = *snap.Status.RestoreSize
 				}
 			}
@@ -971,14 +913,14 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 				)
 
 				// We first delete the source PVC and DataVolume to force a clone without source
-				err := virtClient.CdiClient().CdiV1beta1().DataVolumes(testsuite.NamespaceTestAlternative).Delete(context.Background(), dataVolume.Name, metav1.DeleteOptions{})
+				err := virtClient.CdiClient().CdiV1beta1().DataVolumes(testsuite.NamespaceTestAlternative).Delete(context.Background(), sourceDV.Name, metav1.DeleteOptions{})
 				Expect(err).To(Or(
 					Not(HaveOccurred()),
 					Satisfy(errors.IsNotFound),
 				))
-				Eventually(ThisPVCWith(testsuite.NamespaceTestAlternative, dataVolume.Name), 10*time.Second, 1*time.Second).Should(BeGone())
+				Eventually(ThisPVCWith(testsuite.NamespaceTestAlternative, sourceDV.Name), 10*time.Second, 1*time.Second).Should(BeGone())
 
-				// We check if the VM is succesfully created
+				// We check if the VM is successfully created
 				By("Creating VM")
 				Eventually(func() error {
 					_, err = virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, metav1.CreateOptions{})
@@ -1277,7 +1219,7 @@ var _ = SIGDescribe("DataVolume Integration", func() {
 			Expect(*vm.Spec.DataVolumeTemplates[0].Spec.Storage.StorageClassName).NotTo(Equal(virtualMachinePreference.Spec.Volumes.PreferredStorageClassName))
 		})
 	})
-})
+}))
 
 var explicitCloneRole = &rbacv1.Role{
 	ObjectMeta: metav1.ObjectMeta{
@@ -1388,15 +1330,6 @@ func volumeExpansionAllowed(sc string) bool {
 		*storageClass.AllowVolumeExpansion
 }
 
-func renderVMWithCloneDataVolume(sourceNamespace, sourceName, targetNamespace, sc string) *v1.VirtualMachine {
-	dv := libdv.NewDataVolume(
-		libdv.WithNamespace(testsuite.GetTestNamespace(nil)),
-		libdv.WithPVCSource(sourceNamespace, sourceName),
-		libdv.WithStorage(libdv.StorageWithStorageClass(sc), libdv.StorageWithVolumeSize("1Gi")),
-	)
-	return libstorage.RenderVMWithDataVolumeTemplate(dv)
-}
-
 func renderVMWithRegistryImportDataVolume(containerDisk cd.ContainerDisk, storageClass string) *v1.VirtualMachine {
 	importUrl := cd.DataVolumeImportUrlForContainerDisk(containerDisk)
 	dv := libdv.NewDataVolume(
