@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2022 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -115,7 +115,7 @@ var (
 	})
 )
 
-var _ = SIGDescribe("Export", func() {
+var _ = Describe(SIG("Export", func() {
 	var err error
 	var token *k8sv1.Secret
 	var virtClient kubecli.KubevirtClient
@@ -218,6 +218,10 @@ var _ = SIGDescribe("Export", func() {
 			pod.Spec.SecurityContext = &k8sv1.PodSecurityContext{}
 		}
 		pod.Spec.SecurityContext.FSGroup = &qemuGid
+		// Drop this when we stop testing "local"
+		// The in tree driver for local PVs skips chown/chmod if two pods using the volume overlap
+		// https://github.com/kubernetes/kubernetes/blob/0d9dccfc6bc22f2370650cf5b8ad99cbba74ea23/pkg/volume/local/local.go#L611
+		pod.Spec.SecurityContext.RunAsUser = &qemuGid
 
 		volumeMode := pvc.Spec.VolumeMode
 		if volumeMode != nil && *volumeMode == k8sv1.PersistentVolumeBlock {
@@ -297,6 +301,7 @@ var _ = SIGDescribe("Export", func() {
 
 		pod, err := createSourcePodChecker(pvc)
 		Expect(err).ToNot(HaveOccurred())
+		Eventually(ThisPod(pod), 30*time.Second, 1*time.Second).Should(HaveConditionTrue(k8sv1.PodReady))
 
 		fileName := filepath.Join(dataPath, diskImage)
 		if volumeMode == k8sv1.PersistentVolumeBlock {
@@ -306,7 +311,11 @@ var _ = SIGDescribe("Export", func() {
 		Eventually(func() error {
 			out, stderr, err = exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, md5Command(fileName))
 			return err
-		}, 15*time.Second, 1*time.Second).Should(BeNil(), "md5sum command should succeed", out, stderr)
+		}, 15*time.Second, 1*time.Second).Should(Succeed(), func() string {
+			permissionsCmd := []string{"ls", "-laZ", fileName}
+			lsout, lserr, _ := exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, permissionsCmd)
+			return fmt.Sprintf("md5sum command should succeed; out: %s stderr: %s\npermissions ATM lsout: %s lserr: %s", out, stderr, lsout, lserr)
+		})
 		md5sum := strings.Split(out, " ")[0]
 		Expect(md5sum).To(HaveLen(32))
 
@@ -340,7 +349,7 @@ var _ = SIGDescribe("Export", func() {
 			fileAndPathName = blockVolumeMountPath
 		}
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(downloadPod, downloadPod.Spec.Containers[0].Name, md5Command(fileAndPathName))
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		md5sum := strings.Split(out, " ")[0]
 		Expect(md5sum).To(HaveLen(32))
 		Expect(md5sum).To(Equal(expectedMD5))
@@ -353,7 +362,7 @@ var _ = SIGDescribe("Export", func() {
 			filepath.Join(dataPath, fileName),
 		}
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(downloadPod, downloadPod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 
 		fileName = strings.Replace(fileName, ".gz", "", 1)
 		fileAndPathName := filepath.Join(dataPath, fileName)
@@ -361,7 +370,7 @@ var _ = SIGDescribe("Export", func() {
 			fileAndPathName = blockVolumeMountPath
 		}
 		out, stderr, err = exec.ExecuteCommandOnPodWithResults(downloadPod, downloadPod.Spec.Containers[0].Name, md5Command(fileAndPathName))
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		md5sum := strings.Split(out, " ")[0]
 		Expect(md5sum).To(HaveLen(32))
 		Expect(md5sum).To(Equal(expectedMD5))
@@ -380,14 +389,14 @@ var _ = SIGDescribe("Export", func() {
 			"./" + extractedFileName,
 		}
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(downloadPod, downloadPod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 
 		fileAndPathName := filepath.Join(dataPath, extractedFileName)
 		if volumeMode == k8sv1.PersistentVolumeBlock {
 			fileAndPathName = blockVolumeMountPath
 		}
 		out, stderr, err = exec.ExecuteCommandOnPodWithResults(downloadPod, downloadPod.Spec.Containers[0].Name, md5Command(fileAndPathName))
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		md5sum := strings.Split(out, " ")[0]
 		Expect(md5sum).To(HaveLen(32))
 		Expect(md5sum).To(Equal(expectedMD5))
@@ -564,7 +573,7 @@ var _ = SIGDescribe("Export", func() {
 		By(fmt.Sprintf("Downloading from URL: %s", downloadUrl))
 		Eventually(ThisPod(downloadPod), 30*time.Second, 1*time.Second).Should(HaveConditionTrue(k8sv1.PodReady))
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(downloadPod, downloadPod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 
 		verifyFunction(fileName, comparison, downloadPod, volumeMode)
 	},
@@ -586,7 +595,7 @@ var _ = SIGDescribe("Export", func() {
 		command := append([]string{"/usr/bin/tar", "-xvzf", archivePath, "-C", "./data"}, expectedDirs...)
 		time.Sleep(time.Second * 20)
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		for _, dir := range expectedDirs {
 			Expect(out).To(ContainSubstring(dir), fmt.Sprintf("Expected directory %q in archive", dir))
 		}
@@ -685,7 +694,7 @@ var _ = SIGDescribe("Export", func() {
 		}
 
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(downloadPod, downloadPod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 
 		// Verify contents of the downloaded archive
 		By("Verifying the contents of the downloaded archive")
@@ -938,7 +947,7 @@ var _ = SIGDescribe("Export", func() {
 		Expect(*export.Status.TokenSecretRef).To(Equal(token.Name))
 	})
 
-	It("should be possibe to observe exportserver pod exiting", func() {
+	It("should be possible to observe exportserver pod exiting", func() {
 		sc, exists := libstorage.GetRWOFileSystemStorageClass()
 		if !exists {
 			Fail("Fail test when Filesystem storage is not present")
@@ -1713,7 +1722,7 @@ var _ = SIGDescribe("Export", func() {
 		}
 
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		split := strings.Split(out, "\n---\n")
 		Expect(split).To(HaveLen(3))
 		resCM := &k8sv1.ConfigMap{}
@@ -1741,7 +1750,7 @@ var _ = SIGDescribe("Export", func() {
 			url,
 		}
 		out, stderr, err = exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		split = strings.Split(out, "\n---\n")
 		Expect(split).To(HaveLen(2))
 		resSecret := &k8sv1.Secret{}
@@ -1771,7 +1780,7 @@ var _ = SIGDescribe("Export", func() {
 		}
 
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		list := &k8sv1.List{}
 		err = json.Unmarshal([]byte(out), list)
 		Expect(err).ToNot(HaveOccurred())
@@ -1804,7 +1813,7 @@ var _ = SIGDescribe("Export", func() {
 			url,
 		}
 		out, stderr, err = exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		resSecret := &k8sv1.Secret{}
 		err = yaml.Unmarshal([]byte(out), resSecret)
 		Expect(err).ToNot(HaveOccurred())
@@ -2015,7 +2024,7 @@ var _ = SIGDescribe("Export", func() {
 		}
 
 		out, stderr, err := exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		split := strings.Split(out, "\n---\n")
 		Expect(split).To(HaveLen(5))
 		resCM := &k8sv1.ConfigMap{}
@@ -2061,7 +2070,7 @@ var _ = SIGDescribe("Export", func() {
 			url,
 		}
 		out, stderr, err = exec.ExecuteCommandOnPodWithResults(pod, pod.Spec.Containers[0].Name, command)
-		Expect(err).ToNot(HaveOccurred(), out, stderr)
+		Expect(err).ToNot(HaveOccurred(), "out: %s stderr: %s", out, stderr)
 		split = strings.Split(out, "\n---\n")
 		Expect(split).To(HaveLen(2))
 		resSecret := &k8sv1.Secret{}
@@ -2195,7 +2204,7 @@ var _ = SIGDescribe("Export", func() {
 			Expect(postCertParamms).ToNot(Equal(preCertParamms))
 		})
 	})
-})
+}))
 
 func logToGinkgoWritter(format string, parameters ...interface{}) {
 	_, _ = fmt.Fprintf(GinkgoWriter, format, parameters...)
