@@ -6,6 +6,8 @@ import (
 	"time"
 
 	"kubevirt.io/kubevirt/tests/decorators"
+	"kubevirt.io/kubevirt/tests/events"
+	kvconfig "kubevirt.io/kubevirt/tests/libkubevirt/config"
 	"kubevirt.io/kubevirt/tests/libvmops"
 	"kubevirt.io/kubevirt/tests/watcher"
 
@@ -28,6 +30,7 @@ import (
 	libvmici "kubevirt.io/kubevirt/pkg/libvmi/cloudinit"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	virtpointer "kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
@@ -57,7 +60,7 @@ const (
 	notReady                 = "Not ready"
 )
 
-var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
+var _ = Describe(SIG("VirtualMachineSnapshot Tests", func() {
 
 	var (
 		err        error
@@ -335,40 +338,21 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			}
 
 			It("[test_id:6767]with volumes and guest agent available", decorators.StorageCritical, func() {
-				quantity, err := resource.ParseQuantity("1Gi")
-				Expect(err).ToNot(HaveOccurred())
-				vmi := libvmifact.NewFedora(libnet.WithMasqueradeNetworking())
-				vmi.Namespace = testsuite.GetTestNamespace(nil)
-				vm = libvmi.NewVirtualMachine(vmi)
-				dvName := "dv-" + vm.Name
-				dataVolume := libdv.NewDataVolume(
-					libdv.WithName(dvName),
+				dv := libdv.NewDataVolume(
 					libdv.WithBlankImageSource(),
-					libdv.WithStorage(
-						libdv.StorageWithStorageClass(snapshotStorageClass),
-						libdv.StorageWithVolumeSize(quantity.String()),
+					libdv.WithStorage(libdv.StorageWithStorageClass(snapshotStorageClass)),
+				)
+				vm, vmi := createAndStartVM(
+					libvmi.NewVirtualMachine(
+						libvmifact.NewFedora(
+							libvmi.WithNamespace(testsuite.GetTestNamespace(nil)),
+							libnet.WithMasqueradeNetworking(),
+							libvmi.WithDataVolume("blank", dv.Name),
+						),
+						libvmi.WithDataVolumeTemplate(dv),
 					),
 				)
-				libstorage.AddDataVolumeTemplate(vm, dataVolume)
 
-				vm.Spec.Template.Spec.Domain.Devices.Disks = append(vm.Spec.Template.Spec.Domain.Devices.Disks, v1.Disk{
-					Name: "blank",
-					DiskDevice: v1.DiskDevice{
-						Disk: &v1.DiskTarget{
-							Bus: v1.DiskBusVirtio,
-						},
-					},
-				})
-				vm.Spec.Template.Spec.Volumes = append(vm.Spec.Template.Spec.Volumes, v1.Volume{
-					Name: "blank",
-					VolumeSource: v1.VolumeSource{
-						DataVolume: &v1.DataVolumeSource{
-							Name: "dv-" + vm.Name,
-						},
-					},
-				})
-
-				vm, vmi = createAndStartVM(vm)
 				libwait.WaitForSuccessfulVMIStart(vmi,
 					libwait.WithTimeout(300),
 				)
@@ -404,39 +388,23 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			})
 
 			It("[test_id:6768]with volumes and no guest agent available", decorators.StorageCritical, func() {
-				quantity, err := resource.ParseQuantity("1Gi")
-				Expect(err).ToNot(HaveOccurred())
-				vmi := libvmifact.NewAlpine(libnet.WithMasqueradeNetworking())
-				vmi.Namespace = testsuite.GetTestNamespace(nil)
-				vm = libvmi.NewVirtualMachine(vmi)
-				dvName := "dv-" + vm.Name
-				dataVolume := libdv.NewDataVolume(
-					libdv.WithName(dvName),
+				dv := libdv.NewDataVolume(
 					libdv.WithBlankImageSource(),
 					libdv.WithStorage(
 						libdv.StorageWithStorageClass(snapshotStorageClass),
-						libdv.StorageWithVolumeSize(quantity.String()),
 					),
 				)
-				libstorage.AddDataVolumeTemplate(vm, dataVolume)
-				vm.Spec.Template.Spec.Domain.Devices.Disks = append(vm.Spec.Template.Spec.Domain.Devices.Disks, v1.Disk{
-					Name: "blank",
-					DiskDevice: v1.DiskDevice{
-						Disk: &v1.DiskTarget{
-							Bus: v1.DiskBusVirtio,
-						},
-					},
-				})
-				vm.Spec.Template.Spec.Volumes = append(vm.Spec.Template.Spec.Volumes, v1.Volume{
-					Name: "blank",
-					VolumeSource: v1.VolumeSource{
-						DataVolume: &v1.DataVolumeSource{
-							Name: "dv-" + vm.Name,
-						},
-					},
-				})
+				vm, vmi := createAndStartVM(
+					libvmi.NewVirtualMachine(
+						libvmifact.NewAlpine(
+							libvmi.WithNamespace(testsuite.GetTestNamespace(nil)),
+							libnet.WithMasqueradeNetworking(),
+							libvmi.WithDataVolume("blank", dv.Name),
+						),
+						libvmi.WithDataVolumeTemplate(dv),
+					),
+				)
 
-				vm, vmi = createAndStartVM(vm)
 				libwait.WaitForSuccessfulVMIStart(vmi,
 					libwait.WithTimeout(300),
 				)
@@ -563,7 +531,12 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				}, 30*time.Second, 2*time.Second).Should(BeEmpty())
 			})
 
-			It("[test_id:7472]should succeed online snapshot with hot plug disk", func() {
+			DescribeTable("should succeed online snapshot with hot plug disk", func(withEphemeralHotplug bool) {
+				if withEphemeralHotplug {
+					kvconfig.DisableFeatureGate(featuregate.DeclarativeHotplugVolumesGate)
+					kvconfig.EnableFeatureGate(featuregate.HotplugVolumesGate)
+				}
+
 				var vmi *v1.VirtualMachineInstance
 				vm = renderVMWithRegistryImportDataVolume(cd.ContainerDiskFedoraTestTooling, snapshotStorageClass)
 				vm, vmi = createAndStartVM(vm)
@@ -572,8 +545,11 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 
 				By("Add persistent hotplug disk")
 				persistVolName := AddVolumeAndVerify(virtClient, snapshotStorageClass, vm, false)
-				By("Add temporary hotplug disk")
-				tempVolName := AddVolumeAndVerify(virtClient, snapshotStorageClass, vm, true)
+				var tempVolName string
+				if withEphemeralHotplug {
+					By("Add temporary hotplug disk")
+					tempVolName = AddVolumeAndVerify(virtClient, snapshotStorageClass, vm, true)
+				}
 				By("Create Snapshot")
 				snapshot = libstorage.NewSnapshot(vm.Name, vm.Namespace)
 				_, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, metav1.CreateOptions{})
@@ -633,7 +609,10 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 					}
 					Expect(found).To(BeTrue())
 				}
-			})
+			},
+				Entry("[test_id:7472] with ephemeral hotplug disk", Serial, true),
+				Entry("without ephemeral hotplug disk", false),
+			)
 
 			It("should report appropriate event when freeze fails", func() {
 				// Activate SELinux and reboot machine so we can force fsfreeze failure
@@ -1149,7 +1128,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			})))
 		})
 
-		It("snapshot create before source wait for volume bound, then continues, succeeds and then should not fail", func() {
+		It("snapshot create before source wait for volume bound, then continues and succeeds", func() {
 			wffc := libstorage.IsStorageClassBindingModeWaitForFirstConsumer(snapshotStorageClass)
 			// Stand alone dv
 			dv := libdv.NewDataVolume(
@@ -1184,9 +1163,8 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			By("Create Snapshot before source VM")
 			webhook = createDenyVolumeSnapshotCreateWebhook(virtClient, vm.Name)
 			snapshot = libstorage.NewSnapshot(vm.Name, vm.Namespace)
-			snapshot.Spec.FailureDeadline = &metav1.Duration{Duration: time.Minute}
 
-			_, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, metav1.CreateOptions{})
+			snapshot, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
 
 			By("Wait Snapshot conditions to reflect source doesnt exist")
@@ -1260,6 +1238,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 
 			Expect(snapshot.Status.CreationTime).To(BeNil())
 
+			events.ExpectEvent(snapshot, corev1.EventTypeNormal, "SuccessfulVirtualMachineSnapshotContentCreate")
 			contentName := fmt.Sprintf("%s-%s", vmSnapshotContent, snapshot.UID)
 			content, err := virtClient.VirtualMachineSnapshotContent(vm.Namespace).Get(context.Background(), contentName, metav1.GetOptions{})
 			Expect(err).ToNot(HaveOccurred())
@@ -1270,18 +1249,13 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			snapshot = libstorage.WaitSnapshotSucceeded(virtClient, vm.Namespace, snapshot.Name)
 
 			Expect(snapshot.Status.CreationTime).ToNot(BeNil())
+			Expect(snapshot.Status.SnapshotVolumes.IncludedVolumes).Should(HaveLen(2))
 			content, err = virtClient.VirtualMachineSnapshotContent(vm.Namespace).Get(context.Background(), contentName, metav1.GetOptions{})
 			Expect(err).ToNot(HaveOccurred())
 
 			Expect(*content.Spec.VirtualMachineSnapshotName).To(Equal(snapshot.Name))
 			Expect(content.Spec.Source.VirtualMachine.Spec).To(Equal(vm.Spec))
 			Expect(content.Spec.VolumeBackups).Should(HaveLen(len(vm.Spec.Template.Spec.Volumes)))
-
-			// Sleep to pass the time of the deadline
-			time.Sleep(time.Second)
-			// If snapshot succeeded it should not change to failure when deadline exceeded
-			Expect(snapshot.Status.Phase).To(Equal(snapshotv1.Succeeded))
-			Expect(snapshot.Status.SnapshotVolumes.IncludedVolumes).Should(HaveLen(2))
 		})
 
 		Context("with independent DataVolume", func() {
@@ -1493,7 +1467,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 
 			DescribeTable("Bug #8435 - should create a snapshot successfully", decorators.StorageCritical, func(toRunSourceVM bool) {
 				if !toRunSourceVM {
-					By("Stoping the VM")
+					By("Stopping the VM")
 					vm = libvmops.StopVirtualMachine(vm)
 				}
 
@@ -1508,7 +1482,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			)
 		})
 	})
-})
+}))
 
 func AddVolumeAndVerify(virtClient kubecli.KubevirtClient, storageClass string, vm *v1.VirtualMachine, addVMIOnly bool) string {
 	dv := libdv.NewDataVolume(
@@ -1594,7 +1568,7 @@ func createDenyVolumeSnapshotCreateWebhook(virtClient kubecli.KubevirtClient, vm
 				ClientConfig: admissionregistrationv1.WebhookClientConfig{
 					Service: &admissionregistrationv1.ServiceReference{
 						Namespace: testsuite.GetTestNamespace(nil),
-						Name:      "nonexistant",
+						Name:      "nonexistent",
 						Path:      &whPath,
 					},
 				},
