@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2022 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -24,6 +24,7 @@ import (
 	"fmt"
 
 	. "github.com/onsi/ginkgo/v2"
+	. "github.com/onsi/gomega"
 
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 
@@ -31,8 +32,6 @@ import (
 	rbacv1 "k8s.io/api/rbac/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-
-	"kubevirt.io/kubevirt/tests/util"
 )
 
 const (
@@ -46,7 +45,7 @@ const (
 )
 
 // As our tests run in parallel we need to ensure each worker creates a
-// unique clusterRoleBinding to avoid cleaning up anothers prematurely
+// unique clusterRoleBinding to avoid cleaning up objects belonging to other tests prematurely
 func getClusterRoleBindingName(saName string) string {
 	return fmt.Sprintf("%s-%d", saName, GinkgoParallelProcess())
 }
@@ -88,16 +87,14 @@ func createServiceAccount(saName string) {
 	sa := k8sv1.ServiceAccount{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: saName,
-			Labels: map[string]string{
-				util.KubevirtIoTest: saName,
-			},
 		},
 	}
 
 	_, err := virtCli.CoreV1().ServiceAccounts(GetTestNamespace(nil)).Create(context.Background(), &sa, metav1.CreateOptions{})
-	if !k8serrors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsAlreadyExists, "k8serrors.IsAlreadyExists"),
+	))
 
 	secret := k8sv1.Secret{
 		ObjectMeta: metav1.ObjectMeta{
@@ -110,9 +107,10 @@ func createServiceAccount(saName string) {
 	}
 
 	_, err = virtCli.CoreV1().Secrets(GetTestNamespace(nil)).Create(context.Background(), &secret, metav1.CreateOptions{})
-	if !k8serrors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsAlreadyExists, "k8serrors.IsAlreadyExists"),
+	))
 }
 
 func createClusterRoleBinding(saName string, clusterRole string) {
@@ -121,9 +119,6 @@ func createClusterRoleBinding(saName string, clusterRole string) {
 	clusterRoleBinding := rbacv1.ClusterRoleBinding{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: getClusterRoleBindingName(saName),
-			Labels: map[string]string{
-				util.KubevirtIoTest: saName,
-			},
 		},
 		RoleRef: rbacv1.RoleRef{
 			Kind:     "ClusterRole",
@@ -140,9 +135,10 @@ func createClusterRoleBinding(saName string, clusterRole string) {
 	}
 
 	_, err := virtCli.RbacV1().ClusterRoleBindings().Create(context.Background(), &clusterRoleBinding, metav1.CreateOptions{})
-	if !k8serrors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsAlreadyExists, "k8serrors.IsAlreadyExists"),
+	))
 }
 
 func createRoleBinding(saName string, clusterRole string) {
@@ -151,9 +147,6 @@ func createRoleBinding(saName string, clusterRole string) {
 	roleBinding := rbacv1.RoleBinding{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: saName,
-			Labels: map[string]string{
-				util.KubevirtIoTest: saName,
-			},
 		},
 		RoleRef: rbacv1.RoleRef{
 			Kind:     "ClusterRole",
@@ -170,9 +163,10 @@ func createRoleBinding(saName string, clusterRole string) {
 	}
 
 	_, err := virtCli.RbacV1().RoleBindings(GetTestNamespace(nil)).Create(context.Background(), &roleBinding, metav1.CreateOptions{})
-	if !k8serrors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsAlreadyExists, "k8serrors.IsAlreadyExists"),
+	))
 }
 
 func createSubresourceRole(saName string) {
@@ -181,9 +175,6 @@ func createSubresourceRole(saName string) {
 	role := rbacv1.Role{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: saName,
-			Labels: map[string]string{
-				util.KubevirtIoTest: saName,
-			},
 		},
 		Rules: []rbacv1.PolicyRule{
 			{
@@ -195,16 +186,14 @@ func createSubresourceRole(saName string) {
 	}
 
 	_, err := virtCli.RbacV1().Roles(GetTestNamespace(nil)).Create(context.Background(), &role, metav1.CreateOptions{})
-	if !k8serrors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsAlreadyExists, "k8serrors.IsAlreadyExists"),
+	))
 
 	roleBinding := rbacv1.RoleBinding{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: saName,
-			Labels: map[string]string{
-				util.KubevirtIoTest: saName,
-			},
 		},
 		RoleRef: rbacv1.RoleRef{
 			Kind:     "Role",
@@ -221,36 +210,42 @@ func createSubresourceRole(saName string) {
 	}
 
 	_, err = virtCli.RbacV1().RoleBindings(GetTestNamespace(nil)).Create(context.Background(), &roleBinding, metav1.CreateOptions{})
-	if !k8serrors.IsAlreadyExists(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsAlreadyExists, "k8serrors.IsAlreadyExists"),
+	))
 }
 
 func cleanupServiceAccount(saName string) {
 	virtCli := kubevirt.Client()
 
 	err := virtCli.CoreV1().ServiceAccounts(GetTestNamespace(nil)).Delete(context.Background(), saName, metav1.DeleteOptions{})
-	if !k8serrors.IsNotFound(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsNotFound, "k8serrors.IsNotFound"),
+	))
 
 	err = virtCli.CoreV1().Secrets(GetTestNamespace(nil)).Delete(context.Background(), saName, metav1.DeleteOptions{})
-	if !k8serrors.IsNotFound(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsNotFound, "k8serrors.IsNotFound"),
+	))
 
 	err = virtCli.RbacV1().Roles(GetTestNamespace(nil)).Delete(context.Background(), saName, metav1.DeleteOptions{})
-	if !k8serrors.IsNotFound(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsNotFound, "k8serrors.IsNotFound"),
+	))
 
 	err = virtCli.RbacV1().RoleBindings(GetTestNamespace(nil)).Delete(context.Background(), saName, metav1.DeleteOptions{})
-	if !k8serrors.IsNotFound(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsNotFound, "k8serrors.IsNotFound"),
+	))
 
 	err = virtCli.RbacV1().ClusterRoleBindings().Delete(context.Background(), getClusterRoleBindingName(saName), metav1.DeleteOptions{})
-	if !k8serrors.IsNotFound(err) {
-		util.PanicOnError(err)
-	}
+	Expect(err).To(Or(
+		Not(HaveOccurred()),
+		MatchError(k8serrors.IsNotFound, "k8serrors.IsNotFound"),
+	))
 }
